@@ -1,5 +1,5 @@
 /* Commands for the curses interface to Xconq.
-   Copyright (C) 1986-1989, 1991-1998 Stanley T. Shebs.
+   Copyright (C) 1986-1989, 1991-1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -14,8 +14,8 @@ extern char linear_char;
 extern char bord_char;
 extern char conn_char;
 
-static void impl_build PARAMS ((Side *side, Unit *unit, int u2, int n));
-static void resize_map PARAMS ((int n));
+static void impl_build(Side *side, Unit *unit, int u2, int n);
+static void resize_map(int n);
 
 #if 0 /* (should preserve in help somewhere) */
     tbcat(buf, "To move a unit, use [hjklyubn]\n");
@@ -418,7 +418,6 @@ do_fire_into(side)
 Side *side;
 {
     int x, y;
-    Unit *unit2;
 
     REQUIRE_UNIT();
     sprintf(spbuf, "Fire %s at where?", unit_handle(dside, curunit));
@@ -456,22 +455,22 @@ do_give(side)
 Side *side;
 {
     int n = prefixarg, something = FALSE, u, m, r, gift, actual;
-    Unit *main;
+    Unit *mainunit;
 
     REQUIRE_UNIT();
     u = curunit->type;
-    main = curunit->transport;
-    if (main != NULL) {
+    mainunit = curunit->transport;
+    if (mainunit != NULL) {
 	spbuf[0] = '\0';
-	m = main->type;
+	m = mainunit->type;
 	for_all_material_types(r) {
-	    gift = (n < 0 ? (um_storage_x(m, r) - main->supply[r]) : n);
+	    gift = (n < 0 ? (um_storage_x(m, r) - mainunit->supply[r]) : n);
 	    if (gift > 0) {
 		something = TRUE;
 		/* Be stingy if we're low */
 		if (2 * curunit->supply[r] < um_storage_x(u, r))
 		    gift = max(1, gift/2);
-		actual = transfer_supply(curunit, main, r, gift);
+		actual = transfer_supply(curunit, mainunit, r, gift);
 		sprintf(tmpbuf, " %d %s", actual, m_type_name(r));
 		strcat(spbuf, tmpbuf);
 	    }
@@ -1199,30 +1198,18 @@ Side *side;
 /* Generic command error routine just does a notify. */
 
 void
-#ifdef __STDC__
 cmd_error(Side *side, char *fmt, ...)
-#else
-cmd_error(side, fmt, a1, a2, a3, a4, a5, a6, a7, a8, a9)
-Side *side;
-char *fmt;
-long a1, a2, a3, a4, a5, a6, a7, a8, a9;
-#endif
 {
     char tmpnbuf[BUFSIZE];
+    va_list ap;
 
     if (!empty_string(fmt)) {
-#ifdef __STDC__
-	{
-	    va_list ap;
 
-	    va_start(ap, fmt);
-	    vsprintf(tmpnbuf, fmt, ap);
-	    va_end(ap);
-	}
-#else
-	sprintf(tmpnbuf, fmt, a1, a2, a3, a4, a5, a6, a7, a8, a9);
-#endif
-    low_notify(dside, tmpnbuf);
+	va_start(ap, fmt);
+	vsprintf(tmpnbuf, fmt, ap);
+	va_end(ap);
+
+	low_notify(dside, tmpnbuf);
     }
     xbeep();
 }
