@@ -1,5 +1,5 @@
 /* The main program of the curses interface to Xconq.
-   Copyright (C) 1986-1989, 1991-1998 Stanley T. Shebs.
+   Copyright (C) 1986-1989, 1991-1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -7,6 +7,9 @@ the Free Software Foundation; either version 2, or (at your option)
 any later version.  See the file COPYING.  */
 
 #include "conq.h"
+extern void auto_pick_new_research(Unit *unit);
+extern int auto_pick_new_build_task(Unit *unit);
+extern void auto_pick_new_plan(Unit *unit);
 #include "kpublic.h"
 #include "cmdline.h"
 #include "cconq.h"
@@ -26,9 +29,12 @@ any later version.  See the file COPYING.  */
 extern int autofinish_start;
 extern int autofinish_count;
 
-extern int hosting;
+static void describe_help(int arg, char *key, TextBuffer *buf);
 
-static void describe_help PARAMS ((int arg, char *key, TextBuffer *buf));
+void unit_advance_dialog(Unit *unit);
+void global_advance_dialog(Side *side, Unit *unit, int s);
+int unit_build_dialog(Unit *unit);
+void unit_plan_dialog(Unit *unit);
 
 #ifdef MAC /* temporary */
 char **current_cursor;
@@ -213,9 +219,7 @@ struct a_movie *movies;
 /* The main program just invokes everything else. */
 
 int
-main(argc, argv)
-int argc;
-char *argv[];
+main(int argc, char *argv[])
 {
 #ifdef THINK_C
     /* This is how Think C picks up a command line. */
@@ -248,17 +252,14 @@ char *argv[];
 #endif /* DEBUGGING */
     if (option_game_to_join != NULL) {
 	int rslt;
- 	extern int hosting;
-	extern char *connection_method_name;
-	extern int connection_method;
 
 	/* (should parse variant specs, then comment that they must be ignored) */
 	/* (should accept player specs) */
 	/* Go through once more and complain about anything not used. */
 	parse_command_line(argc, argv, leftover_options);
 	hosting = FALSE;
-	open_remote_connection(option_game_to_join);
-	if (connection_method > 0) {
+	rslt = open_remote_connection(option_game_to_join, hosting);
+	if (rslt > 0) {
 	    rslt = send_join("xxx");
 	    if (rslt) {
 		master_rid = 1;
@@ -269,10 +270,7 @@ char *argv[];
 		    }
 		}
 	    } else {
-		close_remote_connection();
-		/* Use of connection_method this way is weak; means
-		   having to reselect everything up reconnection. */
-		connection_method = 0;
+		close_remote_connection(0);
 	    }
 	}
     } else {
@@ -289,7 +287,7 @@ char *argv[];
 	make_trial_assignments();
 	if (option_game_to_host != NULL) {
 	    hosting = TRUE;
-	    open_remote_connection(option_game_to_host);
+	    open_remote_connection(option_game_to_host, hosting);
 	}
 	calculate_globals();
 	run_synth_methods();
@@ -987,7 +985,6 @@ Unit **unitp;
 {
     char ch;
     int ndirs, dir, nx, ny, rslt = FALSE;
-    Unit *nextocc;
 
     *unitp = NULL;
     prevmode = mode;
@@ -1220,14 +1217,14 @@ Side *side;
 /* Draw an individual detailed cell, as a row of one, on all maps. */
 
 void
-update_cell_display(side, x, y, rightnow)
+update_cell_display(side, x, y, flags)
 Side *side;
 int x, y;
-int rightnow;
+int flags;
 {
     if (active_display(side)) {
 	draw_row(x, y, 1);
-	if (rightnow)
+	if (flags & UPDATE_ALWAYS)
 	  refresh();
     }
 }
@@ -1484,16 +1481,10 @@ end_printing_forms()
 /* Even a curses interface can do simple "movies". */
 
 int
-#ifdef __STDC__
 schedule_movie(Side *side, char *movie, ...)
-#else
-schedule_movie(side, movie, a1, a2, a3, a4, a5)
-Side *side;
-char *movie;
-int a1, a2, a3, a4, a5;
-#endif
 {
     int i, itype;
+    va_list ap;
 
     if (numscheduled >= 10)
       return FALSE;
@@ -1515,22 +1506,12 @@ int a1, a2, a3, a4, a5;
     else if (strcmp(movie, "nuke") == 0)
       itype = movie_nuke;
     movies[numscheduled].itype = itype;
-#ifdef ANSI_PROTOTYPES
-    {
-	va_list ap;
 
-	va_start(ap, movie);
-	for (i = 0; i < 5; ++i)
-	  movies[numscheduled].args[i] = va_arg(ap, int);
-	va_end(ap);
-    }
-#else
-    movies[numscheduled].args[0] = a1;
-    movies[numscheduled].args[1] = a2;
-    movies[numscheduled].args[2] = a3;
-    movies[numscheduled].args[3] = a4;
-    movies[numscheduled].args[4] = a5;
-#endif
+    va_start(ap, movie);
+    for (i = 0; i < 5; ++i)
+      movies[numscheduled].args[i] = va_arg(ap, int);
+    va_end(ap);
+
     ++numscheduled;
     return TRUE;
 }
@@ -1569,39 +1550,6 @@ SideMask sidemask;
     numscheduled = 0;
 }
 
-void
-set_you_player(id)
-int id;
-{
-}
-
-void
-add_remote_player(name)
-char *name;
-{
-}
-
-int
-launch_game()
-{
-    /* Trial side/player assignment, will create the default player if
-       nececessary. */
-    make_trial_assignments();
-    /* A last-minute patch to ensure reasonable area dimensions. */
-    if (area.width == 0 || area.height == 0)
-      set_area_shape(DEFAULTWIDTH, DEFAULTHEIGHT, TRUE);
-    /* Synthesize the remainder of the initial game setup. */
-    calculate_globals();
-    run_synth_methods();
-    final_init();
-    assign_players_to_sides();
-    /* Init the display now. */
-    init_display();
-    /* Do first set of turn calcs. */
-    run_game(0);
-    return TRUE;
-}
-
 void
 make_generic_image_data(imf)
 ImageFamily *imf;
@@ -1619,7 +1567,39 @@ serial_port_dialog()
 
 #endif /* MAC */
 
-unit_advance_dialog(Unit *unit) { auto_pick_new_research(unit); }
-global_advance_dialog(Side *side, Unit *unit, int s) { auto_pick_new_research(unit); }
-unit_build_dialog(Unit *unit) { return auto_pick_new_build_task(unit); }
-unit_plan_dialog(Unit *unit) { auto_pick_new_plan(unit); }
+
+void
+unit_advance_dialog(Unit *unit)
+{
+    auto_pick_new_research(unit);
+}
+
+void
+global_advance_dialog(Side *side, Unit *unit, int s)
+{
+    auto_pick_new_research(unit);
+}
+
+int
+unit_build_dialog(Unit *unit)
+{
+    int u = auto_pick_new_build_task(unit);
+
+    return u;
+}
+
+void
+unit_plan_dialog(Unit *unit)
+{
+    auto_pick_new_plan(unit);
+}
+
+void
+add_remote_locally(int rid, char *str)
+{
+}
+
+void
+send_chat(int rid, char *str)
+{
+}
