@@ -1,5 +1,5 @@
 /* Map graphics for the curses interface to Xconq.
-   Copyright (C) 1986-1989, 1991-1996, 1998 Stanley T. Shebs.
+   Copyright (C) 1986-1989, 1991-1996, 1998, 1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -7,23 +7,23 @@ the Free Software Foundation; either version 2, or (at your option)
 any later version.  See the file COPYING.  */
 
 #include "conq.h"
-extern void others_here_desc PARAMS ((char *buf, Unit *unit));
-extern void occupants_desc PARAMS ((char *buf, Unit *unit));
+extern void others_here_desc(char *buf, Unit *unit);
+extern void occupants_desc(char *buf, Unit *unit);
 #include "cconq.h"
 
-static int xform PARAMS ((int x, int y, int *sxp, int *syp));
-static void draw_divider PARAMS ((void));
-static void draw_terrain_row PARAMS ((int x, int y, int len));
-static void draw_units PARAMS ((int x, int y));
-static void draw_people PARAMS ((int x, int y));
-static void draw_legend PARAMS ((int x, int y));
-static void draw_unit_details PARAMS ((Unit *unit));
-static void describe_cell PARAMS ((int x, int y, int tview, char *filler,
-				  char *buf));
-static void organize_list_contents PARAMS ((void));
-static void add_unit_to_list PARAMS ((Unit *unit));
-static void draw_unit_list_entry PARAMS ((int line));
-static void draw_type_list_entry PARAMS ((int line));
+static int xform(int x, int y, int *sxp, int *syp);
+static void draw_divider(void);
+static void draw_terrain_row(int x, int y, int len);
+static void draw_units(int x, int y);
+static void draw_people(int x, int y);
+static void draw_legend(int x, int y);
+static void draw_unit_details(Unit *unit);
+static void describe_cell(int x, int y, int tview, char *filler,
+				  char *buf);
+static void organize_list_contents(void);
+static void add_unit_to_list(Unit *unit);
+static void draw_unit_list_entry(int line);
+static void draw_type_list_entry(int line);
 
 char *dashbuffer;
 
