@@ -1100,6 +1100,9 @@ Unit *unit, *unit2, *newunit;
     if (completed(newunit)) {
     	garrison_unit(unit2, newunit);
 	make_unit_complete(newunit);
+	update_unit_display(newunit->side, newunit, TRUE);
+	use_up_acp(unit, uu_acp_to_build(u2, u3));
+	return A_BUILD_COMPLETED;
     }
     update_unit_display(newunit->side, newunit, TRUE);
     use_up_acp(unit, uu_acp_to_build(u2, u3));
