@@ -18,20 +18,27 @@ extern void give_up(Side *side, char *ainame);
 
 extern AI_ops mplayer_ops;
 
+/* The array of all possible AI types. */
+
 AI_ops **all_ai_ops;
 
 void
-init_ai_types()
+init_ai_types(void)
 {
     /* Fill in the table of pointers to AI types. */
     all_ai_ops = (AI_ops **) xmalloc(numaitypes * sizeof(AI_ops *));
+    /* A dummy AI(?) - all methods are NULL */
     all_ai_ops[0] = (AI_ops *) xmalloc(sizeof(AI_ops));
+    /* The generic AI "mplayer". */
     all_ai_ops[1] = &mplayer_ops;
 }
 
+/* Given a side that wants to have an AI running its units, find and
+   record the actual AI type that will be used, and run its
+   initialization method. */
+
 void
-init_ai(side)
-Side *side;
+init_ai(Side *side)
 {
     int i;
     char *typename;
@@ -44,18 +51,23 @@ Side *side;
 	    /* (should use the "best" default for this game and side) */
 	    side->player->aitypename = "mplayer";
 	}
+	/* If remote, do nothing beyond recording the name of the AI. */
+	if (numremotes > 0 && side->player->rid != my_rid)
+	  return;
+	/* Scan through the possible AI types. */
 	for (i = 0; i < numaitypes; ++i) {
 	    typename = (all_ai_ops[i])->name;
 	    if (typename != NULL
 		&& strcmp(typename, side->player->aitypename) == 0) {
 		test = (all_ai_ops[i])->to_test_compat;
 		if (test == NULL || (*test)()) {
+		    /* Record the index of the AI type. */
 		    side->aitype = i;
 		    fn = (all_ai_ops[i])->to_init;
 		    if (fn)
 		      (*fn)(side);
 		} else {
-		    /* desired aitype not avail - should complain */
+		    /* desired aitype incompatible - should complain */
 		}
 	    }
 	}
@@ -70,9 +82,7 @@ Side *side;
    being turned off. */
 
 void
-set_side_ai(side, typename)
-Side *side;
-char *typename;
+set_side_ai(Side *side, char *typename)
 {
     Unit *unit;
 
@@ -119,8 +129,7 @@ char *typename;
 /* The following functions dispatch on AI type. */
 
 void
-ai_init_turn(side)
-Side *side;
+ai_init_turn(Side *side)
 {
     void (*fn)(Side *side);
 
@@ -197,30 +206,6 @@ Unit *unit;
       return FALSE;
 }
 
-int
-ai_update_plan(Side *side, Unit *unit)
-{
-    int (*fn)(Unit *unit);
-
-    fn = ((all_ai_ops[side->aitype])->to_update_plan);
-    if (fn)
-      return (*fn)(unit);
-    else
-      return FALSE;
-}
-
-int
-ai_handle_emergency(Side *side, Unit *unit)
-{
-    int (*fn)(Unit *unit);
-
-    fn = ((all_ai_ops[side->aitype])->to_handle_emergency);
-    if (fn)
-      return (*fn)(unit);
-    else
-      return FALSE;
-}
-
 void
 ai_finish_movement(side)
 Side *side;
@@ -596,15 +581,30 @@ ai_init_shared()
 	    if (u_is_base(u2) &&
 		could_create(u1, u2) &&
 		1 /* can be made quickly? */) {
-		set_u_is_base_builder(u1, u2);
+
+// BUG FIX
+		set_u_is_base_builder(u1, TRUE);
+
+//		set_u_is_base_builder(u1, u2);
+
 	    }
 	    if (u_speed(u1) > 0 && could_carry(u1, u2)) {
 		set_u_is_transport(u1, TRUE);
 	    }
+
+// BUG FIX
+
+#if 1
+	    if (could_create(u1,u2)) {
+		set_u_can_make(u1, TRUE);
+#else
+
 	    if (could_create(u2, u1)) {
 		numbuilders++;
 /*		ave_build_time[u1] += uu_make(u2,u1);  */
 		set_u_can_make(u2, TRUE);
+
+#endif
 		/* A colonizer is a mobile builder of advanced units. */
 		if (u_advanced(u2) && mobile(u1))
 		  set_u_is_colonizer(u1, TRUE);
