@@ -2132,6 +2132,33 @@ type_can_carry(int u)
     return FALSE;
 }
 
+/* True if unit has enough occupants assigned to its defense. */
+
+int
+defended_by_occupants(Unit *unit)
+{
+    Unit *unit2;
+    int defenders = 0;
+
+    for_all_occupants(unit, unit2) {
+	if (is_active(unit2)
+	    && unit2->plan
+	    && unit2->plan->maingoal
+	    && unit2->plan->maingoal->type == GOAL_UNIT_OCCUPIED
+	    && unit2->plan->maingoal->args[0] == unit->id
+	    /* Occs that cannot defend the transport should not be
+	       assigned to occupy it, but check anyway for ability to
+	       protect. */
+	    && occ_can_defend_transport(unit2->type, unit->type)) {
+	    ++defenders;
+	}
+    }
+    if (enough_to_garrison(unit, defenders))
+        return TRUE;
+    else 
+        return FALSE;
+}
+
 /* True if first type can both occupy and protect second type. */
 
 int
@@ -2149,3 +2176,61 @@ occ_can_defend_transport(int o, int t)
       return TRUE;
     return FALSE;	
 }
+
+/* True if the specified number of defenders is sufficient to defend
+   the unit. Note that this garrison does not have to exist! */
+
+int
+enough_to_garrison(Unit *unit, int defenders)
+{
+    int u = unit->type;
+    Unit *unit2;
+	
+    /* We only worry about enemies within our tactical range. */	
+    unit2 = mobile_enemy_threat(unit, u_ai_tactical_range(u));
+    /* We are threatened by the enemy! */
+    if (unit2 && defenders < u_ai_war_garrison(u))
+      return FALSE;
+    else if (defenders < u_ai_peace_garrison(u))
+      /* No enemy in sight. */ 
+      return FALSE;
+    else
+      return TRUE;
+}
+
+/* Returns the first mobile enemy unit found within the specified
+   range that can hit or capture our unit. */
+
+Unit *
+mobile_enemy_threat(Unit *unit, int range)
+{
+    int x, y;
+    Unit *unit2;
+	
+    /* Go through all cells within the specified range. */
+    for_all_cells_within_range(unit->x, unit->y, range, x, y) {
+		Side *sidex = (unit->side ? unit->side : indepside);
+    	
+		if (!inside_area(x, y))
+		  continue;
+		if (!terrain_visible(sidex, x, y))
+		  continue;
+		/* Important to count also occupants here. */
+		for_all_stack_with_occs(x, y, unit2) {
+		    /* Only count visible mobile enemy units that actually 
+		       threaten us. */
+		    if (is_active(unit2)
+			/* The NULL side rarely attacks anybody :-) */
+			&& unit2->side
+			&& mobile(unit2->type)
+			&& unit_actually_visible(sidex, unit2)
+			&& !trusted_side(sidex, unit2->side)
+			&& (could_hit(unit2->type, unit->type)
+			    || capture_chance(unit2->type, unit->type, sidex) > 0)) {
+			return unit2;
+		    }
+		}
+    }
+    return NULL;
+}
+
