@@ -35,9 +35,20 @@ any later version.  See the file COPYING.  */
 #define UPDATE_CLOUDS 16
 #define UPDATE_WINDS 32
 
+/* The several stages of game setup. */
+
+enum setup_stage {
+    initial_stage,
+    game_load_stage,
+    variant_setup_stage,
+    player_setup_stage,
+    game_ready_stage
+};
+
+extern enum setup_stage current_stage;
+
 /* Declarations of globally visible globals. */
 
-extern int typesdefined;
 extern int gamedefined;
 extern int compromised;
 extern int cursequence;
@@ -240,7 +251,10 @@ extern int can_detonate(Unit *unit);
 extern int can_capture_directly(Unit *unit);
 extern int type_can_capture_directly(int u);
 extern int type_can_carry(int u);
+extern int defended_by_occupants(Unit *unit);
 extern int occ_can_defend_transport(int o, int t);
+extern int enough_to_garrison(Unit *unit, int defenders);
+extern Unit * mobile_enemy_threat(Unit *unit, int range);
 extern int found_blocking_elevation(int u, int ux, int uy, int uz, int u2, int u2x, int u2y, int u2z);
 extern int enough_ammo(Unit *unit, Unit *other);
 extern int capture_chance(int u, int u2, Side *side2);
