@@ -26,10 +26,6 @@ int any_enter_indep(int u);
 
 extern int error_is_bug;
 
-#ifndef __STDC__
-extern int free ();
-#endif
-
 static void describe_help_system(int arg, char *key, TextBuffer *buf);
 static void describe_instructions(int arg, char *key, TextBuffer *buf);
 static void describe_synth_run(TextBuffer *buf, int methkey);
@@ -3331,7 +3327,6 @@ int val;
       tbcat(buf, "false");
 }
 
-#ifdef __STDC__
 void
 tbprintf(TextBuffer *buf, char *str, ...)
 {
@@ -3343,19 +3338,6 @@ tbprintf(TextBuffer *buf, char *str, ...)
     tbcat(buf, line);
     va_end(ap);
 }
-#else
-void
-tbprintf(buf, str, a1, a2, a3, a4, a5, a6, a7, a8, a9)
-TextBuffer *buf;
-char *str;
-long a1, a2, a3, a4, a5, a6, a7, a8, a9;
-{
-    char line[300];
-
-    sprintf(line, str, a1, a2, a3, a4, a5, a6, a7, a8, a9);
-    tbcat(buf, line);
-}
-#endif
 
 #undef bcopy
 #define bcopy(a,b,c) memcpy(b,a,c)
