@@ -109,19 +109,13 @@ HistEventType type;
 }
 
 HistEvent *
-#ifdef __STDC__
 record_event(HistEventType type, SideMask observers, ...)
-#else
-record_event(type, observers, d1, d2, d3, d4)
-HistEventType type;
-SideMask observers;
-int d1, d2, d3, d4;
-#endif
 {
     int i, val;
     char *descs;
     HistEvent *hevt;
     Side *side;
+    va_list ap;
 
     if (!recording_events)
       return NULL;
@@ -130,25 +124,16 @@ int d1, d2, d3, d4;
     hevt->enddate = g_turn();
     hevt->observers = observers;
     descs = hevtdefns[type].datadescs;
-#ifdef __STDC__
-    {
-	va_list ap;
 
-	va_start(ap, observers);
-	for (i = 0; descs[i] != '\0'; ++i) {
-	    if (i >= 4)
-	      run_error("hevt type %d has too many parameters", type);
-	    val = va_arg(ap, int);
-	    hevt->data[i] = val;
-	}
-	va_end(ap);
+    va_start(ap, observers);
+    for (i = 0; descs[i] != '\0'; ++i) {
+	if (i >= 4)
+	  run_error("hevt type %d has too many parameters", type);
+	val = va_arg(ap, int);
+	hevt->data[i] = val;
     }
-#else
-    hevt->data[0] = d1;
-    hevt->data[1] = d2;
-    hevt->data[2] = d3;
-    hevt->data[3] = d4;
-#endif
+    va_end(ap);
+
     /* Check on plausibility of event data. */
     for (i = 0; descs[i] != '\0'; ++i) {
 	val = hevt->data[i];
