@@ -117,7 +117,7 @@ ImageFamily *imf;
     imf2->numsizes = 0;
     /* Clone the images. */
     for_all_images(imf, img) {
-	img2 = get_img(imf2, img->w, img->h, 0);
+	img2 = get_img(imf2, img->w, img->h);
 	truenext = img2->next;
 	memcpy(img2, img, sizeof(Image));
 	/* Clear the hook, we expect that the caller of this routine
@@ -345,7 +345,7 @@ find_imf(char *name)
    if necessary. */
 
 Image *
-get_img(ImageFamily *imf, int w, int h, int subimg)
+get_img(ImageFamily *imf, int w, int h)
 {
     Image *img, *nimg, *previmg;
 
@@ -364,10 +364,6 @@ get_img(ImageFamily *imf, int w, int h, int subimg)
     nimg->actualw = w;  nimg->actualh = h;
     nimg->notes = lispnil;
     nimg->bboxw = w;  nimg->bboxh = h;
-    /* Subimages get handled separately, we don't want to link into the
-       main list of images. */
-    if (subimg)
-      return nimg;
     /* Rely on zeroing of xmalloc blocks to avoid clearing other fields. */
     /* Link in order by size, smallest first. */
     previmg = NULL;
@@ -486,7 +482,7 @@ Obj *size, *parts;
     Obj *head, *rest, *typ, *prop, *proptype, *datalist;
     
     w = c_number(car(size));  h = c_number(cadr(size));
-    img = get_img(imf, w, h, 0);
+    img = get_img(imf, w, h);
     if (img == NULL)
       run_error("no image?");
     if (img->w == 1 && img->h == 1) {
@@ -781,7 +777,7 @@ ImageFamily *imf;
        small images. */
     if (img->istile || img->synthetic || img->w <= 8 || img->h <= 8)
       return NULL;
-    img2 = get_img(imf, img->w / 2, img->h / 2, 0);
+    img2 = get_img(imf, img->w / 2, img->h / 2);
     /* Chances are that any embedded subimage will become unrecognizable,
        so leave embedname empty. */
     if (img->embedx > 0)
@@ -883,7 +879,7 @@ ImageFamily *imf;
     img = largest_image(imf);
     if (img->istile || img->synthetic || img->w >= 64 || img->h >= 64)
       return NULL;
-    img2 = get_img(imf, img->w * 2, img->h * 2, 0);
+    img2 = get_img(imf, img->w * 2, img->h * 2);
     img2->embedname = img->embedname;
     if (img->embedx > 0)
       img2->embedx = img->embedx * 2;
@@ -1386,6 +1382,7 @@ ImageFamily *imf;
 	if (img->monodata != lispnil
 	    || img->maskdata != lispnil
 	    || img->colrdata != lispnil
+	    || img->filedata != lispnil
 	    || img->rawmonodata != NULL
 	    || img->rawmaskdata != NULL
 	    || img->rawcolrdata != NULL
@@ -1406,10 +1403,10 @@ ImageFamily *imf;
 	      fprintf(fp, " %s", "transition");
 	    fprintf(fp, ")");
 	    if (img->numsubimages > 0) {
-	      fprintf(fp, " (%s %d", keyword_name(K_X), img->numsubimages);
-	      if (img->subx > 0 || img->suby > 0)
-		fprintf(fp, " %d %d", img->subx, img->suby);
-	      fprintf(fp, ")");
+		fprintf(fp, " (%s %d", keyword_name(K_X), img->numsubimages);
+		if (img->subx > 0 || img->suby > 0)
+		  fprintf(fp, " %d %d", img->subx, img->suby);
+		fprintf(fp, ")");
 	    }
 	    if (img->embedname) {
 		fprintf(fp, " (%s \"%s\")",
@@ -1432,7 +1429,9 @@ ImageFamily *imf;
 	    if (img->w == 1 && img->h == 1) {
 		if (img->rawpalette != NULL) {
 		    write_color(fp, -1,
-				img->rawpalette[1], img->rawpalette[2], img->rawpalette[3]);
+				img->rawpalette[1],
+				img->rawpalette[2],
+				img->rawpalette[3]);
 		} else if (img->palette != lispnil) {
 		    palent = cdr(car(img->palette));
 		    if (stringp(car(palent)) || symbolp(car(palent))) {
