@@ -17,30 +17,31 @@ any later version.  See the file COPYING.  */
    preventing fatal conflicts. */
 
 #include "conq.h"
+extern void add_remote_players(void);
+extern void set_player_advantage(int n, int newadv);
+extern void rename_side_for_player(int n);
+extern void set_ai_for_player(int n, char *aitype);
 #include "kernel.h"
 #include "ai.h"
 #include "version.h"
 extern int gameinited;
 
-static void cache_possible_types PARAMS ((void));
-static void kill_excess_units PARAMS ((void));
-static void trial_assign_player PARAMS ((int i, Player *player));
-static void init_view_2 PARAMS ((Side *side, int terrainset));
-static void init_view_cell PARAMS ((int x, int y));
-static void maybe_init_view_cell PARAMS ((int x, int y));
-static int adj_seen_terrain PARAMS ((int x, int y, Side *side));
-static void init_ranged_views PARAMS ((void));
-
-/* This is true when the set of types has been defined.  Subsequently
-   only scenarios based on those types can be loaded. */
-
-int typesdefined = FALSE;
+static void cache_possible_types(void);
+static void kill_excess_units(void);
+static void trial_assign_player(int i, Player *player);
+static void init_view_2(Side *side, int terrainset);
+static void init_view_cell(int x, int y);
+static void maybe_init_view_cell(int x, int y);
+static int adj_seen_terrain(int x, int y, Side *side);
+static void init_ranged_views(void);
 
 /* This is true after the game is totally synthesized, but players may
    not all be in the game yet. */
 
 int gamedefined = FALSE;
 
+enum setup_stage current_stage = initial_stage;
+
 /* These are handy tmp vars, usually used with function args. */
 
 short tmputype;
@@ -101,7 +102,7 @@ short *u_possible;
 
 struct synthtype {
     int key;
-    int (*fn) PARAMS ((int calls, int runs));
+    int (*fn)(int calls, int runs);
     int dflt;
     int calls;
     int runs;
@@ -611,6 +612,7 @@ make_trial_assignments()
     Side *side;
     Player *player;
 
+    Dprintf("Making trial side/player assignments\n");
     /* Fill in the side's predefined default and range of initial advantage. */
     for_all_sides(side) {
     	init_side_advantage(side);
@@ -626,6 +628,8 @@ make_trial_assignments()
     for_all_sides(side) {
 	assignments[i++].side = side;
     }
+    if (numremotes > 0)
+      add_remote_players();
     /* If no players have been created, make one that is human-run,
        presumably by the person who started up this program. */
     if (numplayers == 0) {
@@ -729,8 +733,7 @@ make_up_a_side()
    global values. */
 
 void
-init_side_advantage(side)
-Side *side;
+init_side_advantage(Side *side)
 {
     /* Set up the default and range of initial advantages. */
     if (side->advantage == 0)
@@ -770,7 +773,8 @@ Side *side;
 	    }
 	}
     }
-    /* If we're not getting any guidance from global defaults, just set to 1. */
+    /* If we're not getting any guidance from global defaults, just
+       set to 1. */
     if (side->minadvantage == 0)
       side->minadvantage = 1;
     if (side->maxadvantage == 0)
@@ -780,7 +784,7 @@ Side *side;
 /* Add a side and a player to go with it (used by interfaces). */
 
 int
-add_side_and_player()
+add_side_and_player(void)
 {
     int n;
     Side *side;
@@ -788,7 +792,7 @@ add_side_and_player()
 
     side = make_up_a_side();
     if (side == NULL)
-      return FALSE;
+      return -1;
     n = numsides - 1;
     assignments[n].side = side;
     player = add_player();
@@ -800,15 +804,45 @@ add_side_and_player()
     if (player->advantage == 0) {
 	player->advantage = side->advantage;
     }
-    return TRUE;
+    /* Return the new side's position in the assignment array. */
+    return n;
+}
+
+void
+set_player_advantage(int n, int newadv)
+{
+    Player *player;
+
+    player = assignments[n].player;
+    if (player != NULL)
+      player->advantage = newadv;
+    /* (should complain otherwise) */
+}
+
+void
+rename_side_for_player(int n)
+{
+    Side *side;
+
+    side = assignments[n].side;
+    side->name = side->noun = side->pluralnoun = side->adjective = NULL;
+    make_up_side_name(side);
+}
+
+void
+set_ai_for_player(int n, char *aitype)
+{
+    Player *player;
+
+    player = assignments[n].player;
+    player->aitypename = aitype;
 }
 
 /* This can be used by interfaces to exchange players between one side and
    another. */
 
 int
-exchange_players(n, n2)
-int n, n2;
+exchange_players(int n, int n2)
 {
     int i;
     Player *tmpplayer = assignments[n].player;
@@ -1487,12 +1521,11 @@ assign_players_to_sides()
 			 player->advantage, player_desig(player), side->maxadvantage);
 	    player->advantage = side->maxadvantage;
 	}
-	side->rid = player->rid;
 	/* Call the interface code to initialize the side's display, if
 	   it wants to use one (the interface has to decide). */
 	if (side_wants_display(side)) {
 	    ++numdisplayswanted;
-	    if (side->rid == my_rid) {
+	    if (player->rid == my_rid) {
 		init_ui(side);
 	    } else {
 		init_remote_ui(side);
@@ -1506,7 +1539,7 @@ assign_players_to_sides()
 	    ++numais;
 	}
 	Dprintf("Assigned %s to %s\n",
-		 side_desig(side), player_desig(player));
+		side_desig(side), player_desig(player));
     }
     finish_lengthy_process();
     if (numdisplays < numdisplayswanted) {
@@ -1518,7 +1551,7 @@ assign_players_to_sides()
 			 numdisplays, numdisplayswanted);
 	}
     } else if (numdisplays == 0) {
-	init_warning("Need at least one display to run");
+	init_warning("Need at least one local or remote display to run");
     }
 #ifdef DESIGNERS
     /* Make each displayed side into a designer if it was requested. */
