@@ -16,19 +16,20 @@ any later version.  See the file COPYING.  */
 #include "lisp.h"
 #include "module.h"
 #include "system.h"
-void mac_abort PARAMS ((void));
+void mac_abort(void);
 
 /* Following are from tp.h, but tp.h is too high-level to include. */
 
+#if 0  /* shouldn't be here */
 extern int numremotes;
 extern int my_rid;
 extern int master_rid;
-extern int tmprid;
+#endif
 
-extern void init_file_port PARAMS ((int hosting));
-extern void close_file_port PARAMS ((void));
-extern void low_file_send PARAMS ((int id, char *buf));
-extern int low_file_receive PARAMS ((int *id, char *buf, int maxchars, int timeout));
+extern void init_file_port(int willhost);
+extern void close_file_port(void);
+extern void low_file_send(int id, char *buf);
+extern int low_file_receive(int *id, char *buf, int maxchars, int timeout);
 
 extern int serial_port_dialog(void);
 
@@ -111,12 +112,8 @@ extern CursHandle current_cursor;
 static void low_serial_send(int id, char *buf);
 static int low_serial_readchars(char *buf, int maxchars, int timeout);
 
-char *connection_method_name;
-
 int connection_method;
 
-int hosting;
-
 /* The HFS volume that the program started with. */
 
 short initialvrefnum;
@@ -255,36 +252,59 @@ FILE *
 open_file(char *filename, char *mode)
 {
 	FILE 	*fp;
+	short	curvrefnum;
 	int 	mac_linefeeds = 0;
 	int 	unix_linefeeds = 0;
 	int	ch;
 
-	/* First open in binary read mode (no conversion). */
+	/* Hack. Force debug output to top directory. */ 
+	if (strcmp(filename, "Xconq.DebugOut") == 0)
+	    SetVol(NULL, initialvrefnum);
+
+	/* Hack. Force warning output to top directory. */ 
+	if (strcmp(filename, "Xconq.Warnings") == 0)
+	    SetVol(NULL, initialvrefnum);
+
+	/* Writing or Appending: always mac format. */	
+	if (strcmp(mode, "w") == 0) {
+		fp = fopen(filename, "w");
+		return fp;
+	}		
+	if (strcmp(mode, "a") == 0) {
+		fp = fopen(filename, "a");
+		return fp;
+	}		
+	/* Reading: first open in binary mode (no conversion). */
 	fp = fopen(filename, "rb");
-	/* Don't proceed if we failed. */
+	/* Look in xconq start directory if we did not find a file. */
+	if (fp == NULL) {
+		GetVol(NULL, &curvrefnum);
+		SetVol(NULL, initialvrefnum);
+		fp = fopen(filename, "rb");
+		SetVol(NULL, curvrefnum);
+	}
+	/* Give up if we found nothing there either. */
 	if (fp == NULL)
-		return NULL;
+	    return fp;
+	/* Binary (image) files don't need conversion. */
 	if (strcmp(mode, "rb") == 0)
-	  return fp;
-	/* Count the total number of linefeeds of each kind. */
+	    return fp;
+	/* Text file. Count the number of linefeeds of each kind. */
 	while ((ch = getc(fp)) != EOF) {
 		if (ch == '\r')
 			++mac_linefeeds;
 		if (ch == '\n')
 			++unix_linefeeds;
 	}
-	/* Close the file in case we wish to append or write. */
+	/* Close the file (also needed in unix case to reset file pointer). */
 	fclose(fp);
 	/* Assume that a mac file has more mac than unix linefeeds. */
 	if (mac_linefeeds > unix_linefeeds) {
-		/* Reopen mac files in text mode (with conversion). */
-		fp = fopen(filename, mode);
+		/* Reopen mac file in text mode (with conversion). */
+		fp = fopen(filename, "r");
 	} else	{
-		/* Reopen unix files in binary mode (no conversion). */
-		fp = fopen(filename, strcat(mode, "b"));
-		/* Remove the "b" when done, or mode will be "rbbbbbb" 
-		after a few unix files have been opened. */
-		mode[1] = '\0';
+		/* Reopen unix file in binary mode (no conversion). */
+		fp = fopen(filename, "rb");
 	}
 	return fp;		
 }
@@ -312,16 +332,6 @@ open_module_library_file(Module *module)
 	    module->filename = copy_string(fullnamebuf);
 	    return fp;
 	}
-	/* Try the same name in a different directory. */
-	GetVol(NULL, &curvrefnum);
-	SetVol(NULL, initialvrefnum);
-	fp = open_file(fullnamebuf, "r");
-	SetVol(NULL, curvrefnum);
-	if (fp != NULL) {
-	    /* Remember the filename (what about volume?) where we found it. */
-	    module->filename = copy_string(fullnamebuf);
-	    return fp;
-	}
     }
     return NULL;
 }
@@ -343,12 +353,6 @@ open_module_explicit_file(Module *module)
 		fp = open_file(fullnamebuf, "r");
 		if (fp != NULL)
 		  return fp;
-		GetVol(NULL, &curvrefnum);
-		SetVol(NULL, initialvrefnum);
-		fp = open_file(fullnamebuf, "r");
-		SetVol(NULL, curvrefnum);
-		if (fp != NULL)
-		  return fp;
 	    }
 	}
     } else {
@@ -367,13 +371,8 @@ open_module_explicit_file(Module *module)
 	fp = open_file(fullnamebuf, "r");
 	if (fp != NULL)
 	  return fp;
-	/* Try opening a library module under where the program started. */
-	GetVol(NULL, &curvrefnum);
-	SetVol(NULL, initialvrefnum);
-	fp = open_file(fullnamebuf, "r");
-	SetVol(NULL, curvrefnum);
     }
-    return fp;
+    return NULL;
 }
 
 FILE *
@@ -395,13 +394,6 @@ open_library_file(char *filename)
  	fp = open_file(fullnamebuf, "r");
 	if (fp != NULL)
 	  return fp;
-	/* Change to volume where the program started. */
-	GetVol(NULL, &curvrefnum);
-	SetVol(NULL, initialvrefnum);
-	fp = open_file(fullnamebuf, "r");
-	SetVol(NULL, curvrefnum);
-	if (fp != NULL)
-	  return fp;
     }
     return NULL;
 }
@@ -534,8 +526,8 @@ mac_abort ()
     exit(1);
 }
 
-void
-open_remote_connection(char *methodname)
+int
+open_remote_connection(char *methodname, int willhost)
 {
     int serial_port, rslt;
 
@@ -564,13 +556,15 @@ open_remote_connection(char *methodname)
 	init_serial_port(serial_port);
 	/* Serial supports exactly two programs, so we can easily
 	   set up all the rids right now. */
+#if 0 /* but that would be wrong */
 	master_rid = 1;
-	if (hosting) {
+	if (willhost) {
 	    my_rid = 1;
 	} else {
 	    my_rid = 2;
 	}
 	numremotes = 2;
+#endif
 	break;
       case 2:
 	open_appletalk();
@@ -579,11 +573,12 @@ open_remote_connection(char *methodname)
 	init_warning("No TCP/IP support yet, ignoring");
 	break;
       case 4:
-	init_file_port(hosting);
+	init_file_port(willhost);
 	break;
       default:
 	break;
     }
+    return connection_method;
 }
 
 extern short ser_input_refnum;
@@ -638,12 +633,12 @@ low_receive(int *idp, char *buf, int maxchars, int timeout)
 	break;
       case 1:
 	/* Only one remote if using serial. */
-	*idp = (my_rid == 1 ? 2 : 1);
+	*idp = (0 /*my_rid == 1 */? 2 : 1);
 	rslt = low_serial_readchars(buf, maxchars, timeout);
 	break;
       case 2:
 	/* Only one remote for now. */
-	*idp = (my_rid == 1 ? 2 : 1);
+	*idp = (0 /*my_rid == 1*/ ? 2 : 1);
 	rslt = low_appletalk_receive(idp, buf, maxchars, timeout);
 	break;
       case 3:
@@ -665,7 +660,7 @@ low_receive(int *idp, char *buf, int maxchars, int timeout)
 }
 
 void
-close_remote_connection()
+close_remote_connection(int rid)
 {
     switch (connection_method) {
       case 0:
@@ -915,13 +910,15 @@ open_appletalk()
 
     numgotten = tmpMPPPB.NBP.parm.Lookup.numGotten;
     if (numgotten > 0) {
+#if 0
 	master_rid = 1;
-	if (hosting) {
+	if (willhost) {
 	    my_rid = 1;
 	} else {
 	    my_rid = 2;
 	}
 	numremotes = 1;
+#endif
 	/* (should use this loop to get actual number of remotes) */
 	for (i = 0; i < numgotten; ++i) {
 	    err = NBPExtract(namesbuffer, numgotten, i + 1, &entityname, &remote_addr); 
