@@ -1,5 +1,5 @@
 /* Game modules for Xconq.
-   Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1998 Stanley T. Shebs.
+   Copyright (C) 1991-1996, 1998, 1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -10,7 +10,8 @@ any later version.  See the file COPYING.  */
 
 extern char *readerrbuf;
 
-static void do_one_variant PARAMS ((Module *module, struct a_variant *var, Obj *varsetdata));
+static void do_one_variant(Module *module, struct a_variant *var,
+			   Obj *varsetdata);
 
 /* List of all known modules. Their descriptions can co-exist in memory,
    even if their contents cannot. */
@@ -26,7 +27,7 @@ char *moduledesigbuf = NULL;
 /* Empty out the list of modules. */
 
 void
-clear_game_modules()
+clear_game_modules(void)
 {
     modulelist = mainmodule = NULL;
 }
@@ -34,8 +35,7 @@ clear_game_modules()
 /* Create a brand-new game module. */
 
 Module *
-create_game_module(name)
-char *name;
+create_game_module(char *name)
 {
     Module *module = (Module *) xmalloc(sizeof(Module));
 
@@ -56,8 +56,7 @@ char *name;
 }
 
 Module *
-find_game_module(name)
-char *name;
+find_game_module(char *name)
 {
     Module *module;
 
@@ -74,8 +73,7 @@ char *name;
 /* Produce a module of the given name, either by finding it or creating it. */
 
 Module *
-get_game_module(name)
-char *name;
+get_game_module(char *name)
 {
     Module *module = find_game_module(name);
 
@@ -88,9 +86,7 @@ char *name;
    list of another module. */
 
 Module *
-add_game_module(name, includer)
-char *name;
-Module *includer;
+add_game_module(char *name, Module *includer)
 {
     Module *module = get_game_module(name), *other;
 
@@ -119,7 +115,7 @@ Module *includer;
    it the main module if none defined. */
 
 void
-load_default_game()
+load_default_game(void)
 {
     extern char *standard_game_name;
     char *defaultname = standard_game_name;
@@ -148,8 +144,7 @@ load_default_game()
    otherwise. */
 
 int
-load_game_description(module)
-Module *module;
+load_game_description(Module *module)
 {
     Obj *form, *thecar;
     char *name;
@@ -177,9 +172,7 @@ Module *module;
    function tries to find a file, open it, and load the contents. */
 
 void
-load_game_module(module, dowarn)
-Module *module;
-int dowarn;
+load_game_module(Module *module, int dowarn)
 {
     char ch;
 
@@ -200,30 +193,25 @@ int dowarn;
 	}
 	/* We're done, can close. */
 	close_module(module);
-	/* Mark the module as having been loaded - note that this will happen
-	   even if there were horrible errors. */
+	/* Mark the module as having been loaded - note that this will
+	   happen even if there were horrible errors. */
 	module->loaded = TRUE;
-	/* If the turn number has been set explicitly to a positive value,
-	   assume that a saved game is being restored into the middle of the turn. */
+	/* If the turn number has been set explicitly to a positive
+	   value, assume that a saved game is being restored into the
+	   middle of the turn. */
 	if (g_turn() > 0)
 	  midturnrestore = TRUE;
-	/* If the random state has been set explicitly to a nonnegative value,
-	   use it to reseed the generator. */
+	/* If the random state has been set explicitly to a
+	   nonnegative value, use it to reseed the generator. */
 	if (g_random_state() >= 0)
 	  init_xrandom(g_random_state());
 	/* Make all the cross-references right. */
 	patch_object_references();
-	/* Are all the types staked down now? */
-	if (!canaddutype && !canaddmtype && !canaddttype && !canaddatype) {
-	    typesdefined = TRUE;
-	    /* (should also record this as a sort of base module?) */
-	}
     }
 }
 
 void
-load_base_module(module)
-Module *module;
+load_base_module(Module *module)
 {
     char *basename = module->basemodulename;
     Module *basemodule;
@@ -245,9 +233,7 @@ Module *module;
 /* Given a module, attempt to open it. */
 
 int
-open_module(module, dowarn)
-Module *module;
-int dowarn;
+open_module(Module *module, int dowarn)
 {
     FILE *fp = NULL;
 
@@ -303,8 +289,7 @@ int dowarn;
 /* (fix so that correct name can be found reliably) */
 
 int
-load_side_config(side)
-Side *side;
+load_side_config(Side *side)
 {
 #if 0
     FILE *fp;
@@ -343,8 +328,7 @@ Side *side;
    loaded?) */
 
 void
-read_forms(module)
-Module *module;
+read_forms(Module *module)
 {
     Obj *form;
 
@@ -373,9 +357,7 @@ Module *module;
 /* Interpret the given list of variants. */
 
 void
-do_module_variants(module, lis)
-Module *module;
-Obj *lis;
+do_module_variants(Module *module, Obj *lis)
 {
     int i, found, didsome;
     Obj *restset, *varset;
@@ -416,10 +398,7 @@ Obj *lis;
 }
 
 static void
-do_one_variant(module, var, varsetdata)
-Module *module;
-Variant *var;
-Obj *varsetdata;
+do_one_variant(Module *module, Variant *var, Obj *varsetdata)
 {
     int val, caseval;
     int width = 0, height = 0, circumference, latitude, longitude;
@@ -576,8 +555,7 @@ Obj *varsetdata;
 }
 
 void
-init_module_reshape(module)
-Module *module;
+init_module_reshape(Module *module)
 {
     /* Seed all the reshaping parameters with reasonable values. */
     module->maybe_reshape = TRUE;
@@ -595,8 +573,7 @@ Module *module;
 /* This is true if any actual reshaping is required. */
 
 int
-reshape_the_output(module)
-Module *module;
+reshape_the_output(Module *module)
 {
     return (module->maybe_reshape
 	    && (module->subarea_width != area.width
@@ -615,8 +592,7 @@ Module *module;
 /* Check if the proposed reshape will actually work. */
 
 int
-valid_reshape(module)
-Module *module;
+valid_reshape(Module *module)
 {
     /* (should check hexagon shaping) */
     if (module->subarea_width > area.width
@@ -631,8 +607,7 @@ Module *module;
 /* Close the module. */
 
 void
-close_module(module)
-Module *module;
+close_module(Module *module)
 {
     if (module->sp) {
 	module->sp = NULL;
@@ -647,8 +622,7 @@ Module *module;
 /* Return a description of the module. */
 
 char *
-module_desig(module)
-Module *module;
+module_desig(Module *module)
 {
     if (moduledesigbuf == NULL)
       moduledesigbuf = xmalloc(BUFSIZE);
@@ -663,8 +637,7 @@ Module *module;
 /* Use this to ensure that everything is cool. */
 
 void
-doublecheck_state(side)
-Side *side;
+doublecheck_state(Side *side)
 {
     Unit *unit;
 
@@ -678,17 +651,16 @@ Side *side;
 }
 #endif /* DEBUGGING */
 
-void set_u_internal_name(u, s) int u; char *s; { utypes[u].iname = s; }
-void set_u_type_name(u, s) int u; char *s; { utypes[u].name = s; }
-void set_m_type_name(m, s) int m; char *s; { mtypes[m].name = s; }
-void set_t_type_name(t, s) int t; char *s; { ttypes[t].name = s; }
-void set_a_type_name(a, n) int a; char *n; { atypes[a].name = n; }
+void set_u_internal_name(int u, char *s) { utypes[u].iname = s; }
+void set_u_type_name(int u, char *s) { utypes[u].name = s; }
+void set_m_type_name(int m, char *s) { mtypes[m].name = s; }
+void set_t_type_name(int t, char *s) { ttypes[t].name = s; }
+void set_a_type_name(int a, char *s) { atypes[a].name = s; }
 
 /* If a special symbol, we might not have to fail. */
 
 int
-lazy_bind(sym)
-Obj *sym;
+lazy_bind(Obj *sym)
 {
     int u, m, t, a;
     Obj *value;
@@ -724,8 +696,7 @@ Obj *sym;
 }
 
 int
-coerce_to_side_id(x)
-Obj *x;
+coerce_to_side_id(Obj *x)
 {
     if (numberp(x)) {
 	return c_number(x);
@@ -734,15 +705,13 @@ Obj *x;
 }
 
 Side *
-coerce_to_side(x)
-Obj *x;
+coerce_to_side(Obj *x)
 {
     return side_n(coerce_to_side_id(x));
 }
 
 int
-coerce_to_unit_id(x)
-Obj *x;
+coerce_to_unit_id(Obj *x)
 {
     if (numberp(x)) {
 	return c_number(x);
@@ -751,8 +720,7 @@ Obj *x;
 }
 
 Unit *
-coerce_to_unit(x)
-Obj *x;
+coerce_to_unit(Obj *x)
 {
     return find_unit(coerce_to_unit_id(x));
 }
