@@ -375,11 +375,10 @@ int u, ox, oy, nx, ny;
 }
 
 int
-unit_speed(unit, nx, ny)
-Unit *unit;
-int nx, ny;
+unit_speed(Unit *unit, int nx, int ny)
 {
-    int u = unit->type, speed, x = unit->x, y = unit->y, angle, windval;
+    int u = unit->type, speed, x = unit->x, y = unit->y;
+    int dir, angle1, windval1, angle2, windval2;
     int occeff, totocceff, totoccdenom;
     Unit *occ;
     
@@ -387,10 +386,17 @@ int nx, ny;
     if (unit->hp < u_hp_max(u) && u_speed_damage_effect(u) != lispnil) {
 	speed = damaged_value(unit, u_speed_damage_effect(u), speed);
     }
+    /* The speed effect due to wind is an average of the wind effect
+       in the current cell and in the new cell. */
     if (winds_defined() && u_speed_wind_effect(u) != lispnil) {
-	angle = angle_with(closest_dir(nx - x, nx - y), wind_dir_at(x, y));
-	windval = wind_value(unit, angle, wind_force_at(x, y), u_speed_wind_effect(u), 10000);
-	speed = (speed * windval) / 100;
+	dir = closest_dir(nx - x, ny - y);
+	angle1 = angle_with(dir, wind_dir_at(x, y));
+	windval1 = wind_value(unit, angle1, wind_force_at(x, y),
+			      u_speed_wind_effect(u), 10000);
+	angle2 = angle_with(dir, wind_dir_at(nx, ny));
+	windval2 = wind_value(unit, angle2, wind_force_at(nx, ny),
+			      u_speed_wind_effect(u), 10000);
+	speed = (speed * ((windval1 + windval2) / 2)) / 100;
     }
     if (unit->occupant /* and any occupant speed effects */) {
         totocceff = 100;
@@ -412,19 +418,17 @@ int nx, ny;
     return speed;
 }
 
-/* Compute and return value for a damaged unit, using a list of (hp val) pairs
-   and interpolating between them. */
+/* Compute and return value for a damaged unit, using a list of
+   (hp val) pairs and interpolating between them. */
 
 int
-damaged_value(unit, effect, maxval)
-Unit *unit;
-Obj *effect;
-int maxval;
+damaged_value(Unit *unit, Obj *effect, int maxval)
 {
     int u, err, rslt;
 
     u = unit->type;
-    err = interpolate_in_list_ext(unit->hp, effect, 0, 0, 0, 0, u_hp(u), maxval, &rslt);
+    err = interpolate_in_list_ext(unit->hp, effect, 0, 0, 0, 0, u_hp(u),
+				  maxval, &rslt);
     if (err != 0) {
 	run_warning("cannot get damaged speed for %s at hp %d, using 100",
 		    u_type_name(u), unit->hp);
@@ -437,15 +441,12 @@ int maxval;
    and interpolating between them. */
 
 int
-wind_value(unit, angle, force, effect, maxval)
-Unit *unit;
-int angle, force, maxval;
-Obj *effect;
+wind_value(Unit *unit, int angle, int force, Obj *effect, int maxval)
 {
     int err, rslt;
     Obj *rest, *head, *key, *val;
 
-    for (rest = effect; rest != lispnil; rest = cdr(rest)) {
+    for_all_list(effect, rest) {
 	head = car(rest);
 	key = car(head);
 	if ((numberp(key) && angle == c_number(key))
@@ -459,7 +460,8 @@ Obj *effect;
 		if (err == 0) {
 		    return rslt;
 		} else {
-		    run_warning("no value for wind angle=%d force=%d", angle, force);
+		    run_warning("no value for wind angle=%d force=%d",
+				angle, force);
 		    return maxval;
 		}
 	    }
@@ -469,9 +471,7 @@ Obj *effect;
 }
 
 int
-number_member(x, lis)
-int x;
-Obj *lis;
+number_member(int x, Obj *lis)
 {
     Obj *rest;
 
