@@ -134,32 +134,18 @@ init_nlang()
 
 /* Send a message to everybody who's got a screen. */
 
-#ifdef __STDC__
 void
 notify_all(char *fmt, ...)
-#else
-void
-notify_all(fmt, a1, a2, a3, a4, a5, a6, a7, a8, a9)
-char *fmt;
-long a1, a2, a3, a4, a5, a6, a7, a8, a9;
-#endif
 {
+    va_list ap;
     Side *side;
 
     for_all_sides(side) {
 	if (active_display(side)) {
 	    maybe_mention_date(side);
-#ifdef __STDC__
-	    {
-		va_list ap;
-
-		va_start(ap, fmt);
-		vsprintf(tmpnbuf, fmt, ap);
-		va_end(ap);
-	    }
-#else
-	    sprintf(tmpnbuf, fmt, a1, a2, a3, a4, a5, a6, a7, a8, a9);
-#endif
+	    va_start(ap, fmt);
+	    vsprintf(tmpnbuf, fmt, ap);
+	    va_end(ap);
 	    /* Always capitalize first char of notice. */
 	    if (islower(tmpnbuf[0]))
 	      tmpnbuf[0] = toupper(tmpnbuf[0]);
@@ -168,43 +154,25 @@ long a1, a2, a3, a4, a5, a6, a7, a8, a9;
     }
 }
 
-#ifdef __STDC__
 void
 notify(Side *side, char *fmt, ...)
-#else
-void
-notify(side, fmt, a1, a2, a3, a4, a5, a6, a7, a8, a9)
-Side *side;
-char *fmt;
-long a1, a2, a3, a4, a5, a6, a7, a8, a9;
-#endif
 {
+    va_list ap;
+
     if (!active_display(side))
       return;
     maybe_mention_date(side);
-#ifdef __STDC__
-    {
-	va_list ap;
-
-	va_start(ap, fmt);
-	vsprintf(tmpnbuf, fmt, ap);
-	va_end(ap);
-    }
-#else
-    sprintf(tmpnbuf, fmt, a1, a2, a3, a4, a5, a6, a7, a8, a9);
-#endif
+    va_start(ap, fmt);
+    vsprintf(tmpnbuf, fmt, ap);
+    va_end(ap);
     /* Always capitalize first char of notice. */
     if (islower(tmpnbuf[0]))
       tmpnbuf[0] = toupper(tmpnbuf[0]);
     low_notify(side, tmpnbuf);
 }
 
-#if defined(__STDC__) || defined(MPW_C)
 void
-vnotify(side, fmt, ap)
-Side *side;
-char *fmt;
-va_list ap;
+vnotify(Side *side, char *fmt, va_list ap)
 {
     if (!active_display(side))
       return;
@@ -215,11 +183,9 @@ va_list ap;
       tmpnbuf[0] = toupper(tmpnbuf[0]);
     low_notify(side, tmpnbuf);
 }
-#endif /* __STDC__ */
 
 static void
-maybe_mention_date(side)
-Side *side;
+maybe_mention_date(Side *side)
 {
     /* Note that last_notice_date defaults to 0, so this means that
        any turn 0 notices will not have a date prepended (which is good). */
@@ -230,13 +196,11 @@ Side *side;
     }
 }
 
-/* Pad a given buffer with blanks out to the given position, and cut off any
-   additional content. */
+/* Pad a given buffer with blanks out to the given position, and cut
+   off any additional content. */
 
 void
-pad_out(buf, n)
-char *buf;
-int n;
+pad_out(char *buf, int n)
 {
     int i, len = strlen(buf);
 
@@ -253,8 +217,7 @@ int n;
 /* (should synth complete name/adjective from other parts of speech) */
 
 char *
-side_name(side)
-Side *side;
+side_name(Side *side)
 {
     return (side == NULL ? "independent" :
       (side->name ? side->name :
@@ -265,8 +228,7 @@ Side *side;
 }
 
 char *
-side_adjective(side)
-Side *side;
+side_adjective(Side *side)
 {
     return (side == NULL ? "independent" :
        (side->adjective ? side->adjective :
@@ -277,8 +239,7 @@ Side *side;
 }
 
 char *
-short_side_title(side)
-Side *side;
+short_side_title(Side *side)
 {
     if (side_short_title == NULL)
       side_short_title = xmalloc(BUFSIZE);
@@ -299,9 +260,7 @@ Side *side;
 }
 
 char *
-short_side_title_with_adjective(side, adjective)
-Side *side;
-char *adjective;
+short_side_title_with_adjective(Side *side, char *adjective)
 {
     if (side_short_title == NULL)
       side_short_title = xmalloc(BUFSIZE);
@@ -348,8 +307,7 @@ char *adjective;
    of title. */
 
 int
-short_side_title_plural_p(side)
-Side *side;
+short_side_title_plural_p(Side *side)
 {
     if (side == NULL) {
 	return FALSE;
@@ -368,9 +326,7 @@ Side *side;
 }
 
 char *
-shortest_side_title(side2, buf)
-Side *side2;
-char *buf;
+shortest_side_title(Side *side2, char *buf)
 {
     if (side2 == NULL) {
 	return "-";
@@ -389,9 +345,7 @@ char *buf;
 }
 
 char *
-sidemask_desc(buf, sidemask)
-char *buf;
-SideMask sidemask;
+sidemask_desc(char *buf, SideMask sidemask)
 {
     int first = TRUE;
     Side *side2;
@@ -2073,7 +2027,7 @@ Goal *goal;
     char *argtypes;
 
     if (goal == NULL)
-      return "<null goal>";
+      return "null goal";
     switch (goal->type) {
       case GOAL_KEEP_FORMATION:
 	sprintf(buf, " %d,%d from %s (var %d)",
@@ -2087,8 +2041,7 @@ Goal *goal;
 	break;
 	/* (should add more cases specific to common types of goals) */
       default:
-	sprintf(buf, "<goal s%d %s%s",
-		side_number(goal->side), (goal->tf ? "" : "not "),
+	sprintf(buf, "%s%s", (goal->tf ? "" : "not "),
 		goaldefns[goal->type].name);
 	argtypes = goaldefns[goal->type].argtypes;
 	numargs = strlen(argtypes);
@@ -2114,7 +2067,7 @@ Goal *goal;
 		  tprintf(buf, " u%d?", arg);
 		break;
 	      case 'U':
-		tprintf(buf, " `%s'", unit_handle(NULL, find_unit(arg)));
+		tprintf(buf, " %s", unit_handle(NULL, find_unit(arg)));
 		break;
 	      case 'w':
 		tprintf(buf, " %dx", arg);
@@ -2130,7 +2083,6 @@ Goal *goal;
 		break;
 	    }
 	}
-	strcat(buf, ">");
 	break;
     }
     return buf;
@@ -3007,9 +2959,7 @@ int date;
 /* Show some overall numbers on performance of a side. */
 
 void
-write_side_results(fp, side)
-FILE *fp;
-Side *side;
+write_side_results(FILE *fp, Side *side)
 {
     int i;
 
@@ -3033,9 +2983,7 @@ Side *side;
    and losses. */
 
 void
-write_unit_record(fp, side)
-FILE *fp;
-Side *side;
+write_unit_record(FILE *fp, Side *side)
 {
     int u, gainreason, lossreason, totgain, totloss, val;
 
@@ -3082,9 +3030,7 @@ Side *side;
 }
 
 static int
-gain_count(side, u, r)
-Side *side;
-int u, r;
+gain_count(Side *side, int u, int r)
 {
     int sum;
 
@@ -3098,9 +3044,7 @@ int u, r;
 }
 
 static int
-loss_count(side, u, r)
-Side *side;
-int u, r;
+loss_count(Side *side, int u, int r)
 {
     int sum;
 
@@ -3117,9 +3061,7 @@ int u, r;
    a useful check against subjective evaluation of performance. */
 
 void
-write_combat_results(fp, side)
-FILE *fp;
-Side *side;
+write_combat_results(FILE *fp, Side *side)
 {
     int a, d, atk;
 
@@ -3164,9 +3106,7 @@ Side *side;
 }
 
 static int
-atkstats(side, a, d)
-Side *side;
-int a, d;
+atkstats(Side *side, int a, int d)
 {
     int sum;
 
@@ -3180,9 +3120,7 @@ int a, d;
 }
 
 static int
-hitstats(side, a, d)
-Side *side;
-int a, d;
+hitstats(Side *side, int a, int d)
 {
     int sum;
 
@@ -3196,9 +3134,7 @@ int a, d;
 }
 
 void
-dice_desc(buf, dice)
-char *buf;
-int dice;
+dice_desc(char *buf, int dice)
 {
     int numdice, die, offset;
 
@@ -3219,9 +3155,7 @@ int dice;
 /* The following code formats a list of types that are missing images. */
 
 void
-record_missing_image(typtyp, str)
-int typtyp;
-char *str;
+record_missing_image(int typtyp, char *str)
 {
     if (missinglist == NULL) {
 	missinglist = xmalloc(BUFSIZE);
@@ -3240,12 +3174,11 @@ char *str;
     ++totlisted;
 }
 
-/* Return true if any images could not be found, and provide some helpful info
-   into the supplied buffer. */
+/* Return true if any images could not be found, and provide some
+   helpful info into the supplied buffer. */
 
 int
-missing_images(buf)
-char *buf;
+missing_images(char *buf)
 {
     if (missinglist == NULL)
       return FALSE;
@@ -3259,4 +3192,3 @@ char *buf;
     tprintf(buf, " - %s", missinglist);
     return TRUE;
 }
-
