@@ -216,8 +216,10 @@ execute_plan(Unit *unit)
     }
     DMprintf("%s using plan %s\n", unit_desig(unit), plan_desig(plan));
     /* Units that are asleep or in reserve do nothing. */
-    if (plan->asleep || plan->reserve)
+    /* (This never happens according to debugging). */
+    if (plan->asleep || plan->reserve) {
       return 0;
+    }
     if (plan->execs_this_turn > 1000 && g_units_may_go_into_reserve()) {
 	DMprintf("%s executed plan 1000 times this turn, going into reserve\n",
 		 unit_desig(unit));
@@ -397,6 +399,12 @@ plan_passive(Unit *unit)
 {
     Plan *plan = unit->plan;
 
+    /* Don't allow passive units under ai control. */
+    if (side_has_ai(unit->side) && unit->plan->aicontrol) {
+    	force_replan(unit->side, unit, FALSE);
+    	return;
+    }
+
     /* Special-case human cities in the intro game to automatically
        start producing infantry initially. */
     /* (would be more efficient to put in a once-per-turn location,
