@@ -1,5 +1,5 @@
 /* PostScript(tm) printing for Xconq.
-   Copyright (C) 1994, 1995 Massimo Campostrini & Stanley T. Shebs.
+   Copyright (C) 1994, 1995, 1999 Massimo Campostrini & Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -56,7 +56,7 @@ Piazza Torricelli 2, I56126 Pisa, Italy  ||  Phone: (+39)(50)911272
 Internet: campo@sunthpi3.difi.unipi.it   ||  Fax:   (+39)(50)48277  */
 
 #include "conq.h"
-extern int num_features PARAMS ((void));
+extern int num_features(void);
 #include "print.h"
 #include "imf.h"
 #include "ui.h"
@@ -247,23 +247,23 @@ static int conn_x[NUMDIRS], conn_y[NUMDIRS],
 
 /* Local functions. */
 
-static char *add_esc_string PARAMS ((char *str));
+static char *add_esc_string(char *str);
 
-static void ps_cook_imf PARAMS ((void));
-static void ps_initialize_imf PARAMS ((PsImage *psim));
-static char *ps_hex_dump PARAMS ((Obj *data, int w, int h));
-static char *img_untile PARAMS ((char *tiled, int w, int h, int istile,
-			 int dither, int scale, int gray));
-static void misc_init PARAMS ((void));
-static void ps_initialize PARAMS ((FILE *fp));
-static void page_init PARAMS ((FILE *fp, int page, int i, int j, char *stime));
-static int nearest_valid_x PARAMS ((int x, int y));
-static int sideno_of_seen_unit_at PARAMS ((int x, int y, Side *side));
-static char *name_of_seen_unit_at PARAMS ((int x, int y, Side *side));
-static char *summary_of_seen_units_at PARAMS ((int x, int y, Side *side));
-static int ps_string_width PARAMS ((char *str, int font));
-static int print_unit_legends PARAMS ((FILE *fp, char *name, char *summary, char *m,
-	int dir, int cx, int cy));
+static void ps_cook_imf(void);
+static void ps_initialize_imf(PsImage *psim);
+static char *ps_hex_dump(Obj *data, int w, int h);
+static char *img_untile(char *tiled, int w, int h, int istile,
+			int dither, int scale, int gray);
+static void misc_init(void);
+static void ps_initialize(FILE *fp);
+static void page_init(FILE *fp, int page, int i, int j, char *stime);
+static int nearest_valid_x(int x, int y);
+static int sideno_of_seen_unit_at(int x, int y, Side *side);
+static char *name_of_seen_unit_at(int x, int y, Side *side);
+static char *summary_of_seen_units_at(int x, int y, Side *side);
+static int ps_string_width(char *str, int font);
+static int print_unit_legends(FILE *fp, char *name, char *summary, char *m,
+			      int dir, int cx, int cy);
 
 static void
 ps_cook_imf()
