@@ -13,20 +13,31 @@ any later version.  See the file COPYING.  */
 #include "kpublic.h"
 #include "ai.h"
 
-extern TaskOutcome execute_task_aux PARAMS ((Unit *unit, Task *task));
+/* This is for storing basic stuff about the most recently executed action. */
+typedef struct a_action_record {
+	Unit *actor;			/* Pointer to the actor if it still exists. */
+	short x, y, z;			/* Actor's location at the time of action. */
+	ActionType type;			/* Type of action. */
+	HistEventType result;		/* Its result. */		
+} ActionRecord;
+
+static ActionRecord *latest_action = NULL;
+
+extern TaskOutcome execute_task_aux(Unit *unit, Task *task);
 
 /* Functions in run2.c, only called from this file. */
 
-extern void run_turn_start PARAMS ((void));
-extern void run_restored_turn_start PARAMS ((void));
-extern void run_turn_end PARAMS ((void));
-static void compose_actionvectors PARAMS ((void));
-static void init_movement PARAMS ((void));
-static int move_some_units PARAMS ((int lim));
-static int side_move_some_units PARAMS ((Side *side, int lim));
-static int unit_still_acting PARAMS ((Unit *unit));
-static int unit_still_acting_no_plan PARAMS ((Unit *unit));
-static int move_one_unit_multiple PARAMS ((Unit *unit, int lim));
+extern void run_turn_start(void);
+extern void run_restored_turn_start(void);
+extern void run_turn_end(void);
+static void compose_actionvectors(void);
+static void init_movement(void);
+static int move_some_units(int lim);
+static int side_move_some_units(Side *side, int lim);
+static int unit_still_acting(Unit *unit);
+static int unit_still_acting_no_plan(Unit *unit);
+static int move_one_unit_multiple(Unit *unit, int lim);
+static int action_reaction_needed(int type, int rslt);
 
 /* Priority of sides that are now moving. */
 
@@ -125,6 +136,8 @@ int need_ai_planning;
 
 int need_ai_task_reaction;
 
+int need_ai_action_reaction;
+
 int need_ai_for_new_side;
 
 int need_ai_finish_movement;
@@ -195,6 +208,9 @@ int maxactions;
     time(&rungamestart);
     numacted = numother = planexecs = taskexecs = 0;
     need_ai_planning = FALSE;
+	/* Make sure the action record is allocated. */
+    if (latest_action == NULL)
+       latest_action = (ActionRecord *) xmalloc(sizeof(ActionRecord));
     if (beforestart) {
 	/* If we haven't started yet, see if it's time. */
 	test_for_game_start();
@@ -808,8 +824,23 @@ int lim;
 	  Dprintf("  Moving %s (%d/%d, buzz %d) with plan %s\n",
 		  unit_desig(unit), num, lim, buzz, plan_desig(unit->plan));
 	if (has_pending_action(unit)) {
+
+	    /* Save this info now in case the actor dies etc. */
+	    latest_action->type = unit->act->nextaction.type;
+	    latest_action->actor = unit;
+	    latest_action->x = unit->x;
+	    latest_action->y = unit->y;
+	    latest_action->z = unit->z;
+
 	    /* Execute the action directly. */
 	    rslt = execute_action(unit, &(unit->act->nextaction));
+	    
+	    /* Save the result. */
+	    latest_action->result = rslt;
+	   	    
+	    /* Trigger ai reaction for certain actions. */ 
+	    need_ai_action_reaction = action_reaction_needed(latest_action->type, rslt);
+
 	    /* Clear the action.  Note that the unit might have changed
 	       to a non-acting type, so we have to check for act struct. */
 	    if (unit->act)
@@ -873,6 +904,38 @@ int lim;
     return num;
 }
 
+/* Returns true if ais may need to react on a given action and result. */
+	    
+int
+action_reaction_needed(int type, int rslt)
+{
+	/* Special success flags for captures, overruns and builds that
+	just completed a unit. */
+	if (rslt == A_CAPTURE_SUCCEEDED
+	     || rslt == A_OVERRUN_SUCCEEDED
+	     || rslt == A_BUILD_COMPLETED) {
+		return TRUE;
+	/* Any other action returns A_ANY_DONE on success. */
+	} else if (rslt == A_ANY_DONE
+	/* These actions may change the tactical situation. */
+	    && ((type == ACTION_MOVE
+	           || type == ACTION_ENTER
+	           || type == ACTION_DISBAND
+	           || type == ACTION_CHANGE_TYPE
+	           || type == ACTION_CHANGE_SIDE)
+	        /* Also worry about offensive actions that kill or capture a 
+	        unit. */
+	        ||((type == ACTION_ATTACK
+	           || type == ACTION_FIRE_AT
+	           || type == ACTION_FIRE_INTO
+	           || type == ACTION_DETONATE)
+	        	     && (history->prev->type == H_UNIT_KILLED
+	        	     	|| history->prev->type == H_UNIT_CAPTURED)))) {
+		return TRUE;
+	}
+	return FALSE;
+}
+
 /* This explicitly finishes out a side's activity for the turn. */
 
 void
@@ -918,7 +981,7 @@ Side *side;
     Dprintf("%s finished its turn.\n", side_desig(side));
 }
 
-void run_ai_plan_adjust PARAMS ((Side *side));
+void run_ai_plan_adjust(Side *side);
 
 /* (should decide on useful return value and use, or make void) */
 
@@ -946,6 +1009,15 @@ int when, maxplanning;
 	}
 	need_ai_for_new_side = FALSE;
     }
+
+    /* This code does the following:
+    1) Analyzes the game.
+    2) Reviews goals, theaters and units.
+    3) Runs ai_finish_movement again. Why?
+    4) Updates strategy and unit plans.
+    
+    Executed at the start of each turn. */
+
     if (need_ai_init_turn) {
 	for_all_sides(side) {
 	    if (side_has_ai(side))
@@ -953,6 +1025,12 @@ int when, maxplanning;
 	}
 	need_ai_init_turn = FALSE;
     }
+    
+    /* This code finds a new plan for any unit with a passive plan.
+    
+    Executed after each plan execution, during forced replanning
+    and at the start of each turn. */
+
     if (need_ai_planning) {
 	for_all_sides(side) {
 	    if (side_has_ai(side) /* (should) and need planning for this side*/) {
@@ -962,21 +1040,19 @@ int when, maxplanning;
 			&& unit->plan->aicontrol
 			&& !unit->plan->asleep) {
 			ai_decide_plan(side, unit);
-#if 0 /* comment out until this is figured out */
-			/* ...was in execute_plan - not ideal location, but
-			   needs to be in this function somewhere... */
-			/* Always reevaluate the plan before executing it! */
-			ai_update_plan(side, unit);
-			/* Deal with tactical emergencies such as
-			   enemy units that suddenly appear nearby. */
-			ai_handle_emergency(side, unit);
-#endif
 		    }
 		}
 	    }
 	}
 	need_ai_planning = FALSE;
     }
+    
+    /* This code does two things:
+    1) Reacts to failed move tasks as approprite.
+    2) Reacts to failed resupply tasks by trying to build a depot.
+    
+    Executed after each task execution. */
+
     if (need_ai_task_reaction) {
 	for_all_sides(side) {
 	    if (side_has_ai(side)) {
@@ -994,6 +1070,38 @@ int when, maxplanning;
 	}
 	need_ai_task_reaction = FALSE;
     }
+
+    /* This code does two things:
+    1) Reevaluates the defense of cities and assigns or releases defenders.
+    2) Sets (not pushes) hit tasks etc. for enemy units that appear nearby.
+    
+    Executed after certain actions. */
+
+    if (need_ai_action_reaction) {
+	for_all_sides(side) {
+	    if (side_has_ai(side)) {
+		for_all_side_units(side, unit) {
+		    if (is_active(unit)
+			&& unit->plan
+			&& unit->plan->aicontrol
+			&& distance(unit->x, unit->y, 
+					   latest_action->x, latest_action->y)
+				       <= u_ai_tactical_range(unit->type)) {
+			ai_react_to_action_result(side, unit, TRUE);
+		    }
+		}
+	    }
+	}
+	need_ai_action_reaction = FALSE;
+    }
+
+    /* This code does three things:
+    1) Sets build tasks for stationary units with zero or non-build tasks.
+    2) Forces units that are waiting for tasks to replan.
+    3) Forces units with too many plan execs this turn into reserve.
+    
+    Executed each round. */ 
+
     if (1) {
 	for_all_sides(side) {
 	    if (side_has_ai(side) && !side->finishedturn) {
@@ -1001,6 +1109,17 @@ int when, maxplanning;
 	    }
 	}
     }
+    
+    /* This code does four things:
+    1) Organizes pickup of any units already known to need transport.
+    2) Checks if any other units need transport (rethink_plan).
+    3) Pushes a hit task for offensive units with move tasks if an enemy 
+    	appears nearby (rethink_plan).
+    4) Pushes a build task for capturer if a stationary unit sees a useful 
+    	capture nearby (rethink_plan).
+    
+    Executed at each end of turn. */
+
     if (need_ai_finish_movement) {
 	for_all_sides(side) {
 	    if (side_has_ai(side) && !side->finishedturn) {
@@ -1142,8 +1261,8 @@ extern void auto_pick_new_research(Unit *unit);
 
 extern void unit_plan_dialog(Unit *unit);
 extern void net_resume_build_task(Unit *unit, Unit *unit2, int run);
-extern int has_advance_to_research PARAMS ((Side *side, int a));
-extern int select_by_weight PARAMS ((int *arr, int numvals));
+extern int has_advance_to_research(Side *side, int a);
+extern int select_by_weight(int *arr, int numvals);
 extern int unit_build_dialog(Unit *unit);
 
 static void run_population(Unit *unit);
@@ -1197,10 +1316,12 @@ run_advanced_units()
 
 	/* Make sure the city's side can see everything in visible cells within its reach. */
 	for_all_cells_within_reach(unit, x, y) {
+		Side *sidex = (unit->side ? unit->side : indepside);
+
 	    if (!inside_area(x, y))
 		continue;
-	    if (terrain_visible(unit->side, x, y))
-		see_exact(unit->side, x, y);
+	    if (terrain_visible(sidex, x, y))
+		see_exact(sidex, x, y);
 	}
 	/* Break here if no material types exist. */
 	if (!nummtypes)
@@ -1324,7 +1445,8 @@ run_population(Unit *unit)
 	unit->size -=1;
 	/* Run warning. */
 	if (unit->size > 0) {
-	    notify(unit->side, "The people in %s are starving!", unit->name);			
+	    notify(unit->side, "The people in your %s %s are starving!", 
+	    				u_type_name(u), unit->name);			
 	} else {
 	    /* Kill the unit, but first return borrowed material to
                treasury. */
@@ -1337,7 +1459,8 @@ run_population(Unit *unit)
 		    unit->supply[m] = 0; 			
 		}
 	    }
-	    notify(unit->side, "%s is no more. The people starved to death.", unit->name);			
+	    notify(unit->side, "Your %s %s is no more. The people starved to death.", 
+	    				u_type_name(u), unit->name);			
 	    kill_unit(unit, H_UNIT_STARVED);
 	}
 	/* Done with handling starvation. */
@@ -1352,8 +1475,8 @@ run_population(Unit *unit)
     for_all_advance_types(a) {
 	if ((unit->side == NULL || unit->side->advance[a] != DONE) 
 	    && ua_size_limit_without_adv(u, a) <= unit->size) {
-	    notify(unit->side, "%s needs %s advance to grow in size.", 
-		   unit->name, a_type_name(a));			
+	    notify(unit->side, "Your %s %s needs %s advance to grow in size.", 
+		   			u_type_name(u), unit->name, a_type_name(a));			
 	    return;
 	}
     }
@@ -1370,8 +1493,8 @@ run_population(Unit *unit)
 		}
 	    }
 	    if (!hasocc) {
-		notify(unit->side, "%s needs %s unit to grow in size.", 
-		       unit->name, u_type_name(u2));			
+		notify(unit->side, "Your %s %s needs a %s to grow in size.", 
+		       			   u_type_name(u), unit->name, u_type_name(u2));			
 		return;
 	    }
 	}
@@ -1382,6 +1505,9 @@ run_population(Unit *unit)
       unit->supply[m] -= unit->size * um_consumption_to_grow(u, m);
     /* Then increase the size. */
     unit->size += 1;
+    /* And bragg about it. */
+    notify(unit->side, "Your %s %s prospers and reaches size %d.", 
+		   		u_type_name(u), unit->name, unit->size);			
 }
 
 void
@@ -1566,6 +1692,9 @@ run_research(Unit *unit)
 
 	    /* Set current advance to done. */
 	    unit->side->advance[a] = DONE;
+	    /* Notify the units side about it. */
+	    notify(unit->side, "Your wise men in %s discover %s!",
+				        unit->name, a_type_name(a));
 	    /* Pick new research for all involved units. */
 	    if (side_has_display(unit->side) && ! side_has_ai(unit->side)) {
 		int idle = FALSE;
@@ -1671,6 +1800,8 @@ allocate_used_cells(Unit *unit)
 	int tmpy = unit->y;
 
 	for_all_cells_within_reach(unit, x, y) {
+		Side *sidex = (unit->side ? unit->side : indepside);
+
 	    /* Skip if not inside area */
 	    if (!inside_area(x, y))
 	      continue;
@@ -1678,13 +1809,13 @@ allocate_used_cells(Unit *unit)
 	    if (user_at(x, y) != NOUSER)
 	      continue;
 	    /* Skip if cell is invisible to unit */
-	    if (!terrain_visible(unit->side, x, y))
+	    if (!terrain_visible(sidex, x, y))
 	      continue;
 	    /* Skip if untrusted side has a unit in the cell */
 	    if (unit_at(x, y) != NULL) {
 		int enemy = FALSE;
 		for_all_stack(x, y, unit2) {
-		    if (!trusted_side(unit->side, unit2->side)) {
+		    if (!trusted_side(sidex, unit2->side)) {
 			enemy = TRUE;
 			break;
 		    }
@@ -1816,7 +1947,9 @@ auto_pick_new_build_task(Unit *unit)
 	if (u_advanced(unit2->type)
 	    && distance(unit->x, unit->y, unit2->x, unit2->y)
 	    >= u_ai_tactical_range(unit->type)
-	    && enemy_side(unit->side, unit2->side)) {
+	    && enemy_side(unit->side, unit2->side)
+	    /* Only count citites that we can actually see. */
+	    && unit_actually_visible(unit->side, unit2)) {
 	    enemy_city_near = TRUE;
 	    break;
 	}
@@ -1922,14 +2055,14 @@ auto_pick_new_plan(Unit *unit)
     for_all_occs_with_occs(unit, unit2) {
 	if (u_facility(unit2->type))
 	  facilities += 1;
-	if (in_play(unit2)
+	if (is_active(unit2)
 	    && occ_can_defend_transport(unit2->type, unit->type)) 
 	  defenders += 1;
 	if (mobile(unit2->type))
 	  mobiles += 1;
     }		
-    /* Always build a defender first if we are undefended. */
-    if (defenders < u_ai_min_defenders(unit->type)) {
+    /* Always build defenders if we are undefended. */
+    if (!defended_by_occupants(unit)) {
 	set_unit_plan_type(unit->side, unit, PLAN_DEFENSIVE);
 	return;
     }	
@@ -1937,34 +2070,36 @@ auto_pick_new_plan(Unit *unit)
     /* Check out the tactical neighbourhood. */
     for_all_cells_within_range(unit->x, unit->y, 
 				 u_ai_tactical_range(unit->type), x, y) {
-	if (!inside_area(x, y))
-	  continue;
-	if (!terrain_visible(unit->side, x, y))
-	  invisible_cells +=1;
-	unit2 = NULL;
-	/* Important to count also occupants here. */
-	for_all_stack_with_occs(x, y, unit2) {
-	    /* Only count real units. */
-	    if (!in_play(unit2))
-	      continue;
-	    /* Only count units that we can see. */
-	    if (!unit_actually_visible(unit->side, unit2))
-	      continue;
-	    u2 = unit2->type;
-	    /* First count own units. */
-	    if (unit->side == unit2->side) {
-		if (u_advanced(u2))
-		  my_advanced += 1;
-		else if (u_colonizer_worth(u2))
-		  my_colonizers += 1;
-		my_total += 1;
-		/* Then count hostile units. */
-	    } else if (enemy_side(unit->side, unit2->side)){
-		if (u_advanced(u2))
-		  enemy_advanced += 1;
-		else if (u_colonizer_worth(u2))
-		  enemy_colonizers += 1;
-		enemy_total += 1;
+		Side *sidex = (unit->side ? unit->side : indepside);
+
+		if (!inside_area(x, y))
+		  continue;
+		if (!terrain_visible(sidex, x, y))
+		  invisible_cells +=1;
+		unit2 = NULL;
+		/* Important to count also occupants here. */
+		for_all_stack_with_occs(x, y, unit2) {
+		    /* Only count real units. */
+		    if (!is_active(unit2))
+		      continue;
+		    /* Only count units that we can see. */
+		    if (!unit_actually_visible(sidex, unit2))
+		      continue;
+		    u2 = unit2->type;
+		    /* First count own units. */
+		    if (sidex == unit2->side) {
+			if (u_advanced(u2))
+			  my_advanced += 1;
+			else if (u_colonizer_worth(u2))
+			  my_colonizers += 1;
+			my_total += 1;
+			/* Then count hostile units. */
+		    } else if (enemy_side(sidex, unit2->side)){
+			if (u_advanced(u2))
+			  enemy_advanced += 1;
+			else if (u_colonizer_worth(u2))
+			  enemy_colonizers += 1;
+			enemy_total += 1;
 	    }			
 	}
     }
