@@ -267,7 +267,7 @@ run_turn_start(void)
 /* Do computations to start the first turn of a restored game. */
 
 void
-run_restored_turn_start()
+run_restored_turn_start(void)
 {
     Side *side;
 
@@ -288,7 +288,7 @@ run_restored_turn_start()
 /* Do everything associated with the end of a turn. */
 
 void
-run_turn_end()
+run_turn_end(void)
 {
     update_all_progress_displays("turn end calcs", -1);
     finish_movement();
@@ -321,8 +321,7 @@ run_turn_end()
    risk confusing list traversals or AI calculations. */
 
 void
-request_additional_side(playerspec)
-char *playerspec;
+request_additional_side(char *playerspec)
 {
     if (numsides + new_sides_requested + 1 <= g_sides_max()) {
 	if (players_requested == NULL)
@@ -341,7 +340,7 @@ char *playerspec;
 /* Add the requested number of new sides into an ongoing game. */
 
 static void
-add_new_sides_to_game()
+add_new_sides_to_game(void)
 {
     int i;
     Side *side, *side2;
@@ -390,12 +389,15 @@ add_new_sides_to_game()
 	    for_all_side_units(side, unit) {
 		count_gain(side, unit->type, initial_gain);
 	    }
-	    /* Maybe record that we need to create an AI for the new side later. */
+	    /* Maybe record that we need to create an AI for the new
+               side later. */
 	    if (side_wants_ai(side)) {
 		need_ai_for_new_side = TRUE;
 	    }
 	    for_all_sides(side2) {
-		/* Give all other AIs a chance to rework internal data structures. */
+		/* Give all other AIs a chance to rework internal data
+                   structures. */
+		/* (should move to run_local_ai?) */
 		if (side_has_ai(side2) && side2 != side) {
 		    ai_react_to_new_side(side2, side);
 		}
@@ -427,9 +429,7 @@ add_new_sides_to_game()
    input string spec may be modified in place. */
 /* (should move to side.c?) */
 void
-parse_player_spec(player, spec)
-Player *player;
-char *spec;
+parse_player_spec(Player *player, char *spec)
 {
     int commapos, slashpos, atpos, pluspos;
 
@@ -474,7 +474,7 @@ char *spec;
 /* Compute the leakage of technology from one side to another. */
 
 static void
-run_tech_leakage()
+run_tech_leakage(void)
 {
     int u;
     Side *side, *side2;
@@ -511,7 +511,7 @@ run_tech_leakage()
    fast if the player has lots of units doing development. */
 
 static void
-cache_init_tech_levels()
+cache_init_tech_levels(void)
 {
     int u;
     Side *side;
@@ -528,7 +528,7 @@ cache_init_tech_levels()
 /* Reduce some units' construction tooling randomly. */
 
 static void
-run_tooling_attrition()
+run_tooling_attrition(void)
 {
     int u, u2, att;
     Unit *unit;
@@ -566,7 +566,7 @@ run_tooling_attrition()
 /* Reduce some incomplete units' cp. */
 
 static void
-run_cp_attrition()
+run_cp_attrition(void)
 {
     int u, att;
     Unit *unit;
@@ -598,8 +598,10 @@ run_cp_attrition()
     }
 }
 
+/* At the beginning of a turn, there are no units in reserve. */
+
 static void
-reset_all_reserves()
+reset_all_reserves(void)
 {
     Unit *unit;
 
@@ -614,7 +616,7 @@ reset_all_reserves()
    can do anything into a list. */
 
 static void
-compute_moves()
+compute_moves(void)
 {
     int curturn = g_turn();
     Unit *unit;
@@ -635,16 +637,21 @@ compute_moves()
 
 		/* Advanced unit support. */
 
-/* This keeps the option of letting advanced units do the standard acp calculation
-followed by action(s) in the action loop, in addition to the building and research 
-they do during run_advanced_units. However, disable_standard_acp should be set 
-to TRUE for advanced units in order to avoid a number of complications. Setting it
-to FALSE will in effect let advanced units act twice each turn, once in advanced
-mode and once in the standard mode. */
+		/* This keeps the option of letting advanced units do
+		   the standard acp calculation followed by action(s)
+		   in the action loop, in addition to the building and
+		   research they do during
+		   run_advanced_units. However, disable_standard_acp
+		   should be set to TRUE for advanced units in order
+		   to avoid a number of complications. Setting it to
+		   FALSE will in effect let advanced units act twice
+		   each turn, once in advanced mode and once in the
+		   standard mode. */
 
 		if (u_disable_standard_acp(unit->type))
-			unit->act->initacp = unit->act->acp = 0;
-		else   compute_acp(unit);
+		  unit->act->initacp = unit->act->acp = 0;
+		else
+		  compute_acp(unit);
 
 		update_unit_acp_display(side, unit, FALSE);
 	    }
@@ -655,10 +662,10 @@ mode and once in the standard mode. */
 /* Compute the action points available to the unit this turn. */
 
 void
-compute_acp(unit)
-Unit *unit;
+compute_acp(Unit *unit)
 {
-    int u = unit->type, t, acp, mor, moreff, temp, tempeff, maxacp, minacp, err;
+    int u = unit->type, t, acp, mor, moreff, temp, tempeff;
+    int maxacp, minacp, err;
     Unit *occ;
 
     /* Units still under construction or off-area can't do anything. */
@@ -727,18 +734,17 @@ Unit *unit;
     unit->act->actualmoves = 0;
 }
 
-/* Compute and return the acp of a damaged unit, using a list of (hp acp) pairs
-   and interpolating between them. */
+/* Compute and return the acp of a damaged unit, using a list of (hp
+   acp) pairs and interpolating between them. */
 
 int
-damaged_acp(unit, effect)
-Unit *unit;
-Obj *effect;
+damaged_acp(Unit *unit, Obj *effect)
 {
     int u, err, rslt;
 
     u = unit->type;
-    err = interpolate_in_list_ext(unit->hp, effect, 0, 0, 0, 0, u_hp(u), u_acp(u), &rslt);
+    err = interpolate_in_list_ext(unit->hp, effect, 0, 0, 0, 0, u_hp(u),
+				  u_acp(u), &rslt);
     if (err != 0) {
 	run_warning("cannot get damaged acp for %s at hp %d, using %d",
 		    u_type_name(u), u_acp(u));
@@ -747,8 +753,10 @@ Obj *effect;
     return rslt;
 }
 
+/* Compute the numeric "year part" and the textual "season name". */
+
 static void
-compute_season()
+compute_season(void)
 {
     Obj *names, *rest, *elt;
 
@@ -758,12 +766,14 @@ compute_season()
 	/* Determine the name of the season, if defined. */
 	names = g_season_names();
 	if (names != NULL && names != lispnil && consp(names)) {
-	    for (rest = names; rest != lispnil; rest = cdr(rest)) {
+	    for_all_list(names, rest) {
 		elt = car(rest);
 		if (consp(elt)
 		    && numberp(car(elt))
 		    && numberp(cadr(elt))
-		    && between(c_number(car(elt)), curyearpart, c_number(cadr(elt)))
+		    && between(c_number(car(elt)),
+			       curyearpart,
+			       c_number(cadr(elt)))
 		    && stringp(car(cddr(elt))))
 		  curseasonname = c_string(car(cddr(elt)));
 	    }
@@ -781,8 +791,7 @@ compute_season()
 }
 
 static int
-season_effect(u)
-int u;
+season_effect(int u)
 {
     int err, rslt;
 
@@ -798,7 +807,7 @@ int u;
 /* See how any agreements' terms are holding up. */
 
 static void
-test_agreements()
+test_agreements(void)
 {
     Agreement *ag;
 
@@ -809,10 +818,10 @@ test_agreements()
     }
 }
 
-/* Compute sun-related data. */
+/* Compute lighting-related data. */
 
 static void
-compute_sun()
+compute_sun(void)
 {
     int curtime, highest;
 
@@ -856,6 +865,7 @@ compute_sun()
 	Dprintf("Sun is now at %d,%d\n", sunx, suny);
     }
 }
+
 /* Compute the position of the sun for this turn. */
 
 static void
@@ -1736,7 +1746,13 @@ int x, y;
     }
     for_all_stack(x, y, unit2) {
 	if (in_play(unit2) && unit2->side == tmpunit->side) {
-	    for_all_occupants(unit2, occ) {
+
+    	/* Bug fix. Units inside a transport inside a base or city were
+    	previously unable to resupply directly from the base. Using 
+    	for_all_occs_with_occs instead of for_all_occupants here 
+    	enables such resupply. */
+    	
+	    for_all_occs_with_occs(unit2, occ) {
 		if (in_play(occ) && occ->side == tmpunit->side) {
 		    try_transfer(tmpunit, occ, tmpmtype);
 		}
@@ -1758,7 +1774,10 @@ int x, y;
     }
     for_all_stack(x, y, unit2) {
 	if (in_play(unit2) && unit2->side == tmpunit->side) {
-	    for_all_occupants(unit2, occ) {
+
+    	/* Bug fix (same as above). */
+    	
+	    for_all_occs_with_occs(unit2, occ) {
 		if (in_play(occ) && occ->side == tmpunit->side) {
 		    try_sharing_need(occ, tmpunit, tmpmtype);
 		}
@@ -2614,8 +2633,15 @@ run_auto_repair()
 		if (auto_repair_range_max[u] < 0) {
 		    if (unit->transport && uu_auto_repair(unit->transport->type, u) > 0) {
 			auto_repair_unit(unit->transport, unit);
+		    /* If unit is inside a transport inside a base, also let the base 
+		    repair the unit. */
+		    } else if (unit->transport
+		    	    && unit->transport->transport
+		    	    && uu_auto_repair(unit->transport->transport->type, u) > 0) {
+			auto_repair_unit(unit->transport->transport, unit);
 		    } else {
-			for_all_occupants(unit, occ) {
+			/* Also let units within transports repair a base if the can. */
+			for_all_occs_with_occs(unit, occ) {
 			    if (is_active(occ) && uu_auto_repair(occ->type, u) > 0) {
 				auto_repair_unit(occ, unit);
 			    }
