@@ -18,14 +18,14 @@ any later version.  See the file COPYING.  */
    100, or 100 more than another player, or whatever.  */
 
 #include "conq.h"
-extern char *escaped_symbol PARAMS ((char *str));
-extern char *escaped_string PARAMS ((char *str));
+extern char *escaped_symbol(char *str);
+extern char *escaped_string(char *str);
 #include "kernel.h"
 
-char *basic_player_name PARAMS ((Player *player));
-int read_scorefile PARAMS ((void));
-int interp_score_record PARAMS ((Obj *form));
-char *get_scores PARAMS ((Side *side));
+char *basic_player_name(Player *player);
+int read_scorefile(void);
+int interp_score_record(Obj *form);
+char *get_scores(Side *side);
 
 typedef struct a_score_record {
     char *gamename;
@@ -47,8 +47,9 @@ typedef struct a_score_record {
 #define for_all_score_records(sr)  \
   for ((sr) = records; (sr) != NULL; (sr) = (sr)->next)
 
-static void eval_sk_last_side_wins PARAMS ((Scorekeeper *sk));
-static void eval_sk_last_alliance_wins PARAMS ((Scorekeeper *sk));
+static void eval_sk_last_side_wins(Scorekeeper *sk);
+static void eval_sk_last_alliance_wins(Scorekeeper *sk);
+static void score_variant_desc(ScoreRecord *sr, char *varbuf);
 
 /* The head of the list of scorekeepers. */
 
@@ -98,7 +99,7 @@ ScoreRecord *records;
 /* Clear out any possible scorekeepers. */
 
 void
-init_scorekeepers()
+init_scorekeepers(void)
 {
     scorekeepers = last_scorekeeper = NULL;
     numscorekeepers = 0;
@@ -111,7 +112,7 @@ init_scorekeepers()
 }
 
 Scorekeeper *
-create_scorekeeper()
+create_scorekeeper(void)
 {
     Scorekeeper *sk = (Scorekeeper *) xmalloc(sizeof(Scorekeeper));
 
@@ -142,8 +143,7 @@ create_scorekeeper()
 }
 
 Scorekeeper *
-find_scorekeeper(id)
-int id;
+find_scorekeeper(int id)
 {
     Scorekeeper *sk;
 
@@ -158,7 +158,7 @@ int id;
    must happen after all scorekeepers have been defined. */
 
 void
-init_scores()
+init_scores(void)
 {
     int score;
     Side *side;
@@ -232,7 +232,7 @@ init_scores()
    side moves anything. */
 
 void
-check_pre_turn_scores()
+check_pre_turn_scores(void)
 {
     Side *side;
     Scorekeeper *sk;
@@ -256,7 +256,7 @@ check_pre_turn_scores()
 /* Test all the scorekeepers that should be run only at the end of a turn. */
 
 void
-check_post_turn_scores()
+check_post_turn_scores(void)
 {
     Side *side;
     Scorekeeper *sk;
@@ -289,7 +289,7 @@ check_post_turn_scores()
 }
 
 void
-check_post_action_scores()
+check_post_action_scores(void)
 {
     Side *side;
     Scorekeeper *sk;
@@ -314,7 +314,7 @@ check_post_action_scores()
 }
 
 void
-check_post_event_scores()
+check_post_event_scores(void)
 {
     Side *side;
     Scorekeeper *sk;
@@ -342,18 +342,13 @@ check_post_event_scores()
    on the given side.  This can be expensive to run. */
 
 void
-run_scorekeeper(side, sk)
-Side *side;
-Scorekeeper *sk;
+run_scorekeeper(Side *side, Scorekeeper *sk)
 {
     eval_sk_form(side, sk, sk->body);
 }
 
 int
-eval_sk_form(side, sk, form)
-Side *side;
-Scorekeeper *sk;
-Obj *form;
+eval_sk_form(Side *side, Scorekeeper *sk, Obj *form)
 {
     int val;
     char *formtype;
@@ -447,9 +442,7 @@ Obj *form;
 }
 
 int
-sum_property(side, form)
-Side *side;
-Obj *form;
+sum_property(Side *side, Obj *form)
 {
     int sum = 0, u, typevec[MAXUTYPES];
     Obj *sidelist = lispnil, *typelist = lispnil, *prop = lispnil;
@@ -493,8 +486,7 @@ Obj *form;
 /* Return the point value of a particular unit. */
 
 int
-point_value(unit)
-Unit *unit;
+point_value(Unit *unit)
 {
     /* Incomplete units are always worthless. */
     if (unit->cp > 0 && !completed(unit))
@@ -507,8 +499,7 @@ Unit *unit;
 /* Return the sum of a side's units' point values. */
 
 int
-side_point_value(side)
-Side *side;
+side_point_value(Side *side)
 {
     Unit *unit;
 
@@ -530,10 +521,7 @@ Side *side;
 /* Evaluate a given form with respect to the given scorekeeper and side. */
 
 int
-eval_sk_test(side, sk, form)
-Side *side;
-Scorekeeper *sk;
-Obj *form;
+eval_sk_test(Side *side, Scorekeeper *sk, Obj *form)
 {
     char *formtype;
     Obj *arg1 = lispnil, *arg2 = lispnil, *rest;
@@ -588,8 +576,7 @@ Obj *form;
 }
 
 static void
-eval_sk_last_side_wins(sk)
-Scorekeeper *sk;
+eval_sk_last_side_wins(Scorekeeper *sk)
 {
     Side *side2, *winner = NULL;
     int numleft = 0, points;
@@ -616,8 +603,7 @@ Scorekeeper *sk;
 }
 
 static void
-eval_sk_last_alliance_wins(sk)
-Scorekeeper *sk;
+eval_sk_last_alliance_wins(Scorekeeper *sk)
 {
     Side *side2, *side3, *winner = NULL;
     int numleft = 0, sidepoints[MAXSIDES+1], alliancepoints[MAXSIDES+1];
@@ -681,9 +667,7 @@ Scorekeeper *sk;
 /* Implement the effects of a side winning. */
 
 void
-side_wins(side, why)
-Side *side;
-int why;
+side_wins(Side *side, int why)
 {
     /* Nothing happens to the side's units or people. */
     side->status = 1;
@@ -696,9 +680,7 @@ int why;
 /* Implement the effects of a side losing. */
 
 void
-side_loses(side, side2, why)
-Side *side, *side2;
-int why;
+side_loses(Side *side, Side *side2, int why)
 {
     int x, y, s, s2, ux, uy, changed;
     Unit *unit;
@@ -787,7 +769,7 @@ int why;
    applies to all sides currently in the game. */
 
 void
-all_sides_draw()
+all_sides_draw(void)
 {
     SideMask drew;
     Side *side;
@@ -812,8 +794,7 @@ all_sides_draw()
 /* Record the outcome of the game into the scorefile. */
 
 char *
-basic_player_name(player)
-Player *player;
+basic_player_name(Player *player)
 {
     char *playername;
 
@@ -830,7 +811,7 @@ Player *player;
 }
 
 void
-record_into_scorefile()
+record_into_scorefile(void)
 {
     int i;
     int any_advantage_variation = FALSE, adv, adv2, advantage;
@@ -951,7 +932,7 @@ record_into_scorefile()
 }
 
 int
-read_scorefile()
+read_scorefile(void)
 {
     int startlineno = 1, endlineno = 1;
     int numrecs;
@@ -983,8 +964,7 @@ read_scorefile()
 }
 
 int
-interp_score_record(form)
-Obj *form;
+interp_score_record(Obj *form)
 {
     char *propname;
     Obj *props, *prop;
@@ -1028,11 +1008,8 @@ Obj *form;
     return FALSE;
 }
 
-static void score_variant_desc PARAMS ((ScoreRecord *sr, char *varbuf));
-
 char *
-get_scores(side)
-Side *side;
+get_scores(Side *side)
 {
     int wins, losses, draws, plays, allplays;
     char *buf, sdadvbuf[20], varbuf[BUFSIZE];
@@ -1162,13 +1139,11 @@ Side *side;
     return buf;
 }
 
-/* Given a score record, report any variants that were specified and different from
-   the current module's defaults. */
+/* Given a score record, report any variants that were specified and
+   different from the current module's defaults. */
 
 static void
-score_variant_desc(sr, varbuf)
-ScoreRecord *sr;
-char *varbuf;
+score_variant_desc(ScoreRecord *sr, char *varbuf)
 {
     int i, hasdflt, dfltval, val;
     Obj *restvarset, *varset, *varsetname, *rslt;
@@ -1250,8 +1225,7 @@ char *varbuf;
    to win somehow, or if it can just goof off. */
 
 int
-should_try_to_win(side)
-Side *side;
+should_try_to_win(Side *side)
 {
     Scorekeeper *sk;
 
