@@ -2240,13 +2240,11 @@ all_see_cell(int x, int y)
     }
 }
 
-/* Look at the given position, possibly not seeing anything.  Return true if
-   a unit was spotted. */
+/* Look at the given position, possibly not seeing anything.  Return
+   true if a unit was spotted. */
 
 int
-see_cell(side, x, y)
-Side *side;
-int x, y;
+see_cell(Side *side, int x, int y)
 {
     int update, updatet, chance, t, curview, curuview, newuview, x1, y1;
     int m, mupdate, wupdate, seentype, mistakechance, flags;
@@ -2284,7 +2282,8 @@ int x, y;
    	curuview = unit_view(side, x, y);
    	seer = NULL;
    	for_all_stack(x, y, unit) {
-	    if (side_sees_unit(side, unit)) {
+	    if (side_sees_unit(side, unit)
+		|| u_see_always(unit->type)) {
 		unitseen = unit;
 		break;
 	    } else if (any_see_chances) {
@@ -2388,9 +2387,11 @@ int x, y;
     return (unitseen != NULL);
 }
 
+/* Given a unit type, return a similar-looking type that it might be
+   confused with. */
+
 static int
-mistaken_type(u2)
-int u2;
+mistaken_type(int u2)
 {
     int u3, totalweight, randval;
 
@@ -2415,23 +2416,22 @@ int u2;
    This is the lowest level of all viewing routines, and executed a lot. */
 
 void
-see_exact(side, x, y)
-Side *side;
-int x, y;
+see_exact(Side *side, int x, int y)
 {
-    register int olduview, oldtview, newtview, newuview, update, mupdate, wupdate;
-    register Unit *unit;
+    int olduview, oldtview, newtview, newuview, update, mupdate, wupdate;
+    Unit *unit;
 
     if (side == NULL || side == indepside || !in_area(x, y))
       return;
     if (all_see_all) {
-	/* It may not really be necessary to do anything to the display, but
-	   the kernel doesn't know if the interface is drawing all the units
-	   that are visible, or is only drawing "interesting" ones, or whatever.
-	   It would be up to the interface to decide that, say, its magnification
-	   power for a map is such that only one unit is being displayed, and
-	   that the update from here doesn't result in any visible changes to
-	   what's already been drawn on the screen. */
+	/* It may not really be necessary to do anything to the
+	   display, but the kernel doesn't know if the interface is
+	   drawing all the units that are visible, or is only drawing
+	   "interesting" ones, or whatever.  It would be up to the
+	   interface to decide that, say, its magnification power for
+	   a map is such that only one unit is being displayed, and
+	   that the update from here doesn't result in any visible
+	   changes to what's already been drawn on the screen. */
     	update = TRUE;
     } else {
 	update = FALSE;
@@ -2466,9 +2466,7 @@ int x, y;
 }
 
 static int
-see_materials(side, x, y)
-Side *side;
-int x, y;
+see_materials(Side *side, int x, int y)
 {
     int m, curview, update;
 
