@@ -142,24 +142,23 @@ typedef struct a_side {
     short realtimeout;		/* how long to wait before just going ahead */
     long startbeeptime;		/* after this time, beep to signal next turn */
     short *gaincounts;		/* array of counts of unit gains by the side */
-    short *losscounts;		/* array of counts of unit losses by the side */
+    short *losscounts;		/* array of counts of losses by the side */
     long **atkstats;		/* array of counts of attacks by units */
     long **hitstats;		/* array of damage done by unit attacks */
     /* Pointers to the other major structures of a side. */
     struct a_player *player;	/* pointer to data about the player */
     short playerid;		/* numeric id of the player */
     struct a_ui *ui;		/* pointer to all the user interface data */
-    Obj *uidata;		/* readable/writable form of user interface state */
-    short aitype;		/* type of AI making decisions */		
+    Obj *uidata;		/* read/write form of user interface state */
+    short aitype;		/* type of AI making decisions */
     struct a_ai *ai;		/* pointer to the AI making decisions */
     Obj *aidata;		/* readable/writable form of AI state */
-    int rid;			/* id of remote program that side is using */
-    struct a_rui *rui;
+    struct a_rui *rui;		/* pointer to interface data if remote */
     /* Misc working slots, never saved. */
     short startx, starty;	/* approx center of side's "country" */
     short busy;			/* true when side state not saveable */
     short finalradius;
-    short willingtosave;	/* will this side go along with saving the game? */
+    short willingtosave;	/* will this side go along with saving game? */
     short see_all;		/* true if this side sees everything */
     short may_set_see_all;	/* true if player can ask to see everything */
     short unit_view_restored;	/* true if unit view was read in */
@@ -167,7 +166,7 @@ typedef struct a_side {
     short designer;		/* true if side is doing scenario design */
 #endif /* DESIGNERS */
     /* Various caches, should be possible to recalc as needed. */
-    short *uavail;		/* vector of which types allowed on this side */
+    short *uavail;		/* vector of types allowed on this side */
     struct a_unit *unithead;	/* points to list of all units on this side */
     struct a_unitvector *actionvector;  /* vector of acting units */
     short numwaiting;		/* number of units waiting to get orders */
@@ -374,6 +373,8 @@ typedef struct a_side {
 
 #define side_has_display(s) (((s)->ui) != NULL || ((s)->rui) != NULL)
 
+#define side_has_local_display(side) ((side)->ui != NULL)
+
 #define side_has_ai(s) (((s)->ai) != NULL)
 
 #define side_lost(s) ((s) != NULL && !(s)->ingame && (s)->status < 0)
@@ -444,7 +445,7 @@ typedef struct a_agreement {
 
 enum {
     draft,                    /* agreement is circulating among drafters */
-    proposed,                 /* agreement is proposed to prospective signers */
+    proposed,                 /* agreement proposed to prospective signers */
     in_force,                 /* agreement is active */
     moribund                  /* agreement has expired */
 };
@@ -470,96 +471,100 @@ extern Agreement *last_agreement;
 
 /* Note: Can't use the "Unit" typedef below, must use "struct a_unit". */
 
-extern void init_sides PARAMS ((void));
-extern Side *create_side PARAMS ((void));
-extern void init_side_unithead PARAMS ((Side *side));
-extern int side_has_units PARAMS ((Side *side));
-extern void init_doctrine PARAMS ((Side *side));
-extern void init_self_unit PARAMS ((Side *side));
-extern int init_view PARAMS ((Side *side));
-extern void calc_start_xy PARAMS ((Side *side));
-extern char *side_name PARAMS ((Side *side));
-extern char *side_adjective PARAMS ((Side *side));
-extern int side_number PARAMS ((Side *side));
-extern Side *side_n PARAMS ((int n));
-extern Side *find_side_by_name PARAMS ((char *str));
-extern int side_controls_side PARAMS ((Side *side, Side *side2));
-extern int side_controls_unit PARAMS ((Side *side, struct a_unit *unit));
-extern int side_sees_unit PARAMS ((Side *side, struct a_unit *unit));
-extern int side_sees_image PARAMS ((Side *side, struct a_unit *unit));
-extern int num_units_in_play PARAMS ((Side *side, int u));
-extern int num_units_incomplete PARAMS ((Side *side, int u));
-extern struct a_unit *find_next_unit PARAMS ((Side *side, struct a_unit *prevunit));
-extern struct a_unit *find_prev_unit PARAMS ((Side *side, struct a_unit *nextunit));
-extern struct a_unit *find_next_actor PARAMS ((Side *side, struct a_unit *prevunit));
-extern struct a_unit *find_prev_actor PARAMS ((Side *side, struct a_unit *nextunit));
-extern struct a_unit *find_next_mover PARAMS ((Side *side, struct a_unit *prevunit));
-extern struct a_unit *find_prev_mover PARAMS ((Side *side, struct a_unit *nextunit));
-extern struct a_unit *find_next_awake_mover PARAMS ((Side *side, struct a_unit *prevunit));
-extern struct a_unit *find_prev_awake_mover PARAMS ((Side *side, struct a_unit *nextunit));
-extern int side_initacp PARAMS ((Side *side));
-extern int side_acp PARAMS ((Side *side));
-extern int side_acp_reserved PARAMS ((Side *side));
-extern int using_tech_levels PARAMS ((void));
-extern void remove_side_from_game PARAMS ((Side *side));
-extern int num_displayed_sides PARAMS ((void));
-extern int trusted_side PARAMS ((Side *side1, Side *side2));
-extern int enemy_side PARAMS ((Side *s1, Side *s2));
-extern int allied_side PARAMS ((Side *s1, Side *s2));
-extern int neutral_side PARAMS ((Side *s1, Side *s2));
-extern void reveal_side PARAMS ((Side *sender, Side *recipient, int *types));
-extern void receive_message PARAMS ((Side *side, Side *sender, char *str));
-extern void all_see_occupy PARAMS ((struct a_unit *unit, int x, int y, int inopen));
-extern void all_see_leave PARAMS ((struct a_unit *unit, int x, int y, int inopen));
-extern void cover_area PARAMS ((Side *side, struct a_unit *unit, struct a_unit *oldtransport, int x0, int y0, int x1, int y1));
-extern void reset_coverage PARAMS ((void));
-extern void calc_coverage PARAMS ((Side *side));
-extern void reset_all_views PARAMS ((void));
-extern void reset_view PARAMS ((Side *side));
-extern void react_to_seen_unit PARAMS ((Side *side, struct a_unit *unit, int x, int y));
-extern void all_see_cell PARAMS ((int x, int y));
-extern int see_cell PARAMS ((Side *side, int x, int y));
-extern void see_exact PARAMS ((Side *side, int x, int y));
-extern int seen_border PARAMS ((Side *side, int x, int y, int dir));
-extern void maybe_track PARAMS ((struct a_unit *unit));
-extern void maybe_lose_track PARAMS ((struct a_unit *unit, int nx, int ny));
-extern char *side_desig PARAMS ((Side *side));
+extern void init_sides(void);
+extern Side *create_side(void);
+extern void init_side_unithead(Side *side);
+extern int side_has_units(Side *side);
+extern void init_doctrine(Side *side);
+extern void init_self_unit(Side *side);
+extern int init_view(Side *side);
+extern void calc_start_xy(Side *side);
+extern char *side_name(Side *side);
+extern char *side_adjective(Side *side);
+extern int side_number(Side *side);
+extern Side *side_n(int n);
+extern Side *find_side_by_name(char *str);
+extern int side_controls_side(Side *side, Side *side2);
+extern int side_controls_unit(Side *side, struct a_unit *unit);
+extern int side_sees_unit(Side *side, struct a_unit *unit);
+extern int side_sees_image(Side *side, struct a_unit *unit);
+extern int num_units_in_play(Side *side, int u);
+extern int num_units_incomplete(Side *side, int u);
+extern struct a_unit *find_next_unit(Side *side, struct a_unit *prevunit);
+extern struct a_unit *find_prev_unit(Side *side, struct a_unit *nextunit);
+extern struct a_unit *find_next_actor(Side *side, struct a_unit *prevunit);
+extern struct a_unit *find_prev_actor(Side *side, struct a_unit *nextunit);
+extern struct a_unit *find_next_mover(Side *side, struct a_unit *prevunit);
+extern struct a_unit *find_prev_mover(Side *side, struct a_unit *nextunit);
+extern struct a_unit *find_next_awake_mover(Side *side,
+					    struct a_unit *prevunit);
+extern struct a_unit *find_prev_awake_mover(Side *side,
+					    struct a_unit *nextunit);
+extern int side_initacp(Side *side);
+extern int side_acp(Side *side);
+extern int side_acp_reserved(Side *side);
+extern int using_tech_levels(void);
+extern void remove_side_from_game(Side *side);
+extern int num_displayed_sides(void);
+extern int trusted_side(Side *side1, Side *side2);
+extern int enemy_side(Side *s1, Side *s2);
+extern int allied_side(Side *s1, Side *s2);
+extern int neutral_side(Side *s1, Side *s2);
+extern void reveal_side(Side *sender, Side *recipient, int *types);
+extern void receive_message(Side *side, Side *sender, char *str);
+extern void all_see_occupy(struct a_unit *unit, int x, int y, int inopen);
+extern void all_see_leave(struct a_unit *unit, int x, int y, int inopen);
+extern void cover_area(Side *side, struct a_unit *unit,
+		       struct a_unit *oldtransport, int x0, int y0,
+		       int x1, int y1);
+extern void reset_coverage(void);
+extern void calc_coverage(Side *side);
+extern void reset_all_views(void);
+extern void reset_view(Side *side);
+extern void react_to_seen_unit(Side *side, struct a_unit *unit, int x, int y);
+extern void all_see_cell(int x, int y);
+extern int see_cell(Side *side, int x, int y);
+extern void see_exact(Side *side, int x, int y);
+extern int seen_border(Side *side, int x, int y, int dir);
+extern void maybe_track(struct a_unit *unit);
+extern void maybe_lose_track(struct a_unit *unit, int nx, int ny);
+extern char *side_desig(Side *side);
 
-extern Side *parse_side_spec PARAMS ((char *str));
+extern Side *parse_side_spec(char *str);
 
-extern Doctrine *new_doctrine PARAMS ((int id));
-extern Doctrine *find_doctrine PARAMS ((int id));
-extern Doctrine *find_doctrine_by_name PARAMS ((char *name));
-extern Doctrine *clone_doctrine PARAMS ((Doctrine *doctrine));
-extern void set_doctrine PARAMS ((Side *side, char *spec));
+extern Doctrine *new_doctrine(int id);
+extern Doctrine *find_doctrine(int id);
+extern Doctrine *find_doctrine_by_name(char *name);
+extern Doctrine *clone_doctrine(Doctrine *doctrine);
+extern void set_doctrine(Side *side, char *spec);
 
-extern StandingOrder *new_standing_order PARAMS ((void));
-extern void add_standing_order PARAMS ((Side *side, StandingOrder *sorder, int pos));
-extern int parse_standing_order PARAMS ((Side *side, char *cmdstr));
-extern char *parse_unit_types PARAMS ((Side *side, char *str, char *utypevec));
-extern char *parse_order_cond PARAMS ((Side *side, char *str, StandingOrder *sorder));
-extern char *get_next_arg PARAMS ((char *str, char *buf, char **rsltp));
-extern char *standing_order_desc PARAMS ((StandingOrder *sorder, char *buf));
+extern StandingOrder *new_standing_order(void);
+extern void add_standing_order(Side *side, StandingOrder *sorder, int pos);
+extern int parse_standing_order(Side *side, char *cmdstr);
+extern char *parse_unit_types(Side *side, char *str, char *utypevec);
+extern char *parse_order_cond(Side *side, char *str, StandingOrder *sorder);
+extern char *get_next_arg(char *str, char *buf, char **rsltp);
+extern char *standing_order_desc(StandingOrder *sorder, char *buf);
 
-extern void init_agreements PARAMS ((void));
-extern Agreement *create_agreement PARAMS ((int id));
-extern char *agreement_desig PARAMS ((Agreement *ag));
+extern void init_agreements(void);
+extern Agreement *create_agreement(int id);
+extern char *agreement_desig(Agreement *ag);
 
-extern void fn_set_terrain_view PARAMS ((int x, int y, int val));
-extern void fn_set_aux_terrain_view PARAMS ((int x, int y, int val));
-extern void fn_set_terrain_view_date PARAMS ((int x, int y, int val));
-extern void fn_set_aux_terrain_view_date PARAMS ((int x, int y, int val));
-extern void fn_set_unit_view PARAMS ((int x, int y, int val));
-extern void fn_set_unit_view_date PARAMS ((int x, int y, int val));
-extern void fn_set_material_view PARAMS ((int x, int y, int val));
-extern void fn_set_material_view_date PARAMS ((int x, int y, int val));
-extern void fn_set_temp_view PARAMS ((int x, int y, int val));
-extern void fn_set_temp_view_date PARAMS ((int x, int y, int val));
-extern void fn_set_cloud_view PARAMS ((int x, int y, int val));
-extern void fn_set_cloud_bottom_view PARAMS ((int x, int y, int val));
-extern void fn_set_cloud_height_view PARAMS ((int x, int y, int val));
-extern void fn_set_cloud_view_date PARAMS ((int x, int y, int val));
-extern void fn_set_wind_view PARAMS ((int x, int y, int val));
-extern void fn_set_wind_view_date PARAMS ((int x, int y, int val));
+extern void fn_set_terrain_view(int x, int y, int val);
+extern void fn_set_aux_terrain_view(int x, int y, int val);
+extern void fn_set_terrain_view_date(int x, int y, int val);
+extern void fn_set_aux_terrain_view_date(int x, int y, int val);
+extern void fn_set_unit_view(int x, int y, int val);
+extern void fn_set_unit_view_date(int x, int y, int val);
+extern void fn_set_material_view(int x, int y, int val);
+extern void fn_set_material_view_date(int x, int y, int val);
+extern void fn_set_temp_view(int x, int y, int val);
+extern void fn_set_temp_view_date(int x, int y, int val);
+extern void fn_set_cloud_view(int x, int y, int val);
+extern void fn_set_cloud_bottom_view(int x, int y, int val);
+extern void fn_set_cloud_height_view(int x, int y, int val);
+extern void fn_set_cloud_view_date(int x, int y, int val);
+extern void fn_set_wind_view(int x, int y, int val);
+extern void fn_set_wind_view_date(int x, int y, int val);
 
-extern int load_side_config PARAMS ((Side *side));
+extern int load_side_config(Side *side);
