@@ -1100,25 +1100,6 @@ make_generic_image_data(char *imf)
 {
 }
 
-/* Networking functions (dummies for now). */
-
-void
-add_remote_player(char *name)
-{
-}
-
-int
-launch_game()
-{
-    /* (should fill this in) */
-    return FALSE;
-}
-
-void
-set_you_player(int id)
-{
-}
-
 #ifdef MAC
 
 int current_cursor;
@@ -1161,3 +1142,14 @@ unit_plan_dialog(Unit *unit)
 {
     auto_pick_new_plan(unit);
 }
+
+void
+add_remote_locally(int rid, char *str)
+{
+}
+
+void
+send_chat(int rid, char *str)
+{
+    printf("From %d: received chat \"%s\"\n", rid, str);
+}
