@@ -1,6 +1,6 @@
 /* supply.c 1.0 Sep-7-1998 - implementation of the (new) supply system.
  * 
- * Copyright (C) 1998 Sami Perttu.
+ * Copyright (C) 1998, 1999 Sami Perttu
  * Send bug reports to perttu@cc.helsinki.fi or the Xconq mailing list.
  * 
  * Xconq is free software; you can redistribute it and/or modify
@@ -59,12 +59,6 @@
  * Read the docs (?) for more info.
  */
 
-/* qsort() */
-#include <stdlib.h>
-
-/* memcpy() */
-#include <string.h>
-
 #include "conq.h"
 
 #define INITIAL_WORKSPACE	1024
@@ -103,27 +97,27 @@ typedef struct material_stats_struct {
 /* Copying the whole structure (~8 bytes) is a bit wasteful, but it's way
  * simpler than working with a pointer-based heap. */
 #define heap_node_copy(dst, src) \
-{ (dst) -> pot = (src) -> pot; (dst) -> x = (src) -> x; (dst) -> y = (src) -> y; }
+{ (dst)->pot = (src)->pot; (dst)->x = (src)->x; (dst)->y = (src)->y; }
 
 /* Static protos. */
-static void init_supply_system PARAMS((void));
-static void init_tmp_layers PARAMS((void));
-static void process_supply_class PARAMS((Side *side, material_stats *mclass));
-static void add_unit_heap PARAMS((Unit *unit, int m));
-static void run_supply_lines PARAMS((Side *side, int snum, int m));
-static void establish_supply_zone PARAMS((Side *side, int x, int y, material_stats *mclass));
-static void process_unit_supply PARAMS((Unit *unit, material_stats *mclass, int pot));
-static int calculate_supply_demand PARAMS((Unit *unit, int m, material_stats *res, int pot, int rec_stats));
-static void heap_init PARAMS((void));
-static void heap_insert PARAMS((int pot, short x, short y));
-static int heap_deque PARAMS((heap_node *hn));
-static void zone_init PARAMS((void));
-static void zone_insert PARAMS((Unit *unit, int wd));
-static void zone_sort PARAMS((void));
-static void zone_shuffle PARAMS((void));
-static int compare_zone_nodes PARAMS((const void *a, const void *b));
-static void extend_workspace PARAMS((int semantic_bytes));
-static void optimize_terrain PARAMS((void));
+static void init_supply_system(void);
+static void init_tmp_layers(void);
+static void process_supply_class(Side *side, material_stats *mclass);
+static void add_unit_heap(Unit *unit, int m);
+static void run_supply_lines(Side *side, int snum, int m);
+static void establish_supply_zone(Side *side, int x, int y, material_stats *mclass);
+static void process_unit_supply(Unit *unit, material_stats *mclass, int pot);
+static int calculate_supply_demand(Unit *unit, int m, material_stats *res, int pot, int rec_stats);
+static void heap_init(void);
+static void heap_insert(int pot, short x, short y);
+static int heap_deque(heap_node *hn);
+static void zone_init(void);
+static void zone_insert(Unit *unit, int wd);
+static void zone_sort(void);
+static void zone_shuffle(void);
+static int compare_zone_nodes(const void *a, const void *b);
+static void extend_workspace(int semantic_bytes);
+static void optimize_terrain(void);
 
 static int supply_initialized = FALSE;
 
@@ -184,27 +178,27 @@ Side *side;
     init_supply_system();
 
     /* Do we need to run at all? */
-    if(!mclass_count) return;
+    if (!mclass_count)
+      return;
     
     /* Initialize a_unit variables. */
     for_all_side_units(side, unit) {
 	/* If no materials are important to a unit, it is always considered to
 	 * have optimal supply status. */
-	if(neti[unit -> type]) {
-	    unit -> s_flow = unit -> s_conn = 0;
+	if (neti[unit->type]) {
+	    unit->s_flow = unit->s_conn = 0;
 	} else {
-	    unit -> s_flow = MAX_FLOW;
-	    unit -> s_conn = MAX_CONN;
+	    unit->s_flow = MAX_FLOW;
+	    unit->s_conn = MAX_CONN;
 	}
     }
 
     Dprintf("Running supply for side %d.\n", side_number(side));
     
     /* Run the algorithm for all equivalence classes of materials. */
-    mclass = first_mstat;
-    do {
+    for (mclass = first_mstat; mclass != NULL; mclass = mclass->next) {
 	process_supply_class(side, mclass);
-    } while(mclass = mclass -> next_class);
+    }
 }
 
 int
@@ -223,7 +217,7 @@ int m;
     Unit *unit;
 
     init_supply_system();
-    if(!mclass_count) return;
+    if (!mclass_count) return;
 
     init_tmp_layers();
 
@@ -240,7 +234,7 @@ Unit *unit;
 int m;
 {
     init_supply_system();
-    if(!mclass_count) return;
+    if (!mclass_count) return;
 
     init_tmp_layers();
 
@@ -259,14 +253,14 @@ init_supply_system(void)
     int mad[MAXMTYPES];
     int m, m2, i, u, cond, t;
 
-    if(supply_initialized) return; supply_initialized = TRUE;
+    if (supply_initialized) return; supply_initialized = TRUE;
 
     Dprintf("Initializing the supply system.\n");
 
     mclass_count = 0;
 
     /* Exit immediately if there are no material types. */
-    if(!nummtypes) return;
+    if (!nummtypes) return;
     
     /* for_all_border_types, for_all_connection_types */
     optimize_terrain();
@@ -298,7 +292,7 @@ init_supply_system(void)
     for_all_material_types(m) {
 	
 	/* Already added? */
-	if(mad[m]) continue;
+	if (mad[m]) continue;
 	
 	Dprintf("Analyzing material %d.\n", m);
 
@@ -307,19 +301,19 @@ init_supply_system(void)
 	cond = FALSE;
 	
 	for_all_unit_types(u) {
-	    if(um_supply_potential(u, m) > 0) { cond = TRUE; break; }
+	    if (um_supply_potential(u, m) > 0) { cond = TRUE; break; }
 	}
 	
-	if(!cond) Dprintf("Supply system not needed with this material.\n");
+	if (!cond) Dprintf("Supply system not needed with this material.\n");
 
 	/* If not, skip to the next material. */
-	if(!cond) continue;
+	if (!cond) continue;
 	
 	/* Establish a new equivalence class. */
 	++mclass_count;
-	ms -> next       = NULL;
-	ms -> mtype      = m;
-	ms -> next_class = pc;
+	ms->next       = NULL;
+	ms->mtype      = m;
+	ms->next_class = pc;
 	mad[m]           = TRUE;
 	ps               = ms++;
 	
@@ -328,12 +322,12 @@ init_supply_system(void)
 	/* Find any matching materials and add them to the class. */
 	for_all_material_types(m2) {
 
-	    if(mad[m2]) continue;
+	    if (mad[m2]) continue;
 	    
 	    cond = TRUE;
 	    
 	    for_all_unit_types(u) {
-		if(um_supply_potential(u, m)
+		if (um_supply_potential(u, m)
 		      != um_supply_potential(u, m2)
 		   || um_supply_interdiction_at_for_material(u, m)
 		      != um_supply_interdiction_at_for_material(u, m2)
@@ -344,9 +338,9 @@ init_supply_system(void)
 		}
 	    }
 	    
-	    if(cond) {
+	    if (cond) {
 		for_all_terrain_types(t) {
-		    if(tm_supply_deterioration(t, m)
+		    if (tm_supply_deterioration(t, m)
 		          != tm_supply_deterioration(t, m2)
 		       || tm_supply_enemy_interdiction(t, m)
 		          != tm_supply_enemy_interdiction(t, m2)
@@ -358,12 +352,12 @@ init_supply_system(void)
 		}
 	    }
 	    
-	    if(cond) {
+	    if (cond) {
 		/* All parameters relating to the establishment of supply
 		 * zones are identical. */
-		ms -> next       = ps;
-		ms -> mtype      = m2;
-		ms -> next_class = pc;
+		ms->next       = ps;
+		ms->mtype      = m2;
+		ms->next_class = pc;
 		mad[m2]          = TRUE;
 		ps               = ms++;
 		
@@ -383,7 +377,7 @@ init_supply_system(void)
 	    + numutypes * sizeof(int));
 
     /* Allocate workspace if needed. */
-    if(mclass_count) extend_workspace(0);
+    if (mclass_count) extend_workspace(0);
 
     /* Finally, trim memory taken by material_stats. */
     (void)realloc(mstats, (size_t)ms - (size_t)mstats);
@@ -426,7 +420,7 @@ material_stats *mclass;
     heap_init();
     
     /* Set m to any material representing this equivalence class. */
-    m = mclass -> mtype;
+    m = mclass->mtype;
     
     Dprintf("Processing material class related to material %d.\n", m);
 
@@ -453,17 +447,15 @@ material_stats *mclass;
     /* Layer tmp1 contains supply potentials for each cell. Now we need to find
      * the actual supply zones (continuous areas of non-zero supply potentials).
      */
-    for_all_cells(x, y) if(tmp1_at(x, y)) {
+    for_all_cells(x, y) if (tmp1_at(x, y)) {
 	    
-	ms = mclass;
-	
 	Dprintf("Supply zone found at (%d, %d). Processing:\n", x, y);
-	
-	do {
-	    ms -> demand     = 0;
-	    ms -> supply     = 0;
-	    ms -> wdemand    = 0;
-	} while(ms = ms -> next);
+
+	for (ms = mclass; ms != NULL; ms = ms->next) {
+	    ms->demand = 0;
+	    ms->supply = 0;
+	    ms->wdemand = 0;
+	}
 	
 	zone_init();
 	
@@ -478,75 +470,75 @@ material_stats *mclass;
 
 	do {
 	    Dprintf("Net balance for material %d: supply=%d, demand=%d, weighted demand=%d.\n",
-		    ms -> mtype, ms -> supply, ms -> demand, ms -> wdemand);
+		    ms->mtype, ms->supply, ms->demand, ms->wdemand);
 
-	    m = ms -> mtype;
+	    m = ms->mtype;
 	
 	    /* Shuffle the zone entries. This is the most straightforward
 	     * way of ensuring random distribution of any remainder
 	     * materials. */
 	    zone_shuffle();
 
-	    if(!(ms -> supply && ms -> demand)) continue;
+	    if (!(ms->supply && ms->demand)) continue;
 	    
 	    Dprintf("There's a total of %d units in this supply zone.\n", zone_entries);
 	    
-	    if(ms -> supply >= ms -> demand) {
+	    if (ms->supply >= ms->demand) {
 		    
-		/* There's enough of material ms -> mtype for
+		/* There's enough of material ms->mtype for
 		 * everyone.
 		 */
-		nrem = ms -> demand;
+		nrem = ms->demand;
 		
 		for(zn = zone_ptr, n = zone_entries; n; --n, ++zn) {
 
-		    (void)calculate_supply_demand(zn -> unit, m, &us, zn -> re, FALSE);
+		    (void)calculate_supply_demand(zn->unit, m, &us, zn->re, FALSE);
 		
-		    zn -> unit -> supply[m] += us.demand;
+		    zn->unit->supply[m] += us.demand;
 		
-		    if(neti[zn -> unit -> type]) {
-			zn -> unit -> s_flow +=
-			  ((int)um_supply_importance(zn -> unit -> type, m) << 14)
-			  / neti[zn -> unit -> type];
+		    if (neti[zn->unit->type]) {
+			zn->unit->s_flow +=
+			  ((int)um_supply_importance(zn->unit->type, m) << 14)
+			  / neti[zn->unit->type];
 		    }
 
-		    if(us.demand) 
+		    if (us.demand) 
 		      Dprintf("Gave %d of material %d to (%d, %d).\n",
-			      us.demand, m, zn -> unit -> x, zn -> unit -> y);
+			      us.demand, m, zn->unit->x, zn->unit->y);
 
-		    if(us.supply) {
-			t        = (us.supply * ms -> demand) / ms -> supply;
-			zn -> re = (us.supply * ms -> demand) % ms -> supply;
+		    if (us.supply) {
+			t        = (us.supply * ms->demand) / ms->supply;
+			zn->re = (us.supply * ms->demand) % ms->supply;
 			/* Round down during the first pass. */
-			zn -> unit -> supply[m] -= t;
+			zn->unit->supply[m] -= t;
 			Dprintf("Took %d of material %d from (%d, %d).\n",
-				t, m, zn -> unit -> x, zn -> unit -> y);
+				t, m, zn->unit->x, zn->unit->y);
 			nrem -= t;
-		    } else zn -> re = 0;
+		    } else zn->re = 0;
 		}
 
 
-		if(nrem) {
+		if (nrem) {
 		    /* Let's hope qsort() doesn't mess up the
 		     * beautiful shuffling we did earlier... */
 		    zone_sort();
 		
 		    for(zn = zone_ptr; nrem; --nrem, ++zn) {
 			Dprintf("Took remainder from %d at (%d, %d) with %d.\n",
-				zn -> unit -> type, zn -> unit -> x, zn -> unit -> y, zn -> re);
-			zn -> unit -> supply[m]--;
+				zn->unit->type, zn->unit->x, zn->unit->y, zn->re);
+			zn->unit->supply[m]--;
 		    }
 		}
 	    } else {
-		/* There's a shortage of material ms -> mtype.
+		/* There's a shortage of material ms->mtype.
 		 */
-		nrem = ms -> supply;
+		nrem = ms->supply;
 		
 		for(zn = zone_ptr, n = zone_entries; n; --n, ++zn) {
 		    /* Some of this is stupid, will have to optimize later */
-		    (void)calculate_supply_demand(zn -> unit, m, &us, zn -> re, FALSE);
-		    zn -> uw = zn -> re;
-		    zn -> re = us.weight;
+		    (void)calculate_supply_demand(zn->unit, m, &us, zn->re, FALSE);
+		    zn->uw = zn->re;
+		    zn->re = us.weight;
 		}
 
 		/* Sort by supply weight. */
@@ -554,62 +546,62 @@ material_stats *mclass;
 		
 		for(zn = zone_ptr, n = zone_entries; n; --n, ++zn) {
 			    
-		    (void)calculate_supply_demand(zn -> unit, m, &us, zn -> uw, FALSE);
+		    (void)calculate_supply_demand(zn->unit, m, &us, zn->uw, FALSE);
 		    
-		    zn -> unit -> supply[m] -= us.supply;
+		    zn->unit->supply[m] -= us.supply;
 		
-		    if(us.supply)
+		    if (us.supply)
 		      Dprintf("Took %d of material %d from (%d, %d).\n",
-			      us.supply, m, zn -> unit -> x, zn -> unit -> y);
+			      us.supply, m, zn->unit->x, zn->unit->y);
 
-		    if(us.wdemand) {
-			t = (us.wdemand * ms -> supply) / ms -> wdemand;
+		    if (us.wdemand) {
+			t = (us.wdemand * ms->supply) / ms->wdemand;
 			
-			if(t >= us.demand) {
-			    if(neti[zn -> unit -> type]) {
-				zn -> unit -> s_flow +=
-				  ((int)um_supply_importance(zn -> unit -> type, m) << 14)
-				  / neti[zn -> unit -> type];
+			if (t >= us.demand) {
+			    if (neti[zn->unit->type]) {
+				zn->unit->s_flow +=
+				  ((int)um_supply_importance(zn->unit->type, m) << 14)
+				  / neti[zn->unit->type];
 			    }
-			    zn -> unit -> supply[m] += us.demand;
-			    zn -> re = 0;
-			    zn -> uw = 0;
+			    zn->unit->supply[m] += us.demand;
+			    zn->re = 0;
+			    zn->uw = 0;
 			    nrem -= t;
 			    /* Update weighted demand. */
-			    ms -> wdemand -= (t - us.demand) * us.weight;
+			    ms->wdemand -= (t - us.demand) * us.weight;
 			    Dprintf("Gave %d of material %d to (%d, %d).\n",
-				    us.demand, m, zn -> unit -> x, zn -> unit -> y, 0);
+				    us.demand, m, zn->unit->x, zn->unit->y, 0);
 
 			} else {
 			
-			    if(neti[zn -> unit -> type]) {
-				zn -> uw = ((int)um_supply_importance(zn -> unit -> type, m) << 14) / neti[zn -> unit -> type];
-				zn -> unit -> s_flow += (zn -> uw * t) / us.demand;
-				zn -> uw /= us.demand;
-			    } else zn -> uw = 0;
+			    if (neti[zn->unit->type]) {
+				zn->uw = ((int)um_supply_importance(zn->unit->type, m) << 14) / neti[zn->unit->type];
+				zn->unit->s_flow += (zn->uw * t) / us.demand;
+				zn->uw /= us.demand;
+			    } else zn->uw = 0;
 			
-			    zn -> unit -> supply[m] += t;
-			    zn -> re = (us.wdemand * ms -> supply) % ms -> wdemand;
+			    zn->unit->supply[m] += t;
+			    zn->re = (us.wdemand * ms->supply) % ms->wdemand;
 			    nrem -= t;
 
 			    Dprintf("Gave %d of material %d to (%d, %d); %d of weighted demand left.\n",
-				    t, m, zn -> unit -> x, zn -> unit -> y, zn -> re);
+				    t, m, zn->unit->x, zn->unit->y, zn->re);
 			}
-		    } else zn -> re = 0;
+		    } else zn->re = 0;
 		}
 
-		if(nrem) {
+		if (nrem) {
 		    zone_sort();
 		
 		    for(zn = zone_ptr; nrem; --nrem, ++zn) {
 			Dprintf("Distributed surplus to %d at (%d, %d).\n",
-				zn -> unit -> type, zn -> unit -> x, zn -> unit -> y);
-			zn -> unit -> supply[m]++;
-			if(neti[zn -> unit -> type]) zn -> unit -> s_flow += zn -> uw;
+				zn->unit->type, zn->unit->x, zn->unit->y);
+			zn->unit->supply[m]++;
+			if (neti[zn->unit->type]) zn->unit->s_flow += zn->uw;
 		    }
 		}
 	    }
-	} while(ms = ms -> next);
+	} while((ms = ms->next) != NULL);
 
     }
 
@@ -625,30 +617,31 @@ int m;
     int ss;
     
     /* Get the basic potential. */
-    ss  = um_supply_potential(unit -> type, m);
+    ss  = um_supply_potential(unit->type, m);
 
-    if(!ss) return;
+    if (!ss) return;
 
     /* Effect of terrain on supply potential. */
-    ss *= ut_supply_potential_terrain_effect(unit -> type,
-					     terrain_at(unit -> x, unit -> y));
+    ss *= ut_supply_potential_terrain_effect(unit->type,
+					     terrain_at(unit->x, unit->y));
 
     /* Effect of occupancy on supply potential. */
-    if(tr = unit -> transport) {
+    if ((tr = unit->transport) != NULL) {
 	/* This improves accuracy but could conceivably overflow?? */
-	ss *= uu_occupant_supply_potential(unit -> type, tr -> type);
+	ss *= uu_occupant_supply_potential(unit->type, tr->type);
 	ss /= 10000;
-    } else ss /= 100;
+    } else
+      ss /= 100;
 
     Dprintf("Potential %d, modified to %d, found in a unit of type %d at (%d, %d).\n",
-	    um_supply_potential(unit -> type, m), ss, unit -> type, unit -> x, unit -> y);
+	    um_supply_potential(unit->type, m), ss, unit->type, unit->x, unit->y);
 
     /* Add to the heap unless a previously processed unit in the same cell
      * had a higher supply potential (only the maximum counts). */
 
-    if(ss > tmp1_at(unit -> x, unit -> y)) {
-	set_tmp1_at(unit -> x, unit -> y, ss);
-	heap_insert(ss, unit -> x, unit -> y);
+    if (ss > tmp1_at(unit->x, unit->y)) {
+	set_tmp1_at(unit->x, unit->y, ss);
+	heap_insert(ss, unit->x, unit->y);
     }
 }
 
@@ -670,23 +663,23 @@ int snum, m;
 	Dprintf("Potential %d at (%d, %d).\n", hn.pot, hn.x, hn.y);
 	
 	/* Has this cell already been reached from a stronger supply line? */
-	if(tmp1_at(hn.x, hn.y) > hn.pot) continue;
+	if (tmp1_at(hn.x, hn.y) > hn.pot) continue;
 	
 	/* Attempt to run supply to adjacent cells. */
 	for_all_directions(dir) {
 
-	    if(point_in_dir(hn.x, hn.y, dir, &x, &y)) {
+	    if (point_in_dir(hn.x, hn.y, dir, &x, &y)) {
 
 		tt = terrain_at(x, y);		/* cell type */
 		ss = tmp1_at(x, y);		/* previous supply potential (or 0) */
 
 		/* Evaluate enemy/neutral control/interdiction */
-		if(tmp2_at(x, y) < 0) {
+		if (tmp2_at(x, y) < 0) {
 
 		    /* Check if nobody/another side is controlling the cell. */
-		    if(area.controlside && (cnum = control_side_at(x, y)) != snum) {
-			if(cnum == NOCONTROL) t2 = tm_supply_neutral_interdiction(tt, m);
-			else if(!side -> trusts || !side -> trusts[cnum]) {
+		    if (area.controlside && (cnum = control_side_at(x, y)) != snum) {
+			if (cnum == NOCONTROL) t2 = tm_supply_neutral_interdiction(tt, m);
+			else if (!side->trusts || !side->trusts[cnum]) {
 			    /* Should use reciprocal relation instead in the test? TODO? */
 			    t2 = tm_supply_enemy_interdiction(tt, m);
 			} else t2 = 0;
@@ -694,19 +687,19 @@ int snum, m;
 
 		    /* Enemy interdiction in the cell. */
 		    for_all_stack(x, y, unit) {
-			if(unit -> side != side 
-			   && (!side -> trusts || !side -> trusts[side_number(side)])) {
-			    t2 += (ut_supply_interdiction_at(unit -> type, tt) *
-				   um_supply_interdiction_at_for_material(unit -> type, m)) / 100;
+			if (unit->side != side 
+			   && (!side->trusts || !side->trusts[side_number(side)])) {
+			    t2 += (ut_supply_interdiction_at(unit->type, tt) *
+				   um_supply_interdiction_at_for_material(unit->type, m)) / 100;
 			}
 		    }
 
 		    /* Interdiction from adjacent cells. */
-		    for_all_directions(dir2) if(point_in_dir(x, y, dir2, &nx, &ny)) {
+		    for_all_directions(dir2) if (point_in_dir(x, y, dir2, &nx, &ny)) {
 			for_all_stack(nx, ny, unit) {
-			    if(unit -> side != side && (!side -> trusts || !side -> trusts[side_number(side)])) {
-				t2 += (ut_supply_interdiction_adjacent(unit -> type, tt) *
-				       um_supply_interdiction_adjacent_for_material(unit -> type, m)) / 100;
+			    if (unit->side != side && (!side->trusts || !side->trusts[side_number(side)])) {
+				t2 += (ut_supply_interdiction_adjacent(unit->type, tt) *
+				       um_supply_interdiction_adjacent_for_material(unit->type, m)) / 100;
 			    }
 			}
 		    }
@@ -718,20 +711,20 @@ int snum, m;
 		
 		/* Stop here if we aren't stronger than all previous supply
 		 * attempts. */
-		if(pot <= ss) continue;
+		if (pot <= ss) continue;
 		
 		/* Calculate deterioration from cell and border terrain. */
 		td = tm_supply_deterioration(tt, m);
 		
 		for_all_border_types(tt) {
-		    if(border_at(hn.x, hn.y, dir, tt)) td += tm_supply_deterioration(tt, m);
+		    if (border_at(hn.x, hn.y, dir, tt)) td += tm_supply_deterioration(tt, m);
 		}
 		
 		/* Find the cheapest connection type. Connection terrain is
 		 * assumed to "run over" any border terrain. */
 		cc = td;
 		for_all_connection_types(tt) {
-		    if(connection_at(hn.x, hn.y, dir, tt)
+		    if (connection_at(hn.x, hn.y, dir, tt)
 		       && tm_supply_deterioration(tt, m) < cc) {
 			cc = tm_supply_deterioration(tt, m);
 		    }
@@ -739,7 +732,7 @@ int snum, m;
 
 		/* Compute the final potential and compare. */
 		pot -= min(cc, td);
-		if(pot <= ss) continue;
+		if (pot <= ss) continue;
 
 		/* OK, add this cell to the heap. */
 		set_tmp1_at(x, y, pot);
@@ -764,11 +757,11 @@ material_stats *mclass;
     set_tmp1_at(x, y, 0);
 
     for_all_stack(x, y, unit) {
-	if(unit -> side == side) process_unit_supply(unit, mclass, pot);
+	if (unit->side == side) process_unit_supply(unit, mclass, pot);
     }
 
     for_all_directions(dir) {
-	if(point_in_dir(x, y, dir, &x1, &y1) && tmp1_at(x1, y1)) {
+	if (point_in_dir(x, y, dir, &x1, &y1) && tmp1_at(x1, y1)) {
 	    (void)establish_supply_zone(side, x1, y1, mclass);
 	}
     }
@@ -789,28 +782,24 @@ int pot;
     for_all_occupants(unit, occ) process_unit_supply(occ, mclass, pot);
 
     Dprintf("Processing supply for a unit of type %d at (%d, %d) with potential %d;\n",
-	    unit -> type, unit -> x, unit -> y, pot);
-
-    ms = mclass;
+	    unit->type, unit->x, unit->y, pot);
 
     /* Now the unit. */
-    do {
-
-	if(calculate_supply_demand(unit, ms -> mtype, &res, pot, TRUE)) {
+    for (ms = mclass; ms != NULL; ms = ms->next) {
+	if (calculate_supply_demand(unit, ms->mtype, &res, pot, TRUE)) {
 
 	    sd = TRUE;
 	    
 	    Dprintf("Material %d status: supply=%d, demand=%d, weighted demand=%d.\n",
-		    ms -> mtype, res.supply, res.demand, res.wdemand);
+		    ms->mtype, res.supply, res.demand, res.wdemand);
 	    
-	    ms -> supply  += res.supply;
-	    ms -> demand  += res.demand;
-	    ms -> wdemand += res.wdemand;
+	    ms->supply  += res.supply;
+	    ms->demand  += res.demand;
+	    ms->wdemand += res.wdemand;
 	}
-
-    } while(ms = ms -> next);
+    }
     
-    if(sd) {
+    if (sd) {
 	/* Link up. */
 	zone_insert(unit, pot);
     }
@@ -828,75 +817,75 @@ int pot, rec_stats;
     int sd = FALSE;
     int capm;
 
-    u = unit -> type;
-    s = unit -> supply[m];
+    u = unit->type;
+    s = unit->supply[m];
     
     /* Calculate any supply capacity deterioration. */
     t = um_supply_capacity_threshold(u, m);
     
-    if(pot < t) {
+    if (pot < t) {
 	capm = (pot * 100 + (t - pot) * um_supply_capacity_deterioration(u, m)) / t;
     } else {
 	capm = 100;
     }
 
-    if(rec_stats && neti[u]) {
+    if (rec_stats && neti[u]) {
 	/* Update connectedness. */
-	unit -> s_conn += ((capm << 8) * (int)um_supply_importance(u, m)) / (int)neti[u];
+	unit->s_conn += ((capm << 8) * (int)um_supply_importance(u, m)) / (int)neti[u];
     }
 
     /* Calculate supply. */
     t = um_supply_out_threshold(u, m);
 
-    if(t >= 0 && s > t) {
-	if(um_supply_out_max(u, m) == -1) res -> supply = s - t;
-	else res -> supply = min((um_supply_out_max(u, m) * capm) / 100, s - t);
+    if (t >= 0 && s > t) {
+	if (um_supply_out_max(u, m) == -1) res->supply = s - t;
+	else res->supply = min((um_supply_out_max(u, m) * capm) / 100, s - t);
 
-	if(res -> supply) sd = TRUE;
+	if (res->supply) sd = TRUE;
     } else {
-	res -> supply  = 0;
+	res->supply  = 0;
     }
 
     /* Calculate demand. */
     t = um_clip_in_threshold(u, m);
 
-    if(t > 0 && s < t) {
+    if (t > 0 && s < t) {
 
-	if(um_supply_in_max(u, m) == -1) res -> demand = t - s;
-	else res -> demand = min((um_supply_in_max(u, m) * capm) / 100, t - s);
+	if (um_supply_in_max(u, m) == -1) res->demand = t - s;
+	else res->demand = min((um_supply_in_max(u, m) * capm) / 100, t - s);
 
-	if(res -> demand) {
+	if (res->demand) {
 	    sd = TRUE;
 	} else {
-	    res -> wdemand = 0;
-	    res -> weight  = 0;
+	    res->wdemand = 0;
+	    res->weight  = 0;
 
 	    /* Not sure about this... supply lines so bad that cannot receive
 	     * anything, but inflow still at 100%? */
-	    if(rec_stats && neti[u]) {
-		unit -> s_flow += ((int)um_supply_importance(u, m) << 14) / neti[u];
+	    if (rec_stats && neti[u]) {
+		unit->s_flow += ((int)um_supply_importance(u, m) << 14) / neti[u];
 	    }
 
 	    return sd;
 	}
 
 	/* Calculate weighted demand. */
-	if(um_supply_starve_weight(u, m) != um_supply_in_weight(u, m)) {
-	    res -> weight  = (s * um_supply_in_weight(u, m) + (t - s) * um_supply_starve_weight(u, m)) / t;
+	if (um_supply_starve_weight(u, m) != um_supply_in_weight(u, m)) {
+	    res->weight  = (s * um_supply_in_weight(u, m) + (t - s) * um_supply_starve_weight(u, m)) / t;
 	} else {
-	    res -> weight  = um_supply_in_weight(u, m);
+	    res->weight  = um_supply_in_weight(u, m);
 	}
 
-	res -> wdemand = res -> demand * res -> weight;
+	res->wdemand = res->demand * res->weight;
 
     } else {
-	res -> demand  = 0;
-	res -> weight  = 0;
-	res -> wdemand = 0;
+	res->demand  = 0;
+	res->weight  = 0;
+	res->wdemand = 0;
 
 	/* If didn't need any supplies, add to inflow anyway */
-	if(t > 0 && rec_stats && neti[u]) {
-	    unit -> s_flow += ((int)um_supply_importance(u, m) << 14) / neti[u];
+	if (t > 0 && rec_stats && neti[u]) {
+	    unit->s_flow += ((int)um_supply_importance(u, m) << 14) / neti[u];
 	}
     }
     
@@ -910,28 +899,11 @@ heap_init(void)
 }
 
 static void
-
-// --- CODEWARRIOR GIVES THE FOLLOWING COMPILE ERROR: -------------
-
-//	Error   : identifier 'heap_insert(int, short, short)' redeclared
-//	was declared as: 'void (int, short, short)'
-//	now declared as: 'void (...)'
-
-//	This happens ONLY for this function and not for any other in this file. Weird!
-//	Declaring the formal parameters within the parenthesis solved the problem.
-
-//	heap_insert(pot, x, y)
-//	int pot;
-//	short x, y;
-
-	heap_insert(int pot, short x, short y)
-
-// --------------------------------------------------
-
+heap_insert(int pot, short x, short y)
 {
     int i, f;
     
-    if(++heap_entries == heap_size) extend_workspace(heap_entries * sizeof(heap_node));
+    if (++heap_entries == heap_size) extend_workspace(heap_entries * sizeof(heap_node));
 
     i = heap_entries;
     f = i >> 1;
@@ -954,19 +926,19 @@ heap_node *hn;
     int i = 2, f = 1, epot;
     heap_node *enode;
     
-    if(!heap_entries) return FALSE;
+    if (!heap_entries) return FALSE;
     
     enode = &heap_ptr[heap_entries];	/* Last entry in the heap
 					 * (the first slot is empty). */
-    epot  = enode -> pot;		/* Priority of the last entry. */
+    epot  = enode->pot;		/* Priority of the last entry. */
 
     /* Get the top of the heap. */
     heap_node_copy(hn, &heap_ptr[1]);
     
     /* Ripple the remaining entries up in the heap. */
     while(i < heap_entries) {
-	if(heap_ptr[i].pot > heap_ptr[i + 1].pot) {
-	    if(epot > heap_ptr[i].pot) {
+	if (heap_ptr[i].pot > heap_ptr[i + 1].pot) {
+	    if (epot > heap_ptr[i].pot) {
 		heap_node_copy(&heap_ptr[f], enode);
 		--heap_entries;
 		return TRUE;
@@ -975,7 +947,7 @@ heap_node *hn;
 	    f  = i;
 	    i += i;
 	} else {
-	    if(epot > heap_ptr[i + 1].pot) {
+	    if (epot > heap_ptr[i + 1].pot) {
 		heap_node_copy(&heap_ptr[f], enode);
 		--heap_entries;
 		return TRUE;
@@ -986,7 +958,7 @@ heap_node *hn;
 	}
     }
 
-    if(i == heap_entries && heap_ptr[i].pot > epot) {
+    if (i == heap_entries && heap_ptr[i].pot > epot) {
 	heap_node_copy(&heap_ptr[f], &heap_ptr[i]);
 	heap_node_copy(&heap_ptr[i], enode);
     } else {
@@ -1008,7 +980,7 @@ zone_insert(unit, re)
 Unit *unit;
 int re;
 {
-    if(zone_entries == zone_size) extend_workspace(zone_entries * sizeof(zone_node));
+    if (zone_entries == zone_size) extend_workspace(zone_entries * sizeof(zone_node));
     
     zone_ptr[zone_entries].re   = re;
     zone_ptr[zone_entries].unit = unit;
@@ -1034,15 +1006,15 @@ zone_shuffle(void)
 	
 	zn2 = &zn1[xrandom(n)];
 	
-	t.re        = zn1 -> re;
-	t.uw        = zn1 -> uw;
-	t.unit      = zn1 -> unit;
-	zn1 -> re   = zn2 -> re;
-	zn1 -> uw   = zn2 -> uw;
-	zn1 -> unit = zn2 -> unit;
-	zn2 -> re   = t.re;
-	zn2 -> uw   = t.uw;
-	zn2 -> unit = t.unit;
+	t.re        = zn1->re;
+	t.uw        = zn1->uw;
+	t.unit      = zn1->unit;
+	zn1->re   = zn2->re;
+	zn1->uw   = zn2->uw;
+	zn1->unit = zn2->unit;
+	zn2->re   = t.re;
+	zn2->uw   = t.uw;
+	zn2->unit = t.unit;
     }
 }
 
@@ -1050,21 +1022,24 @@ static int
 compare_zone_nodes(a, b)
 const void *a, *b;
 {
-    return (int)(((zone_node *)b) -> re - ((zone_node *)a) -> re);
+    return (int)(((zone_node *)b)->re - ((zone_node *)a)->re);
 }
 
 static void
-extend_workspace(semantic_bytes)
-int semantic_bytes;
+extend_workspace(int semantic_bytes)
 {
     void *new_ws;
 
-    if(!ws_size) ws_size = INITIAL_WORKSPACE; else ws_size <<= 1;
+    if (!ws_size)
+      ws_size = INITIAL_WORKSPACE;
+    else
+      ws_size <<= 1;
 
     /* Should try realloc() here but who cares. */
     new_ws    = xmalloc(ws_size);
 
-    if(semantic_bytes) memcpy(new_ws, ws, semantic_bytes);
+    if (semantic_bytes)
+      memcpy(new_ws, ws, semantic_bytes);
 
     ws        = new_ws;
     zone_ptr  = (zone_node *)new_ws;
@@ -1075,8 +1050,10 @@ int semantic_bytes;
     zone_size = ws_size / sizeof(zone_node) - 1;
 }
 
-/* Initialize stuff for macros for_all_border_types and for_all_connection_types.
- * This could/should be done in calculate_globals(). */
+/* Initialize stuff for macros for_all_border_types and
+   for_all_connection_types.  This could/should be done in
+   calculate_globals(). */
+
 static void
 optimize_terrain(void)
 {
@@ -1088,15 +1065,15 @@ optimize_terrain(void)
     ctypear = (int *)xmalloc(numttypes * sizeof(int));
     
     for_all_terrain_types(t) {
-	if(t_is_border(t)) {
-	    if(pb < 0) firstbtype = t; else { btypear[pb] = t; pb = t; }
-	} else if(t_is_connection(t)) {
-	    if(pc < 0) firstctype = t; else { ctypear[pc] = t; pc = t; }
+	if (t_is_border(t)) {
+	    if (pb < 0) firstbtype = t; else { btypear[pb] = t; pb = t; }
+	} else if (t_is_connection(t)) {
+	    if (pc < 0) firstctype = t; else { ctypear[pc] = t; pc = t; }
 	}
     }
 
-    if(pb < 0) btypear[pb = firstbtype = 0] = -1; else btypear[pb] = -1;
-    if(pc < 0) ctypear[pc = firstctype = 0] = -1; else ctypear[pc] = -1;
+    if (pb < 0) btypear[pb = firstbtype = 0] = -1; else btypear[pb] = -1;
+    if (pc < 0) ctypear[pc = firstctype = 0] = -1; else ctypear[pc] = -1;
 
     /* Pedantic */
     (void)realloc((void *)btypear, (pb + 1) * sizeof(int));
