@@ -10,7 +10,7 @@ any later version.  See the file COPYING.  */
 #include "kernel.h"
 
 extern int need_ai_task_reaction;
-extern int target_visible PARAMS ((Unit *unit, Task *task));
+extern int target_visible(Unit *unit, Task *task);
 
 /* This is the number of tasks to allocate initially.  More will always be
    allocated as needed, so this should be a "reasonable" value. */
@@ -21,19 +21,19 @@ extern int target_visible PARAMS ((Unit *unit, Task *task));
 
 #define CLEAR_AGENDA 99
 
-static int compare_directions PARAMS ((const void *a0, const void *a1));
-static int test_for_buildable PARAMS ((int x, int y));
-static int collect_test PARAMS ((int x, int y));
-static int extractable_test PARAMS ((int x, int y));
-static int repair_test PARAMS ((int x, int y));
-static int resupply_test PARAMS ((int x, int y));
-static TaskOutcome execute_task_aux PARAMS ((Unit *unit, Task *task));
+static int compare_directions(const void *a0, const void *a1);
+static int test_for_buildable(int x, int y);
+static int collect_test(int x, int y);
+static int extractable_test(int x, int y);
+static int repair_test(int x, int y);
+static int resupply_test(int x, int y);
+static TaskOutcome execute_task_aux(Unit *unit, Task *task);
 
 /* Declare all the task functions. */
 
 #undef  DEF_TASK
 #define DEF_TASK(name,code,argtypes,DOFN,createfn,setfn,netsetfn,pushfn,netpushfn,argdecl)  \
-  static TaskOutcome DOFN PARAMS ((Unit *unit, Task *task));
+  static TaskOutcome DOFN(Unit *unit, Task *task);
 
 #include "task.def"
 
@@ -848,7 +848,7 @@ enum choicestate {
     rightonly
 };
 
-static TaskOutcome do_approach_subtask PARAMS ((Unit *unit, Task *task, int tx, int ty, short *statep));
+static TaskOutcome do_approach_subtask(Unit *unit, Task *task, int tx, int ty, short *statep);
 
 /* The move-to task is the main way for units to get from point A to
    point B.  In addition to the destination, the task has a required
@@ -1674,7 +1674,7 @@ execute_task_aux(unit, task)
 Unit *unit;
 Task *task;
 {
-    TaskOutcome (*fn) PARAMS ((Unit *unit, Task *task));
+    TaskOutcome (*fn)(Unit *unit, Task *task);
 
     if (!alive(unit) || task == NULL)
       return TASK_UNKNOWN;
@@ -1702,8 +1702,8 @@ int
 choose_move_dirs(unit, tx, ty, shortest, dirtest, dirsort, dirs)
 Unit *unit;
 int tx, ty, shortest, *dirs;
-int (*dirtest) PARAMS ((Unit *, int));
-void (*dirsort) PARAMS ((Unit *, int *, int));
+int (*dirtest)(Unit *, int);
+void (*dirsort)(Unit *, int *, int);
 {
     int dx, dxa, dy, dist, d1, d2, d3, d4, axis = -1, hextant = -1;
     int numdirs = 0, shortestnumdirs;
@@ -2347,9 +2347,9 @@ int n;
     add_task(unit, 0, create_sentry_task(unit, n));
 }
 
-extern int parse_location PARAMS ((Side *side, char *arg, int *xp, int *yp));
+extern int parse_location(Side *side, char *arg, int *xp, int *yp);
 
-extern Unit *parse_unit PARAMS ((Side *side, char *arg));
+extern Unit *parse_unit(Side *side, char *arg);
 
 /* Find a unit with the given name, either alive or dead. */
 
