@@ -9,17 +9,33 @@ any later version.  See the file COPYING. */
 /* This is the implementation of the high-level protocol. */
 
 #include "conq.h"
+extern void send_variant_value(int i, int v1, int v2, int v3, int v4, int v5);
+extern void (*update_variant_callback)(int i, int v1, int v2, int v3, int v4, int v5);
+extern void (*update_assignment_callback)(int n);
+extern int net_add_side_and_player(void);
+extern void net_set_player_advantage(int n, int newadv);
+extern void net_rename_side_for_player(int n);
+extern void net_set_ai_for_player(int n, char *aitype);
+extern int net_exchange_players(int n, int n2);
+extern void set_player_advantage(int n, int newadv);
+extern void rename_side_for_player(int n);
+extern void set_ai_for_player(int n, char *aitype);
+extern void add_to_packet(char *str);
+extern void flush_write(void);
+extern void send_game_checksum_error(int rid, int my_csum, int master_csum);
 #include "kernel.h"
 #include "kpublic.h"
-
-void flush_outgoing_queue(void);
-void flush_incoming_queue(void);
+extern int game_checksum(void);
 
 extern long randstate;
 
 /* Iteration over all remote programs, by rid. */
 
-#define for_all_remotes(rid) for ((rid) = 1; (rid) <= numremotes; ++(rid))
+#define for_all_remotes(rid) \
+  for ((rid) = 1; (rid) <= numremotes; ++(rid)) \
+    if (online[rid])
+
+/* Definitions of special characters in the protocol. */
 
 #define STARTPKT '$'
 #define ENDPKT '^'
@@ -29,7 +45,6 @@ extern long randstate;
 #define ENDPKTESC '&'
 #define ESCAPEPKTESC '@'
 
-static void broadcast_message(Side *side, SideMask sidemask, char *str);
 static void broadcast_command_5(char *cmd, int val, int val2, int val3,
 				int val4, int val5);
 static void broadcast_side_property(Side *side, char *prop, int val);
@@ -63,9 +78,21 @@ static void receive_unit_prop(char *str);
 static void receive_world_prop(char *str);
 static void receive_run_game(char *str);
 static void receive_game_checksum(char *str);
-static int game_checksum(void);
+static void receive_error(char *str);
+static void receive_remote_program(char *str);
+static void receive_chat(char *str);
+static void receive_variant_setting(char *str);
+static void receive_assignment_setting(char *str);
 static int tohex(int x);
 static int fromhex(int x);
+static void flush_incoming_queue(void);
+
+/* This is true if the program expects to host the game and also be the
+   master when all the remote programs are hooked up. */
+
+int hosting;
+
+/* This is the total number of programs in the game. */
 
 int numremotes;
 
@@ -79,8 +106,14 @@ int my_rid;
 
 int master_rid;
 
+/* The program to which we are currently downloading. */
+
 int tmprid;
 
+char *remote_player_specs[100];
+
+int online[100];
+
 int expecting_ack;
 
 int timeout_warnings = TRUE;
@@ -97,22 +130,73 @@ int dlbufend;
 
 long new_randstate;
 
+void (*update_variant_callback)(int i, int v1, int v2, int v3, int v4, int v5) = NULL;
+
+void (*update_assignment_callback)(int n) = NULL;
+
+int quitter;
+
+/* If a side is being played from a remote program, we don't need the
+   full user interface structure, just make a placeholder that records
+   the program's id. */
+
 void
-init_remote_ui(side)
-Side *side;
+init_remote_ui(Side *side)
 {
     if (side->rui == NULL) {
 	side->rui = (RUI *) xmalloc(sizeof(RUI));
     }
-    side->rui->rid = side->rid;
+    /* At present, rui->rid is unused. */
+    side->rui->rid = side->player->rid;
+}
+
+/* For a new remote program with given remote id and player spec,
+   record it locally and also broadcast to all remotes currently
+   online. */
+
+void
+add_remote_program(int rid, char *name)
+{
+    int rid2;
+
+    numremotes = max(rid, numremotes);
+    online[rid] = TRUE;
+    /* Inform our new program of all the existing programs. */
+    for_all_remotes(rid2) {
+	if (rid2 != rid) {
+	    sprintf(spbuf, "p%d %s", rid2, remote_player_specs[rid2]);
+	    send_packet(rid, spbuf);
+	}
+    }
+    remote_player_specs[rid] = copy_string(name);
+    add_remote_locally(rid, name);
+    /* Now broadcast info about the new program to everybody. */
+    sprintf(spbuf, "p%d %s", rid, name);
+    broadcast_packet(spbuf);
+}
+
+/* For each remote program (including us), add a player corresponding
+   to the spec supplied by that program. */
+
+void
+add_remote_players(void)
+{
+    int rid;
+    Player *player;
+
+    for_all_remotes(rid) {
+	player = add_player();
+	parse_player_spec(player, remote_player_specs[rid]);
+	canonicalize_player(player);
+	player->rid = rid;
+    }
 }
 
 /* Send a message asking to join the game.  Return TRUE if the host
    actually acknowledged us, FALSE if no response. */
 
 int
-send_join(str)
-char *str;
+send_join(char *str)
 {
     int tries = 100, successful;
 
@@ -129,9 +213,29 @@ char *str;
     return FALSE;
 }
 
+/* Tell the remote program what its id will be during this game. */
+
 void
-send_version(rid)
-int rid;
+send_remote_id(int rid)
+{
+    sprintf(spbuf, "r%d", rid);
+    send_packet(rid, spbuf);
+}
+
+void
+net_send_chat(int rid, char *str)
+{
+    if (my_rid == master_rid) {
+	send_chat(rid, str);
+    }
+    if (numremotes > 0) {
+	sprintf(spbuf, "c%d %s", rid, str);
+	broadcast_packet(spbuf);
+    }
+}
+
+void
+send_version(int rid)
 {
     /* In order to guarantee that the kernels can actually stay in
        sync, we require that the program versions match exactly. */
@@ -140,32 +244,117 @@ int rid;
 }
 
 void
-send_assignment(id, side, player)
-int id;
-Side *side;
-Player *player;
+send_variant_value(int i, int v1, int v2, int v3, int v4, int v5)
+{
+    /* Local master change done already. */
+    if (numremotes > 0) {
+	sprintf(spbuf, "v %d %d %d %d %d %d", i, v1, v2, v3, v4, v5);
+	broadcast_packet(spbuf);
+    }
+}
+
+void
+net_set_player_advantage(int n, int newadv)
+{
+    if (my_rid == master_rid) {
+	set_player_advantage(n, newadv);
+    }
+    if (numremotes > 0) {
+	sprintf(spbuf, "a%d advantage %d", n, newadv);
+	broadcast_packet(spbuf);
+    }
+}
+
+int
+net_add_side_and_player(void)
+{
+    int rslt = -1;
+
+    if (my_rid == master_rid) {
+	rslt = add_side_and_player();
+    }
+    if (numremotes > 0) {
+	sprintf(spbuf, "a0 add");
+	broadcast_packet(spbuf);
+    }
+    return rslt;
+}
+
+void
+net_rename_side_for_player(int n)
+{
+    if (my_rid == master_rid) {
+	rename_side_for_player(n);
+    }
+    if (numremotes > 0) {
+	sprintf(spbuf, "a%d rename", n);
+	broadcast_packet(spbuf);
+    }
+}
+
+void
+net_set_ai_for_player(int n, char *aitype)
+{
+    if (my_rid == master_rid) {
+	set_ai_for_player(n, aitype);
+    }
+    if (numremotes > 0) {
+	sprintf(spbuf, "a%d ai %s", n, (aitype ? aitype : ""));
+	broadcast_packet(spbuf);
+    }
+}
+
+int
+net_exchange_players(int n, int n2)
+{
+    int rslt = -1;
+
+    if (my_rid == master_rid) {
+	rslt = exchange_players(n, n2);
+    }
+    if (numremotes > 0) {
+	sprintf(spbuf, "a%d exchange %d", n, n2);
+	broadcast_packet(spbuf);
+    }
+    return rslt;
+}
+
+void
+send_assignment(int rid, Side *side, Player *player)
 {
     sprintf(spbuf, "Passign %d %d", side->id, player->id);
-    send_packet(id, spbuf);
+    send_packet(rid, spbuf);
 }
 
 void
-send_id(id)
-int id;
+download_to_player(Player *player)
 {
-    sprintf(spbuf, "Pyou %d", id);
-    send_packet(id, spbuf);
+    int i;
+
+    download_game_module(player->rid);
+    /* Send it the current list of side/player assignments. */
+    for (i = 0; i < numsides; ++i) {
+	send_assignment(player->rid, assignments[i].side,
+			assignments[i].player);
+    }
+#if 0
+    send_id(player->id);
+#endif
+    /* Make it run everything up to the player setup phase. */
+    send_randstate(player->rid);
+    /* If errors, should set player rid back to zero */
 }
 
 void
-download_to_player(player)
-Player *player;
+download_game_module(int rid)
 {
-    int i, rslt;
+    int rslt;
     Module *module;
 
-    tmprid = player->rid;
-    send_packet(tmprid, "GameModule");
+    /* Record the rid in a global so the module-writing code knows
+       where to send all the packets. */
+    tmprid = rid;
+    send_packet(rid, "gameModule");
     module = create_game_module("*download*");
     /* Fill in some default slots. */
     module->startlineno = 1;
@@ -174,82 +363,173 @@ Player *player;
     module->compress_layers = TRUE;
     module->def_all = TRUE; /* for now */
     if (mainmodule != NULL) {
+	module->title = mainmodule->title;
+	module->blurb = mainmodule->blurb;
+	module->picturename = mainmodule->picturename;
+#if 0 /* side-effects... */
+	module->basemodulename = mainmodule->basemodulename;
+	module->defaultbasemodulename = mainmodule->defaultbasemodulename;
+	module->basegame = mainmodule->basegame;
+#endif
+	module->version = mainmodule->version;
+	module->variants = mainmodule->variants;
 	if (!empty_string(mainmodule->origmodulename)) {
 	    module->origmodulename = mainmodule->origmodulename;
 	} else if (!empty_string(mainmodule->name)) {
 	    module->origmodulename = mainmodule->name;
 	}
+	module->origvariants = mainmodule->origvariants;
     }
     downloading = TRUE;
     rslt = write_game_module(module);
     downloading = FALSE;
-    send_packet(tmprid, "\neludoMemaG\n");
-    /* Send it the current list of side/player assignments. */
-    for (i = 0; i < numsides; ++i) {
-	send_assignment(tmprid, assignments[i].side, assignments[i].player);
+    send_packet(rid, "\neludoMemag\n");
+    tmprid = 0;
+}
+
+#ifdef UNIX
+#define DOWNLOADPACKETSIZE 200
+#else
+#define DOWNLOADPACKETSIZE 40
+#endif
+
+static char *notherbuf;
+
+void
+add_to_packet(char *str)
+{
+    if (notherbuf == NULL)
+      notherbuf = xmalloc(DOWNLOADPACKETSIZE + 10);
+    if (strlen(str) + strlen(notherbuf) > DOWNLOADPACKETSIZE) {
+	/* No room in the packet, send it and start on a new one. */
+	send_packet(tmprid, notherbuf);
+	notherbuf[0] = '\0';
+	/* If the string is long, break it into multiple packets. */
+	while (strlen(str) > DOWNLOADPACKETSIZE) {
+	    strncpy(notherbuf, str, DOWNLOADPACKETSIZE);
+	    notherbuf[DOWNLOADPACKETSIZE] = '\0';
+	    send_packet(tmprid, notherbuf);
+	    notherbuf[0] = '\0';
+	    str += DOWNLOADPACKETSIZE;
+	}
     }
-    send_id(player->id);
-    /* Make it run everything up to the player setup phase. */
-    send_randstate(tmprid);
-    send_packet(tmprid, "Launch");
-    /* If errors, should set player rid back to zero */
+    strcat(notherbuf, str);
 }
 
 void
-send_randstate(id)
-int id;
+flush_write(void)
+{
+    if (!empty_string(notherbuf)) {
+	send_packet(tmprid, notherbuf);
+	notherbuf[0] = '\0';
+    }
+}
+
+void
+broadcast_game_module(void)
+{
+    int rid;
+
+    for_all_remotes(rid) {
+	if (rid != my_rid) {
+	    download_game_module(rid);
+	}
+    }
+}
+
+void
+broadcast_variants_chosen(void)
+{
+    /* Once variants have been chosen, programs will advance to making
+       trial assignments immediately, so make sure randstates are in
+       sync first. */
+    sprintf(spbuf, "R%ld", randstate);
+    broadcast_packet(spbuf); 
+    sprintf(spbuf, "vOK");
+    broadcast_packet(spbuf);
+}
+
+void
+broadcast_players_assigned(void)
+{
+    sprintf(spbuf, "aOK");
+    broadcast_packet(spbuf);
+}
+
+void
+send_randstate(int rid)
 {
     sprintf(spbuf, "R%ld", randstate);
-    send_packet(id, spbuf); 
+    send_packet(rid, spbuf); 
 }
 
 void
-send_game_checksum(id)
-int id;
+send_game_checksum(int rid)
 {
     sprintf(spbuf, "Z%d %d", my_rid, game_checksum());
-    send_packet(id, spbuf); 
+    send_packet(rid, spbuf); 
 }
 
 void
-broadcast_game_checksum()
+broadcast_game_checksum(void)
 {
     sprintf(spbuf, "Z%d %d", my_rid, game_checksum());
     broadcast_packet(spbuf); 
 }
 
+void
+send_game_checksum_error(int rid, int my_csum, int master_csum)
+{
+    sprintf(spbuf, "Echecksum %d %d %d", my_rid, my_csum, master_csum);
+    send_packet(rid, spbuf); 
+}
+
 time_t last_checksum_time;
 
 int
-net_run_game(maxactions)
-int maxactions;
+net_run_game(int maxactions)
 {
-    int oldsernum, oldstate, numdone = 0;
+    int oldsernum, oldstate, sendcheck, oldcsum, newcsum, numdone = 0;
     time_t now;
 
     if (my_rid == master_rid) {
 	if (numremotes > 0) {
 	    oldsernum = g_run_serial_number();
 	    oldstate = randstate;
-	    time(&now);
-	    if (idifftime(now, last_checksum_time) >= 2) {
-		broadcast_game_checksum();
-		last_checksum_time = now;
+	    /* Send occasional checksums at random times. */
+	    sendcheck = FALSE;
+	    if (0 /* for now */) {
+		time(&now);
+		sendcheck = (idifftime(now, last_checksum_time) >= 2);
+		if (sendcheck)
+		  last_checksum_time = now;
 	    }
+	    if (sendcheck)
+	      broadcast_game_checksum();
+	    oldcsum = game_checksum();
 	}
+	/* This is where the master's real run_game call happens. */
 	numdone = run_game(maxactions);
-	if (numremotes > 0 && numdone > 0) {
-	    sprintf(spbuf, "X%d %d %d", maxactions, oldsernum, oldstate);
-	    broadcast_packet(spbuf);
-	    broadcast_game_checksum();
+	if (numremotes > 0) {
+	    if (numdone > 0) {
+		sprintf(spbuf, "Za%d %d", my_rid, oldcsum);
+		broadcast_packet(spbuf); 
+		sprintf(spbuf, "X%d %d %d", maxactions, oldsernum, oldstate);
+		broadcast_packet(spbuf);
+		broadcast_game_checksum();
+	    } else {
+		newcsum = game_checksum();
+		if (newcsum != oldcsum)
+		  run_warning("Checksum changed %d -> %d when numdone == 0",
+			      oldcsum, newcsum);
+	    }
 	}
     }
     return numdone;
 }
 
 void
-net_request_additional_side(playerspec)
-char *playerspec;
+net_request_additional_side(char *playerspec)
 {
     if (my_rid == master_rid) {
 	request_additional_side(playerspec);
@@ -261,41 +541,26 @@ char *playerspec;
 }
 
 void
-net_send_message(side, sidemask, str)
-Side *side;
-SideMask sidemask;
-char *str;
+net_send_message(Side *side, SideMask sidemask, char *str)
 {
     if (my_rid == master_rid) {
 	send_message(side, sidemask, str);
     }
     if (numremotes > 0) {
-	broadcast_message(side, sidemask, str);
+	sprintf(spbuf, "M%d %d %s", side_number(side), sidemask, str);
+	broadcast_packet(spbuf);
     }
 }
 
 static void
-broadcast_message(side, sidemask, str)
-Side *side;
-SideMask sidemask;
-char *str;
-{
-    sprintf(spbuf, "M%d %d %s", side_number(side), sidemask, str);
-    broadcast_packet(spbuf);
-}
-
-static void
-broadcast_command_5(cmd, a1, a2, a3, a4, a5)
-char *cmd;
-int a1, a2, a3, a4, a5;
+broadcast_command_5(char *cmd, int a1, int a2, int a3, int a4, int a5)
 {
     sprintf(spbuf, "C%s %d %d %d %d %d", cmd, a1, a2, a3, a4, a5);
     broadcast_packet(spbuf);
 }
 
 void
-net_resign_game(side, side2)
-Side *side, *side2;
+net_resign_game(Side *side, Side *side2)
 {
     if (my_rid == master_rid) {
 	resign_game(side, side2);
@@ -308,9 +573,7 @@ Side *side, *side2;
 /* Side property tweaking. */
 
 void
-net_set_side_name(side, side2, newname)
-Side *side, *side2;
-char *newname;
+net_set_side_name(Side *side, Side *side2, char *newname)
 {
     if (my_rid == master_rid) {
 	set_side_name(side, side2, newname);
@@ -321,9 +584,7 @@ char *newname;
 }
 
 void
-net_set_side_longname(side, side2, newname)
-Side *side, *side2;
-char *newname;
+net_set_side_longname(Side *side, Side *side2, char *newname)
 {
     if (my_rid == master_rid) {
 	set_side_longname(side, side2, newname);
@@ -334,9 +595,7 @@ char *newname;
 }
 
 void
-net_set_side_shortname(side, side2, newname)
-Side *side, *side2;
-char *newname;
+net_set_side_shortname(Side *side, Side *side2, char *newname)
 {
     if (my_rid == master_rid) {
 	set_side_shortname(side, side2, newname);
@@ -347,9 +606,7 @@ char *newname;
 }
 
 void
-net_set_side_noun(side, side2, newname)
-Side *side, *side2;
-char *newname;
+net_set_side_noun(Side *side, Side *side2, char *newname)
 {
     if (my_rid == master_rid) {
 	set_side_noun(side, side2, newname);
@@ -360,9 +617,7 @@ char *newname;
 }
 
 void
-net_set_side_pluralnoun(side, side2, newname)
-Side *side, *side2;
-char *newname;
+net_set_side_pluralnoun(Side *side, Side *side2, char *newname)
 {
     if (my_rid == master_rid) {
 	set_side_pluralnoun(side, side2, newname);
@@ -373,9 +628,7 @@ char *newname;
 }
 
 void
-net_set_side_adjective(side, side2, newname)
-Side *side, *side2;
-char *newname;
+net_set_side_adjective(Side *side, Side *side2, char *newname)
 {
     if (my_rid == master_rid) {
 	set_side_adjective(side, side2, newname);
@@ -386,9 +639,7 @@ char *newname;
 }
 
 void
-net_set_side_emblemname(side, side2, newname)
-Side *side, *side2;
-char *newname;
+net_set_side_emblemname(Side *side, Side *side2, char *newname)
 {
     if (my_rid == master_rid) {
 	set_side_emblemname(side, side2, newname);
@@ -399,9 +650,7 @@ char *newname;
 }
 
 void
-net_set_side_colorscheme(side, side2, newname)
-Side *side, *side2;
-char *newname;
+net_set_side_colorscheme(Side *side, Side *side2, char *newname)
 {
     if (my_rid == master_rid) {
 	set_side_colorscheme(side, side2, newname);
@@ -412,8 +661,7 @@ char *newname;
 }
 
 void
-net_finish_turn(side)
-Side *side;
+net_finish_turn(Side *side)
 {
     if (my_rid == master_rid) {
 	finish_turn(side);
@@ -424,9 +672,7 @@ Side *side;
 }
 
 void
-net_set_trust(side, side2, val)
-Side *side, *side2;
-int val;
+net_set_trust(Side *side, Side *side2, int val)
 {
     if (my_rid == master_rid) {
 	set_trust(side, side2, val);
@@ -437,9 +683,7 @@ int val;
 }
 
 void
-net_set_mutual_trust(side, side2, val)
-Side *side, *side2;
-int val;
+net_set_mutual_trust(Side *side, Side *side2, int val)
 {
     if (my_rid == master_rid) {
 	set_mutual_trust(side, side2, val);
@@ -450,9 +694,7 @@ int val;
 }
 
 void
-net_set_controlled_by(side, side2, val)
-Side *side, *side2;
-int val;
+net_set_controlled_by(Side *side, Side *side2, int val)
 {
     if (my_rid == master_rid) {
 	set_controlled_by(side, side2, val);
@@ -463,9 +705,7 @@ int val;
 }
 
 void
-net_set_autofinish(side, value)
-Side *side;
-int value;
+net_set_autofinish(Side *side, int value)
 {
     if (my_rid == master_rid) {
 	set_autofinish(side, value);
@@ -1083,6 +1323,19 @@ net_set_capture_task(Unit *unit, int x, int y)
     }
 }
 
+void
+net_set_occupy_task(Unit *unit, Unit *transport)
+{
+    if (my_rid == master_rid) {
+	set_occupy_task(unit, transport);
+    }
+    if (numremotes > 0) {
+	tmptask = create_occupy_task(unit, transport);
+	broadcast_add_task(unit, CLEAR_AGENDA, tmptask);
+	free_task(tmptask);
+    }
+}
+
 void
 net_set_collect_task(unit, m, x, y)
 Unit *unit;
@@ -1503,10 +1756,8 @@ int x, y, r, dir, force;
 }
 
 static void
-broadcast_layer_change(layername, side, x, y, a1, a2, a3)
-char *layername;
-Side *side;
-int x, y, a1, a2, a3;
+broadcast_layer_change(char *layername, Side *side, int x, int y,
+		       int a1, int a2, int a3)
 {
     char buf[BUFSIZE];
 
@@ -1518,17 +1769,20 @@ int x, y, a1, a2, a3;
 #endif /* DESIGNERS */
 
 void
-send_quit()
+send_quit(void)
 {
-    broadcast_packet("Q");
+    /* (should have more error-handling, since may be called in bad
+       situations) */
+    sprintf(spbuf, "Q%d", my_rid);
+    broadcast_packet(spbuf);
+    flush_outgoing_queue();
 }
 
 /* Given a buffer with a packet in it, send it all the places that
    it should go. */
 
 static void
-broadcast_packet(buf)
-char *buf;
+broadcast_packet(char *buf)
 {
     int rid;
     extern int in_run_game;
@@ -1552,9 +1806,7 @@ char *buf;
    add checksum), send, and maybe wait for an acknowledgement. */
 
 int
-send_packet(id, inbuf)
-int id;
-char *inbuf;
+send_packet(int id, char *inbuf)
 {
     int i, j, csum, numtimeouts;
     char buf[BUFSIZE];
@@ -1602,7 +1854,7 @@ char *inbuf;
 	if (timeout_warnings)
 	  run_warning("Timed out waiting for ack");
 	++numtimeouts;
-	if (my_rid == master_rid) {
+	if (hosting && my_rid == master_rid) {
 	    /* If we're the master, we MUST be assured that our
 	       packets have been received, since we've already changed
 	       our own state and can't undo it. So we will loop here
@@ -1629,9 +1881,7 @@ struct q_entry {
 } *outgoing, *outgoing_last, *incoming, *incoming_last;
 
 static void
-save_outgoing_packet(id, inbuf)
-int id;
-char *inbuf;
+save_outgoing_packet(int id, char *inbuf)
 {
     struct q_entry *entry;
 
@@ -1647,7 +1897,7 @@ char *inbuf;
 }
 
 void
-flush_outgoing_queue()
+flush_outgoing_queue(void)
 {
     struct q_entry *entry;
 
@@ -1662,9 +1912,7 @@ flush_outgoing_queue()
 }
 
 static void
-save_incoming_packet(id, inbuf)
-int id;
-char *inbuf;
+save_incoming_packet(int id, char *inbuf)
 {
     struct q_entry *entry;
 
@@ -1680,7 +1928,7 @@ char *inbuf;
 }
 
 void
-flush_incoming_queue()
+flush_incoming_queue(void)
 {
     struct q_entry *entry;
 
@@ -1703,9 +1951,7 @@ static int nothing_count;
 static int nothing_timeout;
 
 static void
-remove_chars(buf, n)
-char *buf;
-int n;
+remove_chars(char *buf, int n)
 {
     int i;
 
@@ -1714,10 +1960,9 @@ int n;
 }
 
 void
-receive_data(timeout)
-int timeout;
+receive_data(int timeout)
 {
-    char buf[BUFSIZE], *pktend;
+    char buf[2000], *pktend;
     int retry = 10, gotsome, i, j, len, csum, pktcsum;
 
     /* (should have buffers for each remote prog) */
@@ -1843,15 +2088,13 @@ int timeout;
 }
 
 void
-receive_packet(id, buf)
-int id;
-char *buf;
+receive_packet(int id, char *buf)
 {
     int should_rebroadcast;
 
     Dprintf("From %d: \"%s\"\n", id, buf);
     if (downloading) {
-	if (strcmp(buf, "\neludoMemaG\n") == 0) {
+	if (strcmp(buf, "\neludoMemag\n") == 0) {
 	    /* We've seen the end-of-module marker, now interpret. */
 	    downloading = FALSE;
 	    mainmodule = get_game_module("*download*");
@@ -1863,8 +2106,7 @@ char *buf;
 	    /* Make all the cross-references right. */
 	    patch_object_references();
 	    check_game_validity();
-	    typesdefined = TRUE;
-	    make_trial_assignments();
+	    current_stage = variant_setup_stage;
 	} else {
 	    /* Make sure we have space with which to concatenate. */
 	    if (strlen(downloadbuf) + strlen(buf) >= 200000) {
@@ -1883,16 +2125,8 @@ char *buf;
 	  case 'C':
 	    receive_command(buf + 1);
 	    break;
-	  case 'G':
-	    downloading = TRUE;
-	    if (downloadbuf == NULL)
-	      downloadbuf = xmalloc(200000);
-	    downloadbuf[0] = '\0';
-	    should_rebroadcast = FALSE;
-	    break;
-	  case 'L':
-	    launch_game();
-	    /* This is only issued by the master, no need to rebroadcast. */
+	  case 'E':
+	    receive_error(buf + 1);
 	    should_rebroadcast = FALSE;
 	    break;
 	  case 'M':
@@ -1945,10 +2179,54 @@ char *buf;
 	    /* Checksums may be broadcast, but not automatically. */
 	    should_rebroadcast = FALSE;
 	    break;
-	  case 'j':	
-	    add_remote_player(buf + 1);
+	  case 'a':
+	    if (buf[1] == 'O' && buf[2] == 'K') {
+		current_stage = game_ready_stage;
+		/* This is only issued by the master, no need to
+                   rebroadcast. */
+		should_rebroadcast = FALSE;
+	    } else {
+		receive_assignment_setting(buf + 1);
+	    }
+	    break;
+	  case 'c':
+	    receive_chat(buf + 1);
+	    break;
+	  case 'g':
+	    downloading = TRUE;
+	    /* (should use obstack here) */
+	    if (downloadbuf == NULL)
+	      downloadbuf = xmalloc(200000);
+	    downloadbuf[0] = '\0';
 	    should_rebroadcast = FALSE;
 	    break;
+	  case 'j':
+	    send_remote_id(id);
+	    add_remote_program(id, buf + 1);
+	    /* Don't rebroadcast, the master will handle specially. */
+	    should_rebroadcast = FALSE;
+	    break;
+	  case 'p':
+	    receive_remote_program(buf + 1);
+	    current_stage = game_load_stage;
+	    /* This is only issued by the master, no need to rebroadcast. */
+	    should_rebroadcast = FALSE;
+	    break;
+	  case 'r':	
+	    my_rid = atoi(buf + 1);
+	    /* This is only issued by the master, no need to rebroadcast. */
+	    should_rebroadcast = FALSE;
+	    break;
+	  case 'v':
+	    if (buf[1] == 'O' && buf[2] == 'K') {
+		current_stage = player_setup_stage;
+		/* This is only issued by the master, no need to
+                   rebroadcast. */
+		should_rebroadcast = FALSE;
+	    } else {
+		receive_variant_setting(buf + 1);
+	    }
+	    break;
 	  default:
 	    /* Since the protocol's purpose is to keep multiple
 	       executables' state in sync, every kind of packet must
@@ -1956,14 +2234,15 @@ char *buf;
 	    run_warning("Packet not recognized: \"%s\"\n", buf);
 	    break;
 	}
+	/* The master should rebroadcast most types of packets
+	   automatically, so all programs stay in sync. */
 	if (my_rid == master_rid && should_rebroadcast)
 	  broadcast_packet(buf);
     }
 }
 
 static void
-receive_net_message(str)
-char *str;
+receive_net_message(char *str)
 {
     int id;
     char *nstr;
@@ -1982,8 +2261,7 @@ char *str;
 }
 
 static void
-receive_command(str)
-char *str;
+receive_command(char *str)
 {
     int i, args[5];
     char *nstr, *argstr;
@@ -2050,8 +2328,7 @@ char *str;
 }
 
 static void
-receive_action(str)
-char *str;
+receive_action(char *str)
 {
     int unitid, acteeid, i;
     char *nstr;
@@ -2091,8 +2368,7 @@ char *str;
 }
 
 static void
-receive_task(str)
-char *str;
+receive_task(char *str)
 {
     int unitid, pos, tasktype, i;
     char *nstr;
@@ -2129,8 +2405,7 @@ char *str;
 }
 
 static void
-receive_player_prop(str)
-char *str;
+receive_player_prop(char *str)
 {
     int val, val2;
     char *nstr;
@@ -2147,27 +2422,25 @@ char *str;
 	side = side_n(val);
 	if (side != NULL)
 	  side->player = find_player(val2);
-    } else if (strncmp(str, "you ", 4) == 0) {
-	str += 4;
-	val = strtol(str, &nstr, 10);
-	set_you_player(val);
-	/* This only comes from master, no need to rebroadcast. */
     } else {
 	run_warning("Unknown P packet \"%s\", ignoring", str);
     }
 }
 
 static void
-receive_quit(str)
-char *str;
+receive_quit(char *str)
 {
-    /* (should decide what kind of quit is happening) */
-    run_warning("Q packet received, should quit now");
+    int rid;
+    char *nstr;
+
+    rid = strtol(str, &nstr, 10);
+    Dprintf("Received quit from %d\n", rid);
+    online[rid] = FALSE;
+    quitter = rid;
 }
 
 static void
-receive_side_prop(str)
-char *str;
+receive_side_prop(char *str)
 {
     int id, sn, val;
     char *nstr;
@@ -2256,8 +2529,7 @@ char *str;
 }
 
 static void
-receive_unit_prop(str)
-char *str;
+receive_unit_prop(char *str)
 {
     int sid, uid, val, val2;
     char *nstr;
@@ -2343,8 +2615,7 @@ char *str;
 }
 
 static void
-receive_world_prop(str)
-char *str;
+receive_world_prop(char *str)
 {
     int id, x, y, a1, a2, a3;
     char *str2, *nstr;
@@ -2396,8 +2667,7 @@ char *str;
 }
 
 static void
-receive_run_game(str)
-char *str;
+receive_run_game(char *str)
 {
     int maxactions, newsernum;
     char *reststr, *nreststr;
@@ -2413,27 +2683,30 @@ char *str;
 	Dprintf("Rand state matches\n");
     }
     randstate = new_randstate;
+    /* This where non-masters actually call run_game. */
     run_game(maxactions);
 }
 
 static void
-receive_game_checksum(str)
-char *str;
+receive_game_checksum(char *str)
 {
-    int other_rid, other_csum, our_csum;
+    int before_run = FALSE, other_rid, other_csum, our_csum;
     char *reststr, *nreststr;
 
+    if (*str == 'a') {
+	before_run = TRUE;
+	++str;
+    }
     other_rid = strtol(str, &reststr, 10);
     other_csum = strtol(reststr, &nreststr, 10);
     our_csum = game_checksum();
     if (our_csum != other_csum) {
-#if 0 /* should use a distinct message */
-	/* If we're about to lose, make sure everybody else knows it. */
+	/* If we're about to lose, make sure the master knows about it. */
 	if (my_rid != master_rid)
-	  send_game_checksum(master_rid);
-#endif
-	run_warning("Game is out of sync! (received %d from %d, computed %d)",
-		    other_csum, other_rid, our_csum);
+	  send_game_checksum_error(master_rid, our_csum, other_csum);
+	run_warning("Game is out of sync! (received %d from %d, computed %d%s)",
+		    other_csum, other_rid, our_csum,
+		    (before_run ? ", before run_game" : ""));
     }
 }
 
@@ -2441,8 +2714,8 @@ char *str;
 
 #define add_int_to_checksum(cs, x) ((cs) += (x));
 
-static int
-game_checksum()
+int
+game_checksum(void)
 {
     int csum, i;
     Side *side;
@@ -2493,11 +2766,107 @@ game_checksum()
     return csum;
 }
 
+static void
+receive_error(char *str)
+{
+    Dprintf("Error reported, %s\n", str);
+}
+
+static void
+receive_remote_program(char *str)
+{
+    int rid;
+    char *nstr;
+
+    rid = strtol(str, &nstr, 10);
+    str = nstr + 1;
+    numremotes = max(rid, numremotes);
+    online[rid] = TRUE;
+    remote_player_specs[rid] = copy_string(str);
+    /* (should do with a function pointer) */
+    add_remote_locally(rid, str);
+}
+
+static void
+receive_chat(char *str)
+{
+    int rid;
+    char *nstr;
+
+    rid = strtol(str, &nstr, 10);
+    str = nstr + 1;
+    /* (should do with a function pointer) */
+    send_chat(rid, str);
+}
+
+static void
+receive_variant_setting(char *str)
+{
+    int i, v1, v2, v3, v4, v5;
+    char *nstr;
+
+    ++str;
+    i = strtol(str, &nstr, 10);
+    str = nstr + 1;
+    v1 = strtol(str, &nstr, 10);
+    str = nstr + 1;
+    v2 = strtol(str, &nstr, 10);
+    str = nstr + 1;
+    v3 = strtol(str, &nstr, 10);
+    str = nstr + 1;
+    v4 = strtol(str, &nstr, 10);
+    str = nstr + 1;
+    v5 = strtol(str, &nstr, 10);
+    if (update_variant_callback)
+      (*update_variant_callback)(i, v1, v2, v3, v4, v5);
+}
+
+static void
+receive_assignment_setting(char *str)
+{
+    int n, n2, val;
+    char *nstr, *aitype;
+    Player *player;
+
+    n = strtol(str, &nstr, 10);
+    str = nstr;
+    ++str;
+    if (strncmp(str, "add", 3) == 0) {
+	n = add_side_and_player();
+    } else if (strncmp(str, "advantage ", 10) == 0) {
+	val = strtol(str + 10, NULL, 10);
+	player = assignments[n].player;
+	if (player != NULL) {
+	    player->advantage = val;
+	}
+    } else if (strncmp(str, "ai ", 3) == 0) {
+	if (str[3] == '\0')
+	  aitype = NULL;
+	else
+	  aitype = copy_string(str + 3);
+	set_ai_for_player(n, aitype);
+    } else if (strncmp(str, "exchange ", 9) == 0) {
+	n2 = strtol(str + 9, NULL, 10);
+	n2 = exchange_players(n, n2);
+	if (update_assignment_callback)
+	  (*update_assignment_callback)(n2);
+    } else if (strncmp(str, "rename", 6) == 0) {
+	rename_side_for_player(n);
+    } else {
+	/* (should complain) */
+    }
+    if (n >= 0) {
+	/* Most settings affect the same assignment, so always update it
+	   here. */
+	if (update_assignment_callback)
+	  (*update_assignment_callback)(n);
+    }
+}
+
 /* Convert hex digit A to a number.  */
 
 static int
-fromhex(a)
-int a;
+fromhex(int a)
 {
     if (a >= '0' && a <= '9')
       return a - '0';
@@ -2511,8 +2880,7 @@ int a;
 /* Convert number NIB to a hex digit.  */
 
 static int
-tohex(nib)
-int nib;
+tohex(int nib)
 {
     if (nib < 10)
       return '0' + nib;
@@ -2530,11 +2898,10 @@ static FILE *outport;
 static char *sendbuf;
 
 void
-init_file_port(hosting)
-int hosting;
+init_file_port(int ishost)
 {
     /* Just use wired-in filenames, since only for debugging. */
-    if (hosting) {
+    if (ishost) {
 	inport_filename = "server.in";
 	outport_filename = "server.out";
     } else {
@@ -2547,7 +2914,7 @@ int hosting;
       run_warning("connection files opening failed");
     /* (should be able to get all the rids from file) */
     master_rid = 1;
-    if (hosting) {
+    if (ishost) {
 	my_rid = 1;
     } else {
 	my_rid = 2;
@@ -2556,9 +2923,7 @@ int hosting;
 }
 
 void
-low_file_send(rid, buf)
-int rid;
-char *buf;
+low_file_send(int rid, char *buf)
 {
     int i, j, len;
 
@@ -2585,10 +2950,7 @@ char *buf;
 }
 
 int
-low_file_receive(idp, buf, maxchars, timeout)
-int *idp;
-char *buf;
-int maxchars, timeout;
+low_file_receive(int *idp, char *buf, int maxchars, int timeout)
 {
     int rslt = FALSE, i, j, len;
     char readbuf[BUFSIZE], *str;
@@ -2635,7 +2997,7 @@ int maxchars, timeout;
 }
 
 void
-close_file_port()
+close_file_port(void)
 {
     fclose(inport);
     fclose(outport);
