@@ -1522,6 +1522,8 @@ Unit *unit;
 {
     int uview;
 
+	if (side == NULL)
+	  side = indepside;
     if (!in_play(unit))
       return FALSE;
     if (unit->side == side)
@@ -1570,15 +1572,16 @@ int x, y;
    ones where the wind in any adjacent cell is different. */
 
 int
-draw_winds_here(side, x, y)
-Side *side;
-int x, y;
+draw_winds_here(Side *side, int x, int y)
 {
     int dir, x1, y1, windhere = wind_view(side, x, y);
 
     /* Designers should see wind in every cell. */
     if (is_designer(side))
       return TRUE;
+    /* Don't draw wind in unseen areas. */
+    if (terrain_view(side, x, y) == UNSEEN)
+      return FALSE;
     for_all_directions(dir) {
 	if (interior_point_in_dir(x, y, dir, &x1, &y1)) {
 	    if (windhere != wind_view(side, x1, y1))
@@ -2217,10 +2220,41 @@ short *amts, *rslts;
 	    neededsome = TRUE;
 	    unit2 = unit->transport;
 	    if (in_play(unit2) && completed(unit2)) {
-		/* Be stingy if transport is low */
-		if (2 * unit2->supply[m] < um_storage_x(unit2->type, m))
-		  want = max(1, want/2);
-		actual = transfer_supply(unit2, unit, m, want);
+	    	
+	    	/* Bug fix. Units inside a transport inside a base or city were
+	    	previously unable to resupply directly from the base. Now the 
+	    	occ checks if the transport is inside a base and then resupplies 
+	    	directly from it. Moreover, the 'stingy' 50% left principle is 
+	    	applied only to units that need m themselves. Other units are 
+	    	free to give away all their supply. */
+	    
+	         Unit	*base = unit2->transport;
+		int	request = want;				
+
+		/* First take as much supplies as possible from the transport's 
+		transport (the base) if it exists. */
+		actual = 0;
+	         if (in_play(base) && completed(base)) {
+			/* Be stingy if base is low (but only if it also needs m). */
+			if (2 * base->supply[m] < um_storage_x(base->type, m)
+			    && (um_base_consumption(base->type, m) > 0 
+			         || um_consumption_per_move(base->type, m) > 0)) {		    			
+				request = max(1, want/2);
+			}
+			actual += transfer_supply(base, unit, m, request);
+			want -= actual;
+		}
+		/* If still unsatisfied, also take supplies from transport. */
+		if (want) {
+			request = want;
+			/* Be stingy if transport is low (but only if it also needs m). */
+			if (2 * unit2->supply[m] < um_storage_x(unit2->type, m)
+			    && (um_base_consumption(unit2->type, m) > 0 
+			         || um_consumption_per_move(unit2->type, m) > 0)) {		    			
+				request = max(1, want/2);
+			}
+			actual += transfer_supply(unit2, unit, m, want);
+		}
 		if (rslts)
 		  rslts[m] = actual;
 	    }
@@ -2279,7 +2313,7 @@ add_default_unit_image(ImageFamily *imf, int u)
     int i, hi, lo;
     Image *img;
 
-    img = get_img(imf, 16, 16, 0);
+    img = get_img(imf, 16, 16);
     if (img == NULL)
       return imf;
     img->rawmonodata = xmalloc(32);
@@ -2336,7 +2370,7 @@ int t;
 {
     Image *img;
 
-    img = get_img(imf, 8, 8, 0);
+    img = get_img(imf, 8, 8);
     img->istile = TRUE;
     img->rawmonodata = xmalloc(8);
     (img->rawmonodata)[1] = (t << 2);
@@ -2401,7 +2435,7 @@ add_default_emblem_image(ImageFamily *imf, int s2)
     int i;
     Image *img;
 
-    img = get_img(imf, 8, 8, 0);
+    img = get_img(imf, 8, 8);
     if (img == NULL)
       return imf;
     img->rawmonodata = xmalloc(8);
