@@ -1,5 +1,5 @@
 /* Definitions relating to units in Xconq.
-   Copyright (C) 1987-1989, 1991-1998 Stanley T. Shebs.
+   Copyright (C) 1987-1989, 1991-1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -8,13 +8,6 @@ any later version.  See the file COPYING.  */
 
 /* Advanced unit support. */
 extern short default_size; 
-
-// --- REPLACED BY u_reach ------------------------------
-
-// 	extern short default_reach; 
-
-// --------------------------------------------------
-
 extern short default_usedcells; 
 extern short default_maxcells; 
 extern long default_population; 
@@ -67,15 +60,11 @@ typedef struct a_unit {
     short maxcells;		/* Max number of cells that unit can use */
     short curadvance;		/* Advance currently being researched. */ 
     long population;		/* Size of units population */
-
-// --- ADVANCED UNIT SUPPORT --------------------------------------
-
     short *production;		/* Cache of units last production. */
     short autobuild;		/* True if building on automatic. */
     short autoresearch;		/* True if research on automatic. */
-
-// ------------------------------------------------------------
-
+    short autoplan;		/* True if planning on automatic. */
+    short cp_stash;		/* Stash of cps recovered from incomplete build tasks. */
 } Unit;
 
 /* The unit extras structure stores properties that are (usually)
@@ -119,6 +108,28 @@ typedef struct a_unit_extras {
 #define for_all_occupants(u1,v) \
   for (v = (u1)->occupant; v != NULL; v = v->nexthere)
 
+/* Iterate through all occupants including occs within occs within occs within (u). */
+
+/* This nifty little macro will climb the occupant : nexthere tree and follow all 
+branches three levels below (u) to find all the occs within occs within occs within (u). 
+The test for (var) != (u)->nexthere is to stop the macro from climbing up above (u). */ 
+
+#define for_all_occs_with_occs(u,var)  \
+  for ((var) = (u)->occupant; \
+          (var) != NULL && \
+          (var) != (u)->nexthere; \
+  	 (var) = ((var)->occupant != NULL ? \
+  	 	        (var)->occupant : \
+  	 	      ((var)->nexthere != NULL ? \
+  	 	        (var)->nexthere : \
+  		      ((var)->transport != NULL && \
+  		        (var)->transport->nexthere != NULL ? \
+  		        (var)->transport->nexthere : \
+  		      ((var)->transport != NULL && \
+  		        (var)->transport->transport != NULL && \
+  		        (var)->transport->transport->nexthere != NULL ? \
+  		        (var)->transport->transport->nexthere : NULL)))))
+
 #define is_unit(unit) ((unit) != NULL && is_unit_type((unit)->type))
 
 #define alive(unit) ((unit)->hp > 0)
@@ -134,11 +145,11 @@ typedef struct a_unit_extras {
 
 /* Extractor for the actual altitude of an airborne unit. */
 
-#define unit_alt(unit) ((unit)->z & 1 == 0 ? ((unit)->z >> 1) : 0)
+#define unit_alt(unit) (((unit)->z & 1) == 0 ? ((unit)->z >> 1) : 0)
 
 /* Extractor for the connection a unit is on. */
 
-#define unit_conn(unit) ((unit)->z & 1 == 1 ? ((unit)->z >> 1) : NONTTYPE)
+#define unit_conn(unit) (((unit)->z & 1) == 1 ? ((unit)->z >> 1) : NONTTYPE)
 
 /* This is true if the unit is on the board somewhere. */
 
@@ -255,13 +266,6 @@ typedef struct a_actiondefn {
     ActionType typecode;
     char *name;
     char *argtypes;
-#ifdef THINK_C
-    int (*dofn) PARAMS ((Unit *unit, Unit *unit2, ...));
-    int (*checkfn) PARAMS ((Unit *unit, Unit *unit2, ...));
-#else
-    int (*dofn) PARAMS (());
-    int (*checkfn) PARAMS (());
-#endif
 } ActionDefn;
 
 #define MAXACTIONARGS 4
@@ -319,11 +323,11 @@ typedef struct a_goal {
     short args[MAXGOALARGS];
 } Goal;
 
-extern Goal *create_goal PARAMS ((GoalType type, Side *side, int tf));
-extern int cell_unknown PARAMS ((int x, int y));
-extern int enemies_present PARAMS ((int x, int y));
-extern int goal_truth PARAMS ((Side *side, Goal *goal));
-extern char *goal_desig PARAMS ((Goal *goal));
+extern Goal *create_goal(GoalType type, Side *side, int tf);
+extern int cell_unknown(int x, int y);
+extern int enemies_present(int x, int y);
+extern int goal_truth(Side *side, Goal *goal);
+extern char *goal_desig(Goal *goal);
 
 /* A task is a single executable element of a unit's plan.  Each task type
    is something that has been found useful or convenient to encapsulate as
@@ -360,7 +364,7 @@ typedef struct a_task {
 typedef struct a_taskdefn {
     char *name;
     char *argtypes;
-    TaskOutcome (*exec) PARAMS ((Unit *unit, Task *task));
+    TaskOutcome (*exec)(Unit *unit, Task *task);
 } TaskDefn;
 
 #define is_task_type(x) (between(0, (x), NUMTASKTYPES - 1))
@@ -433,168 +437,167 @@ extern char *plantypenames[];
 
 /* Declarations of unit-related functions. */
 
-extern void init_units PARAMS ((void));
-extern Unit *create_bare_unit PARAMS ((int type));
-extern Unit *create_unit PARAMS ((int type, int makebrains));
-extern void init_unit_actorstate PARAMS ((Unit *unit, int flagacp));
-extern void init_unit_plan PARAMS ((Unit *unit));
-extern void init_unit_tooling PARAMS ((Unit *unit));
-extern void init_unit_opinions PARAMS ((Unit *unit, int nsides));
-extern void init_unit_extras PARAMS ((Unit *unit));
-extern void change_unit_type PARAMS ((Unit *unit, int newtype, int reason));
-extern int max_builds PARAMS ((int u));
-extern int enter_cell PARAMS ((Unit *unit, int x, int y));
-extern int can_occupy_cell PARAMS ((Unit *unit, int x, int y));
-extern int type_can_occupy_cell PARAMS ((int u, int x, int y));
-extern int can_occupy_cell_without PARAMS ((Unit *unit, int x, int y, Unit *unit3));
-extern int type_can_occupy_cell_without PARAMS ((int u, int x, int y, Unit *unit3));
-extern void enter_cell_aux PARAMS ((Unit *unit, int x, int y));
-extern int can_occupy PARAMS ((Unit *unit, Unit *transport));
-extern int can_carry PARAMS ((Unit *transport, Unit *unit));
-extern int type_can_occupy PARAMS ((int u, Unit *transport));
-extern int can_occupy_type PARAMS ((Unit *unit, int u2));
-extern int can_carry_type PARAMS ((Unit *transport, int u));
-extern void enter_transport PARAMS ((Unit *unit, Unit *transport));
-extern void leave_cell PARAMS ((Unit *unit));
-extern void leave_transport PARAMS ((Unit *unit));
-extern void eject_excess_occupants PARAMS ((Unit *unit));
-extern void eject_occupant PARAMS ((Unit *unit, Unit *occ));
+extern void init_units(void);
+extern Unit *create_bare_unit(int type);
+extern Unit *create_unit(int type, int makebrains);
+extern void init_unit_actorstate(Unit *unit, int flagacp);
+extern void init_unit_plan(Unit *unit);
+extern void init_unit_tooling(Unit *unit);
+extern void init_unit_opinions(Unit *unit, int nsides);
+extern void init_unit_extras(Unit *unit);
+extern void change_unit_type(Unit *unit, int newtype, int reason);
+extern int max_builds(int u);
+extern int enter_cell(Unit *unit, int x, int y);
+extern int can_occupy_cell(Unit *unit, int x, int y);
+extern int type_can_occupy_cell(int u, int x, int y);
+extern int can_occupy_cell_without(Unit *unit, int x, int y, Unit *unit3);
+extern int type_can_occupy_cell_without(int u, int x, int y, Unit *unit3);
+extern void enter_cell_aux(Unit *unit, int x, int y);
+extern int can_occupy(Unit *unit, Unit *transport);
+extern int can_carry(Unit *transport, Unit *unit);
+extern int type_can_occupy(int u, Unit *transport);
+extern int can_occupy_type(Unit *unit, int u2);
+extern int can_carry_type(Unit *transport, int u);
+extern void enter_transport(Unit *unit, Unit *transport);
+extern void leave_cell(Unit *unit);
+extern void leave_transport(Unit *unit);
+extern void eject_excess_occupants(Unit *unit);
+extern void eject_occupant(Unit *unit, Unit *occ);
+extern int new_unit_allowed_on_side(int u, Side *side);
+extern int unit_allowed_on_side(Unit *unit, Side *side);
+extern int test_class_membership(Obj *leaf);
+extern int type_allowed_on_side(int u, Side *side);
+extern int type_ever_available(int u, Side *side);
+extern int unit_trusts_unit(Unit *unit1, Unit *unit2);
+extern void dispose_of_plan(Unit *unit);
+extern void flush_dead_units(void);
+extern void sort_units(int byidonly);
+extern int moves_till_low_supplies(Unit *unit);
+extern char *unit_desig(Unit *unit);
+extern char *unit_desig_no_loc(Unit *unit);
+extern char *utype_name_n(int u, int n);
+extern char *shortest_unique_name(int u);
+extern char *shortest_generic_name(int u);
+extern char *actorstate_desig(struct a_actorstate *as);
+extern Unit *find_unit(int n);
+extern Unit *find_unit_dead_or_alive(int n);
+extern Unit *find_unit_by_name(char *nm);
+extern Unit *find_unit_by_number(int nb);
+extern Unit *find_unit_by_symbol(Obj *sym);
+extern int find_unit_name(char *str);
+extern void insert_unit(Unit *unithead, Unit *unit);
+extern void delete_unit(Unit *unit);
+extern int num_occupants(Unit *unit);
+extern int num_units_at(int x, int y);
+extern void check_all_units(void);
+extern void check_unit(Unit *unit);
+extern UnitVector *make_unit_vector(int initsize);
+extern void clear_unit_vector(UnitVector *vec);
+extern UnitVector *add_unit_to_vector(UnitVector *vec, Unit *unit, int flag);
+extern void remove_unit_from_vector(UnitVector *vec, Unit *unit, int pos);
+extern void sort_unit_vector(UnitVector *vec);
+extern Obj *get_x_property(Unit *unit, int subkey);
+extern Obj *get_x_property_by_name(Unit *unit, char *str);
 
-// --- INDEPENDENT GHOST UNIT BUG FIX ---------------------------------
+extern int disband_unit_directly(Side *side, Unit *unit);
 
-extern int new_unit_allowed_on_side PARAMS ((int u, Side *side));
-
-// --------------------------------------------------------------
-
-extern int unit_allowed_on_side PARAMS ((Unit *unit, Side *side));
-extern int test_class_membership PARAMS ((Obj *leaf));
-extern int type_allowed_on_side PARAMS ((int u, Side *side));
-extern int unit_trusts_unit PARAMS ((Unit *unit1, Unit *unit2));
-extern void dispose_of_plan PARAMS ((Unit *unit));
-extern void flush_dead_units PARAMS ((void));
-extern void sort_units PARAMS ((int byidonly));
-extern int moves_till_low_supplies PARAMS ((Unit *unit));
-extern char *unit_desig PARAMS ((Unit *unit));
-extern char *unit_desig_no_loc PARAMS ((Unit *unit));
-extern char *utype_name_n PARAMS ((int u, int n));
-extern char *shortest_unique_name PARAMS ((int u));
-extern char *shortest_generic_name PARAMS ((int u));
-extern char *actorstate_desig PARAMS ((struct a_actorstate *as));
-extern Unit *find_unit PARAMS ((int n));
-extern Unit *find_unit_dead_or_alive PARAMS ((int n));
-extern Unit *find_unit_by_name PARAMS ((char *nm));
-extern Unit *find_unit_by_number PARAMS ((int nb));
-extern Unit *find_unit_by_symbol PARAMS ((Obj *sym));
-extern int find_unit_name PARAMS ((char *str));
-extern void insert_unit PARAMS ((Unit *unithead, Unit *unit));
-extern void delete_unit PARAMS ((Unit *unit));
-extern int num_occupants PARAMS ((Unit *unit));
-extern int num_units_at PARAMS ((int x, int y));
-extern void check_all_units PARAMS ((void));
-extern void check_unit PARAMS ((Unit *unit));
-extern UnitVector *make_unit_vector PARAMS ((int initsize));
-extern void clear_unit_vector PARAMS ((UnitVector *vec));
-extern UnitVector *add_unit_to_vector PARAMS ((UnitVector *vec, Unit *unit, int flag));
-extern void remove_unit_from_vector PARAMS ((UnitVector *vec, Unit *unit, int pos));
-extern void sort_unit_vector PARAMS ((UnitVector *vec));
-extern Obj *get_x_property PARAMS ((Unit *unit, int subkey));
-extern Obj *get_x_property_by_name PARAMS ((Unit *unit, char *str));
-
-extern int disband_unit_directly PARAMS ((Side *side, Unit *unit));
-
-extern void add_unit_to_stack PARAMS ((Unit *unit, int x, int y));
-extern void remove_unit_from_stack PARAMS ((Unit *unit));
-extern void glimpse_adjacent_terrain PARAMS ((Unit *unit));
-extern void add_to_unit_hp PARAMS ((Unit *unit, int hp));
-extern void wreck_unit PARAMS ((Unit *unit));
+extern void add_unit_to_stack(Unit *unit, int x, int y);
+extern void remove_unit_from_stack(Unit *unit);
+extern void glimpse_adjacent_terrain(Unit *unit);
+extern void add_to_unit_hp(Unit *unit, int hp);
+extern void wreck_unit(Unit *unit);
 
 /* Declarations of plan-related functions. */
 
-extern int move_into_formation PARAMS ((Unit *unit));
-extern int victim_here PARAMS ((int x, int y));
-extern int worth_capturing PARAMS ((Side *side, int u2, Side *oside, int x, int y));
-extern int target_here PARAMS ((int x, int y));
-extern int supplies_here PARAMS ((Unit *unit, int x, int y, int m));
-extern int indep_captureable_here PARAMS ((int x, int y));
-extern int useful_captureable_here PARAMS ((int x, int y));
-extern int useful_type PARAMS ((Side *side, int u));
-extern int could_capture_any PARAMS ((int u));
-extern void make_plausible_random_args PARAMS ((char *argtypestr, int i, short *args, Unit *unit));
-extern int range_left PARAMS ((Unit *unit));
-extern int find_worths PARAMS ((int range));
-extern int attack_worth PARAMS ((Unit *unit, int e));
-extern int threat PARAMS ((Side *side, int u, int x0, int y0));
-extern int react_to_enemies PARAMS ((Unit *unit));
-extern int move_patrol PARAMS ((Unit *unit));
-extern int build_time PARAMS ((Unit *unit, int prod));
-extern Plan *create_plan PARAMS ((void));
-extern void free_plan PARAMS ((Plan *plan));
-extern char *plan_desig PARAMS ((Plan *plan));
-extern int might_be_captured PARAMS ((Unit *unit));
-extern int occupant_could_capture PARAMS ((Unit *unit, int etype));
-extern int can_capture_neighbor PARAMS ((Unit *unit));
-extern int occupant_can_capture_neighbor PARAMS ((Unit *unit));
-extern int find_closest_unit PARAMS ((Side *side, int x0, int y0, int maxdist, int (*pred)(void), int *rxp, int *ryp));
-extern int fullness PARAMS ((Unit *unit));
-extern int can_build PARAMS ((Unit *unit));
-extern int can_move PARAMS ((Unit *unit));
-extern int out_of_ammo PARAMS ((Unit *unit));
-extern int survival_time PARAMS ((Unit *unit));
-extern int usable_cell PARAMS ((Unit *unit, int x, int y));
-extern int explorable_cell PARAMS ((int x, int y));
-extern int reachable_unknown PARAMS ((int x, int y));
-extern int adj_known_ok_terrain PARAMS ((int x, int y, Side *side, int u));
-extern int should_capture_maker PARAMS ((Unit *unit));
-extern int no_possible_moves PARAMS ((Unit *unit));
-extern int normal_completion_time PARAMS ((int u, int u2));
-extern int adj_unit PARAMS ((int x, int y));
-extern int past_halfway_point PARAMS ((Unit *unit));
+extern int move_into_formation(Unit *unit);
+extern int victim_here(int x, int y);
+extern int worth_capturing(Side *side, int u2, Side *oside, int x, int y);
+extern int target_here(int x, int y);
+extern int supplies_here(Unit *unit, int x, int y, int m);
+extern int indep_captureable_here(int x, int y);
+extern int useful_captureable_here(int x, int y);
+extern int useful_type(Side *side, int u);
+extern int could_capture_any(int u);
+extern void make_plausible_random_args(char *argtypestr, int i, short *args, Unit *unit);
+extern int range_left(Unit *unit);
+extern int find_worths(int range);
+extern int attack_worth(Unit *unit, int e);
+extern int threat(Side *side, int u, int x0, int y0);
+extern int react_to_enemies(Unit *unit);
+extern int move_patrol(Unit *unit);
+extern int build_time(Unit *unit, int prod);
+extern Plan *create_plan(void);
+extern void free_plan(Plan *plan);
+extern char *plan_desig(Plan *plan);
+extern int might_be_captured(Unit *unit);
+extern int occupant_could_capture(Unit *unit, int etype);
+extern int can_capture_neighbor(Unit *unit);
+extern int occupant_can_capture_neighbor(Unit *unit);
+extern int find_closest_unit(Side *side, int x0, int y0, int maxdist, int (*pred)(int x, int y), int *rxp, int *ryp);
+extern int fullness(Unit *unit);
+extern int can_build(Unit *unit);
+extern int can_move(Unit *unit);
+extern int out_of_ammo(Unit *unit);
+extern int survival_time(Unit *unit);
+extern int usable_cell(Unit *unit, int x, int y);
+extern int explorable_cell(int x, int y);
+extern int reachable_unknown(int x, int y);
+extern int adj_known_ok_terrain(int x, int y, Side *side, int u);
+extern int should_capture_maker(Unit *unit);
+extern int no_possible_moves(Unit *unit);
+extern int normal_completion_time(int u, int u2);
+extern int adj_unit(int x, int y);
+extern int past_halfway_point(Unit *unit);
 
-extern int self_build_base_for_self PARAMS ((Unit *unit));
+extern int self_build_base_for_self(Unit *unit);
 
-extern int operating_range_worst PARAMS ((int u));
-extern int operating_range_best PARAMS ((int u));
+extern int operating_range_worst(int u);
+extern int operating_range_best(int u);
 
-extern int terrain_always_impassable PARAMS ((int u, int t));
+extern int terrain_always_impassable(int u, int t);
 
-extern int execute_standing_order PARAMS ((Unit *unit, int addtask));
-extern int can_build_or_help PARAMS ((Unit *unit));
-extern int can_produce PARAMS ((Unit *unit));
-extern int low_on_supplies_one PARAMS ((Unit *unit));
-extern int low_on_ammo_one PARAMS ((Unit *unit));
+extern int execute_standing_order(Unit *unit, int addtask);
+extern int can_build_or_help(Unit *unit);
+extern int can_produce(Unit *unit);
+extern int low_on_supplies_one(Unit *unit);
+extern int low_on_ammo_one(Unit *unit);
 
-extern void set_waiting_for_tasks PARAMS ((Unit *unit, int flag));
+extern void set_waiting_for_tasks(Unit *unit, int flag);
 
-extern int execute_standing_order PARAMS ((Unit *unit, int addtask));
+extern int execute_standing_order(Unit *unit, int addtask);
 
 /* Declarations of task-related functions. */
 
-extern void init_tasks PARAMS ((void));
-extern void allocate_task_block PARAMS ((void));
-extern Task *create_task PARAMS ((TaskType type));
-extern Task *clone_task PARAMS ((Task *oldtask));
-extern int fire_can_damage PARAMS ((Unit *unit, Unit *unit2));
-extern Unit *repair_here PARAMS ((int x, int y));
-extern Unit *aux_resupply_here PARAMS ((Unit *unit));
-extern Unit *resupply_here PARAMS ((int x, int y));
-extern int can_auto_resupply_self PARAMS ((Unit *unit, int *materials, int numtypes));
-extern int choose_move_dirs PARAMS ((Unit *unit, int tx, int ty, int shortest, int (*dirtest)(Unit *, int), void (*dirsort)(Unit *, int *, int), int *dirs));
-extern int plausible_move_dir PARAMS ((Unit *unit, int dir));
-extern void sort_directions PARAMS ((Unit *unit, int *dirs, int numdirs));
-extern void free_task PARAMS ((Task *task));
-extern char *parse_task PARAMS ((Side *side, char *str, Task **taskp));
-extern char *task_desig PARAMS ((Task *task));
-extern Unit *find_unit_to_complete PARAMS ((Unit *unit, Task *task));
+extern void init_tasks(void);
+extern void allocate_task_block(void);
+extern Task *create_task(TaskType type);
+extern Task *clone_task(Task *oldtask);
+extern int fire_can_damage(Unit *unit, Unit *unit2);
+extern Unit *repair_here(int x, int y);
+extern Unit *aux_resupply_here(Unit *unit);
+extern Unit *resupply_here(int x, int y);
+extern int can_auto_resupply_self(Unit *unit, int *materials, int numtypes);
+extern int choose_move_dirs(Unit *unit, int tx, int ty, int shortest, int (*dirtest)(Unit *, int), void (*dirsort)(Unit *, int *, int), int *dirs);
+extern int plausible_move_dir(Unit *unit, int dir);
+extern void sort_directions(Unit *unit, int *dirs, int numdirs);
+extern void free_task(Task *task);
+extern char *parse_task(Side *side, char *str, Task **taskp);
+extern char *task_desig(Task *task);
+extern Unit *find_unit_to_complete(Unit *unit, Task *task);
+
+extern int real_capture_chance(Unit *unit, Unit *unit2);
+extern int attack_can_damage_or_capture(Unit *unit, Unit *unit2);
+extern int fire_can_damage_or_capture(Unit *unit, Unit *unit2);
 
 #undef  DEF_ACTION
 #define DEF_ACTION(name,code,args,prepfn,netprepfn,dofn,CHECKFN,ARGDECL,doc)  \
-  extern int CHECKFN PARAMS (ARGDECL);
+  extern int CHECKFN ARGDECL;
 
 #include "action.def"
 
 #undef  DEF_TASK
 #define DEF_TASK(name,code,argtypes,dofn,CREATEFN,setfn,netsetfn,pushfn,netpushfn,ARGDECL)  \
-  extern Task *CREATEFN PARAMS (ARGDECL);
+  extern Task *CREATEFN ARGDECL;
 
 #include "task.def"
 
