@@ -27,20 +27,14 @@ any later version.  See the file COPYING.  */
 #include <errno.h>
 #include <fcntl.h>
 
+/* (should not include these anymore?) */
 #include <sys/file.h>
 #include <netinet/in.h>
 #include <sys/socket.h>
 #include <netdb.h>
-#ifndef __CYGWIN32__
-# include <netinet/tcp.h>
-#endif
+#include <netinet/tcp.h>
 #include <sys/ioctl.h>
 
-extern int numremotes;
-extern int my_rid;
-extern int master_rid;
-extern int tmprid;
-
 extern void close_displays(void);
 
 /* Default names for places in Unix. */
@@ -72,7 +66,7 @@ static char *score_file_pathname(char *name);
 uid_t games_uid;
 
 char *
-default_library_pathname()
+default_library_pathname(void)
 {
     char *name;
 
@@ -84,7 +78,7 @@ default_library_pathname()
 }
 
 char *
-default_images_pathname()
+default_images_pathname(void)
 {
     char *name;
 
@@ -96,7 +90,7 @@ default_images_pathname()
 }
 
 char *
-news_filename()
+news_filename(void)
 {
     /* (should search in library list) */
     make_pathname(xconq_libs->path, NEWSFILE, "", spbuf);
@@ -106,7 +100,7 @@ news_filename()
 static char *savegamename;
 
 char *
-saved_game_filename()
+saved_game_filename(void)
 {
     if (savegamename == NULL)
       savegamename = game_filename("XCONQSAVEFILE", SAVEFILE);
@@ -116,7 +110,7 @@ saved_game_filename()
 static char *checkgamename;
 
 char *
-checkpoint_filename()
+checkpoint_filename(void)
 {
     if (checkgamename == NULL)
       checkgamename = game_filename("XCONQCHECKPOINTFILE", CHECKPOINTFILE);
@@ -134,14 +128,14 @@ preferences_filename(void)
 }
 
 char *
-error_save_filename()
+error_save_filename(void)
 {
     /* No need to cache name, will only get requested once. */
     return game_filename("XCONQERRORFILE", ERRORFILE);
 }
 
 char *
-statistics_filename()
+statistics_filename(void)
 {
     /* No need to cache name, will only get requested once. */
     return game_filename("XCONQSTATSFILE", STATSFILE);
@@ -150,7 +144,7 @@ statistics_filename()
 static char *homedir;
 
 static char *
-game_homedir()
+game_homedir(void)
 {
     char *str;
     struct passwd *pwd;
@@ -179,8 +173,7 @@ game_homedir()
 }
 
 static char *
-game_filename(namevar, defaultname)
-char *namevar, *defaultname;
+game_filename(char *namevar, char* defaultname)
 {
     char *str, *home;
 
@@ -194,20 +187,20 @@ char *namevar, *defaultname;
     return str;
 }
 
-/* This wrapper replaces fopen everywhere in the kernel. On the mac side it does 
-unix-to-mac linefeed conversion if necessary. Here it does absolutely nothing. */
+/* This wrapper replaces fopen everywhere in the kernel. On the mac
+   side it does unix-to-mac linefeed conversion if necessary. Here it
+   does absolutely nothing. */
 
 FILE *
 open_file(char *filename, char *mode)
 {
-	return fopen(filename, mode);
+    return fopen(filename, mode);
 }
 
 /* Attempt to open a library file. */
 
 FILE *
-open_module_library_file(module)
-Module *module;
+open_module_library_file(Module *module)
 {
     LibraryPath *p;
     FILE *fp;
@@ -230,8 +223,8 @@ Module *module;
 }
 
 FILE *
-open_module_explicit_file(module)
-Module *module;
+open_module_explicit_file(Module *module)
+
 {
     if (module->filename == NULL)
       return NULL;
@@ -239,8 +232,7 @@ Module *module;
 }
 
 FILE *
-open_library_file(filename)
-char *filename;
+open_library_file(char *filename)
 {
     char fullnamebuf[1024];
     LibraryPath *p;
@@ -262,8 +254,7 @@ char *filename;
 }
 
 FILE *
-open_scorefile_for_reading(name)
-char *name;
+open_scorefile_for_reading(char *name)
 {
     FILE *fp;
 
@@ -272,8 +263,7 @@ char *name;
 }
 
 FILE *
-open_scorefile_for_writing(name)
-char *name;
+open_scorefile_for_writing(char *name)
 {
     FILE *fp;
 
@@ -286,8 +276,7 @@ char *name;
 }
 
 void
-close_scorefile_for_writing(fp)
-FILE *fp;
+close_scorefile_for_writing(FILE *fp)
 {
     fclose(fp);
     /* Reset the uid back to the user who started the game. */
@@ -297,8 +286,7 @@ FILE *fp;
 static char *scorenamebuf;
 
 static char *
-score_file_pathname(name)
-char *name;
+score_file_pathname(char *name)
 {
     char *scorepath, extrabuf[BUFSIZE];
 
@@ -320,8 +308,7 @@ char *name;
 }
 
 void
-make_pathname(path, name, extn, pathbuf)
-char *path, *name, *extn, *pathbuf;
+make_pathname(char *path, char *name, char *extn, char *pathbuf)
 {
     strcpy(pathbuf, "");
     if (!empty_string(path)) {
@@ -344,7 +331,7 @@ char *path, *name, *extn, *pathbuf;
 /* Remove a saved game from the system. */
 
 void
-remove_saved_game()
+remove_saved_game(void)
 {
     unlink(saved_game_filename());
 }
@@ -368,6 +355,7 @@ stop_handler(int sig)
 stop_handler(int sig, int code, struct sigcontext *scp, char *addr)
 #endif
 {
+    /* (should try to tell other programs of departure?) */
     close_displays();
     exit(1);
 }
@@ -391,7 +379,7 @@ crash_handler(int sig, int code, struct sigcontext *scp, char *addr)
 	printf(" code %d\n", code);
 #endif
 	printf("\n");
-	write_entire_game_state(ERRORFILE);
+	write_entire_game_state(error_save_filename());
     }
     abort();
 }
@@ -411,13 +399,13 @@ hup_handler(int sig, int code, struct sigcontext *scp, char *addr)
 	already_been_here = TRUE;
 	close_displays();
 	printf("Somebody was disconnected, saving the game.\n");
-	write_entire_game_state(ERRORFILE);
+	write_entire_game_state(error_save_filename());
     }
     abort();
 }
 
 void
-init_signal_handlers()
+init_signal_handlers(void)
 {
     signal(SIGINT, stop_handler);
     if (0 /* don't accidently quit */ && !Debug) {
@@ -447,8 +435,7 @@ struct timeval reallasttime = { 0, 0 };
 struct timeval realcurtime;
 
 int
-n_seconds_elapsed(n)
-int n;
+n_seconds_elapsed(int n)
 {
     gettimeofday(&realcurtime, NULL);
     if (realcurtime.tv_sec > (reallasttime.tv_sec + (n - 1))) {
@@ -465,8 +452,7 @@ int n;
 struct timeval reallastmstime = { 0, 0 };
 
 int
-n_ms_elapsed(n)
-int n;
+n_ms_elapsed(int n)
 {
     int interval;
     struct timeval tmprealtime;
@@ -481,252 +467,7 @@ int n;
 /* Record the current time of day. */
 
 void
-record_ms()
+record_ms(void)
 {
     gettimeofday(&reallastmstime, NULL);
 }
-
-/* Low-level networking support for Unix. */
-
-int connection_method;
-
-int hosting;
-
-int remote_desc = -1;
-
-void
-open_remote_connection(methodname)
-char *methodname;
-{
-#if 0
-    struct sgttyb sg;
-#endif
-    char *port_str;
-    int port;
-    struct hostent *hostent;
-    struct sockaddr_in sockaddr;
-    int tmp;
-    char hostname[100];
-    struct protoent *protoent;
-    int i;
-    int tmp_desc;
-
-    if (!strchr(methodname, ':')) {
-	remote_desc = open(methodname, O_RDWR);
-	if (remote_desc < 0)
-	  init_warning("Could not open remote device");
-
-#if 0
-	ioctl(remote_desc, TIOCGETP, &sg);
-	sg.sg_flags = RAW;
-	ioctl(remote_desc, TIOCSETP, &sg);
-#endif
-    } else {
-	/* Extract the port number. */
-	port_str = strchr(methodname, ':');
-	port = atoi(port_str + 1);
-
-	tmp_desc = socket(PF_INET, SOCK_STREAM, 0);
-	if (tmp_desc < 0)
-	  init_warning("Can't open socket");
-
-	/* Allow rapid reuse of this port. */
-	tmp = 1;
-	setsockopt (tmp_desc, SOL_SOCKET, SO_REUSEADDR, (char *) &tmp,
-		    sizeof(tmp));
-
-	if (hosting) {
-	    sockaddr.sin_family = PF_INET;
-	    sockaddr.sin_port = htons(port);
-	    sockaddr.sin_addr.s_addr = INADDR_ANY;
-
-	    if (bind(tmp_desc, (struct sockaddr *) &sockaddr, sizeof(sockaddr))
-		|| listen (tmp_desc, 1))
-	      init_warning("Can't bind address");
-
-	    tmp = sizeof (sockaddr);
-	    remote_desc = accept(tmp_desc, (struct sockaddr *) &sockaddr, &tmp);
-	    if (remote_desc == -1)
-	      init_warning("Accept failed");
-
-	    protoent = getprotobyname("tcp");
-	    if (!protoent)
-	      init_warning("getprotobyname");
-
-	    /* Enable TCP keep alive process. */
-	    tmp = 1;
-	    setsockopt(tmp_desc, SOL_SOCKET, SO_KEEPALIVE, (char *) &tmp, sizeof(tmp));
-
-	    /* Tell TCP not to delay small packets.  This greatly speeds up
-	       interactive response. */
-	    tmp = 1;
-	    setsockopt(remote_desc, protoent->p_proto, TCP_NODELAY,
-		       (char *) &tmp, sizeof(tmp));
-
-	    /* No longer need the descriptor. */
-	    close(tmp_desc);
-
-	    /* If we don't do this, then program simply exits when
-	       the remote side dies.  */
-	    signal(SIGPIPE, SIG_IGN);
-#if defined(FASYNC)
-	    fcntl(remote_desc, F_SETFL, FASYNC);
-#endif
-	    fprintf (stderr, "Remote connection using %s\n", methodname);
-
-	    my_rid = 1;
-	} else {
-	    tmp = min (port_str - methodname, (int) sizeof hostname - 1);
-	    strncpy (hostname, methodname, tmp);
-	    hostname[tmp] = '\0';
-	    hostent = gethostbyname (hostname);
-	    if (!hostent) {
-		init_warning("%s: unknown host\n", hostname);
-		return;
-	    }
-	    for (i = 1; i <= 15; i++) {
-		remote_desc = socket(PF_INET, SOCK_STREAM, 0);
-		if (remote_desc < 0) {
-		    init_warning("can't create a socket");
-		    return;
-		}
-
-		/* Allow rapid reuse of this port. */
-		tmp = 1;
-		setsockopt(remote_desc, SOL_SOCKET, SO_REUSEADDR, (char *) &tmp, sizeof(tmp));
-
-		/* Enable TCP keep alive process. */
-		tmp = 1;
-		setsockopt(remote_desc, SOL_SOCKET, SO_KEEPALIVE, (char *) &tmp, sizeof(tmp));
-
-		sockaddr.sin_family = PF_INET;
-		sockaddr.sin_port = htons(port);
-		memcpy(&sockaddr.sin_addr.s_addr, hostent->h_addr,
-		       sizeof (struct in_addr));
-
-		if (connect(remote_desc, (struct sockaddr *) &sockaddr, sizeof(sockaddr)) == 0)
-		  break;
-
-		close(remote_desc);
-		remote_desc = -1;
-
-		/* We retry for ECONNREFUSED because that is often a
-		   temporary condition, which happens when the server
-		   is being restarted.  */
-		if (errno != ECONNREFUSED)
-		  return;
-		sleep(1);
-	    }
-
-	    protoent = getprotobyname ("tcp");
-	    if (!protoent)
-	      return;
-
-	    tmp = 1;
-	    if (setsockopt(remote_desc, protoent->p_proto, TCP_NODELAY,
-			   (char *) &tmp, sizeof(tmp)))
-	      return;
-
-	    signal(SIGPIPE, SIG_IGN);
-
-	    my_rid = 2;
-	}
-	numremotes = 2;
-	connection_method = 2;
-    }
-}
-
-void
-low_send(id, buf)
-int id;
-char *buf;
-{
-    int len, cc;
-
-    len = strlen(buf);
-    while (len > 0) {
-	cc = write(remote_desc, buf, len);
-
-	if (cc < 0)
-	  return;
-	len -= cc;
-	buf += cc;
-    }
-}
-
-static int wait_for(int timeout);
-
-static int
-wait_for(int timeout)
-{
-    int numfds;
-    struct timeval tv;
-    fd_set readfds, exceptfds;
-
-    FD_ZERO (&readfds);
-    FD_ZERO (&exceptfds);
-
-    tv.tv_sec = timeout;
-    tv.tv_usec = 0;
-
-    FD_SET(remote_desc, &readfds);
-    FD_SET(remote_desc, &exceptfds);
-
-    while (1) {
-	if (timeout >= 0)
-	  numfds = select(remote_desc+1, &readfds, 0, &exceptfds, &tv);
-	else
-	  numfds = select(remote_desc+1, &readfds, 0, &exceptfds, 0);
-
-	if (numfds <= 0) {
-	    if (numfds == 0)
-	      return -1;
-	    else if (errno == EINTR)
-	      continue;
-	    else
-	      return -2;	/* Got an error from select or poll */
-	}
-	return 0;
-    }
-}
-
-int
-low_receive(int *idp, char *buf, int maxchars, int timeout)
-{
-    int status, n;
-    /* time_t */ unsigned long start_time, now;
-
-    time(&start_time);
-
-    while (1) {
-	status = wait_for(timeout);
-	if (status < 0)
-	  return FALSE;
-	n = read(remote_desc, buf, maxchars);
-	if (n > 0) {
-	    buf[n] = '\0';
-	    *idp = (my_rid == 1 ? 2 : 1);
-	    return TRUE;
-	} else if (timeout == 0) {
-	    return FALSE;
-	} else if (timeout == -1) {
-	    /* Go around again. */
-	} else {
-	    time(&now);
-	    if (now > start_time + timeout) {
-		Dprintf("%ul > %ul + %d\n", now, start_time, timeout);
-		return FALSE /* timed out */;
-	    }
-	}
-    }
-}
-
-void
-close_remote_connection()
-{
-    if (remote_desc < 0)
-      return;
-
-    close(remote_desc);
-    remote_desc = -1;
-}
