@@ -335,7 +335,6 @@ int amt;
 
 /* Like sprintf, but appends. */
 
-#ifdef __STDC__
 void
 tprintf(char *buf, char *str, ...)
 {
@@ -371,33 +370,6 @@ vtprintf(char *buf, char *str, va_list ap)
     vsprintf(line, str, ap);
     strcat(buf, line);
 }
-#else
-void
-tprintf(buf, str, a1, a2, a3, a4, a5, a6, a7, a8, a9)
-char *buf, *str;
-long a1, a2, a3, a4, a5, a6, a7, a8, a9;
-{
-    char line[300];
-
-    sprintf(line, str, a1, a2, a3, a4, a5, a6, a7, a8, a9);
-    strcat(buf, line);
-}
-
-void
-tnprintf(buf, n, str, a1, a2, a3, a4, a5, a6, a7, a8, a9)
-char *buf, *str;
-int n;
-long a1, a2, a3, a4, a5, a6, a7, a8, a9;
-{
-    int n1 = n - strlen(buf);
-    char line[300];
-
-    if (n1 > 0) {
-	sprintf(line, str, a1, a2, a3, a4, a5, a6, a7, a8, a9);
-	strncat(buf, line, n1);
-    }
-}
-#endif
 
 int
 select_by_weight(arr, numvals)
@@ -665,8 +637,6 @@ char *buf;
       strcat(buf, "G");
 }
 
-#ifdef __STDC__
-
 void
 debug_printf(char *str, ...)
 {
@@ -696,33 +666,6 @@ debugg_printf(char *str, ...)
     vfprintf(dgfp, str, ap);
     va_end(ap);
 }
-#else
-/* Kind of cheesy, should only use if real ANSI not available. */
-
-void
-debug_printf(str, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11, a12)
-char *str;
-long a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11, a12;
-{
-    fprintf(dfp, str, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11, a12);
-}
-
-void
-debugm_printf(str, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11, a12)
-char *str;
-long a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11, a12;
-{
-    fprintf(dmfp, str, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11, a12);
-}
-
-void
-debugg_printf(str, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11, a12)
-char *str;
-long a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11, a12;
-{
-    fprintf(dgfp, str, a1, a2, a3, a4, a5, a6, a7, a8, a9, a10, a11, a12);
-}
-#endif /* __STDC__ */
 
 #endif /* DEBUGGING */
 
@@ -857,27 +800,15 @@ dump_activity_trace(void)
 /* Handling for various kinds of failures. */
 
 void
-#ifdef __STDC__
 init_error(char *str, ...)
-#else
-init_error(str, a1, a2, a3, a4, a5, a6, a7, a8, a9)
-char *str;
-long a1, a2, a3, a4, a5, a6, a7, a8, a9;
-#endif
 {
     char buf[BUFSIZE];
+    va_list ap;
 
-#ifdef __STDC__
-    {
-	va_list ap;
+    va_start(ap, str);
+    vsprintf(buf, str, ap);
+    va_end(ap);
 
-	va_start(ap, str);
-	vsprintf(buf, str, ap);
-	va_end(ap);
-    }
-#else
-    sprintf(buf, str, a1, a2, a3, a4, a5, a6, a7, a8, a9);
-#endif
     Dprintf("INIT ERROR %s INIT ERROR\n", buf);
     if (warnings_logged)
       log_warning("INIT ERROR", buf);
@@ -885,27 +816,15 @@ long a1, a2, a3, a4, a5, a6, a7, a8, a9;
 }
 
 void
-#ifdef __STDC__
 init_warning(char *str, ...)
-#else
-init_warning(str, a1, a2, a3, a4, a5, a6, a7, a8, a9)
-char *str;
-long a1, a2, a3, a4, a5, a6, a7, a8, a9;
-#endif
 {
     char buf[BUFSIZE];
+    va_list ap;
 
-#ifdef __STDC__
-    {
-	va_list ap;
+    va_start(ap, str);
+    vsprintf(buf, str, ap);
+    va_end(ap);
 
-	va_start(ap, str);
-	vsprintf(buf, str, ap);
-	va_end(ap);
-    }
-#else
-    sprintf(buf, str, a1, a2, a3, a4, a5, a6, a7, a8, a9);
-#endif
     Dprintf("INIT WARNING %s INIT WARNING\n", buf);
     if (warnings_logged)
       log_warning("INIT", buf);
@@ -917,27 +836,15 @@ long a1, a2, a3, a4, a5, a6, a7, a8, a9;
 /* A run error is fatal. */
 
 void
-#ifdef __STDC__
 run_error(char *str, ...)
-#else
-run_error(str, a1, a2, a3, a4, a5, a6, a7, a8, a9)
-char *str;
-long a1, a2, a3, a4, a5, a6, a7, a8, a9;
-#endif
 {
     char buf[BUFSIZE];
+    va_list ap;
 
-#ifdef __STDC__
-    {
-	va_list ap;
+    va_start(ap, str);
+    vsprintf(buf, str, ap);
+    va_end(ap);
 
-	va_start(ap, str);
-	vsprintf(buf, str, ap);
-	va_end(ap);
-    }
-#else
-    sprintf(buf, str, a1, a2, a3, a4, a5, a6, a7, a8, a9);
-#endif
     Dprintf("RUN ERROR %s RUN ERROR\n", buf);
     if (warnings_logged)
       log_warning("RUN ERROR", buf);
@@ -948,27 +855,15 @@ long a1, a2, a3, a4, a5, a6, a7, a8, a9;
    usually a problem with Xconq or a game design. */
 
 void
-#ifdef __STDC__
 run_warning(char *str, ...)
-#else
-run_warning(str, a1, a2, a3, a4, a5, a6, a7, a8, a9)
-char *str;
-long a1, a2, a3, a4, a5, a6, a7, a8, a9;
-#endif
 {
     char buf[BUFSIZE];
+    va_list ap;
 
-#ifdef __STDC__
-    {
-	va_list ap;
+    va_start(ap, str);
+    vsprintf(buf, str, ap);
+    va_end(ap);
 
-	va_start(ap, str);
-	vsprintf(buf, str, ap);
-	va_end(ap);
-    }
-#else
-    sprintf(buf, str, a1, a2, a3, a4, a5, a6, a7, a8, a9);
-#endif
     Dprintf("RUN WARNING %s RUN WARNING\n", buf);
     if (warnings_logged)
       log_warning("RUN", buf);
@@ -980,8 +875,9 @@ long a1, a2, a3, a4, a5, a6, a7, a8, a9;
 void
 log_warning(char *typ, char *str)
 {
-    if (ewfp == NULL)
-      ewfp = open_file("Xconq.Warnings", "w");
-    if (ewfp != NULL)
+    ewfp = open_file("Xconq.Warnings", "a");
+    if (ewfp != NULL) {
       fprintf(ewfp, "%s: %s\n", typ, str);
+      fclose(ewfp);
+    }
 }
