@@ -9,6 +9,8 @@ any later version.  See the file COPYING.  */
 #include "conq.h"
 extern char *escaped_symbol(char *str);
 extern char *escaped_string(char *str);
+extern void add_to_packet(char *str);
+extern void flush_write(void);
 #include "ai.h"
 #include "imf.h"
 extern ImageFamily **recorded_imfs;
@@ -98,8 +100,6 @@ static void add_form_to_form(Obj *x);
 static void end_form(void);
 static void newline_form(void);
 static void space_form(void);
-static void add_to_packet(int id, char *str);
-static void flush_write(void);
 static void write_bool_prop(char *name, int value,
 			    int dflt, int nodefaulting, int addnewline);
 static void write_num_prop(char *name, int value,
@@ -210,8 +210,7 @@ char *fname;
    containing the requested content.  Return true if everything went OK. */
 
 int
-write_game_module(module)
-Module *module;
+write_game_module(Module *module)
 {
     if (module->filename == NULL && tmprid == 0) {
 	/* (should be an error?) */
@@ -333,9 +332,10 @@ Module *module;
 	    newline_form();
 	    newline_form();
 	}
-	flush_write();
 	if (wfp != NULL)
 	  fclose(wfp);
+	else
+	  flush_write();
 	return TRUE;
     } else {
 	return FALSE;
@@ -2457,8 +2457,8 @@ char *hd;
     if (wfp) {
 	fprintf(wfp, "(%s", hd);
     } else {
-	add_to_packet(tmprid, "(");
-	add_to_packet(tmprid, hd);
+	add_to_packet("(");
+	add_to_packet(hd);
     }
 }
 
@@ -2469,8 +2469,8 @@ char *x;
     if (wfp) {
 	fprintf(wfp, " %s", x);
     } else {
-	add_to_packet(tmprid, " ");
-	add_to_packet(tmprid, x);
+	add_to_packet(" ");
+	add_to_packet(x);
     }
 }
 
@@ -2481,7 +2481,7 @@ char *x;
     if (wfp) {
 	fputs(x, wfp);
     } else {
-	add_to_packet(tmprid, x);
+	add_to_packet(x);
     }
 }
 
@@ -2496,7 +2496,7 @@ int x;
     } else {
 	buf[0] = x;
 	buf[1] = '\0';
-	add_to_packet(tmprid, buf);
+	add_to_packet(buf);
     }
 }
 
@@ -2510,7 +2510,7 @@ int x;
 	fprintf(wfp, " %d", x);
     } else {
 	sprintf(buf, " %d", x);
-	add_to_packet(tmprid, buf);
+	add_to_packet(buf);
     }
 }
 
@@ -2524,7 +2524,7 @@ int x;
 	fprintf(wfp, "%d", x);
     } else {
 	sprintf(buf, "%d", x);
-	add_to_packet(tmprid, buf);
+	add_to_packet(buf);
     }
 }
 
@@ -2544,7 +2544,7 @@ int x, valtype;
     if (wfp) {
 	fputs(buf, wfp);
     } else {
-	add_to_packet(tmprid, buf);
+	add_to_packet(buf);
     }
 }
 
@@ -2562,7 +2562,7 @@ Obj *x;
 	if (onemorebuf == NULL)
 	  onemorebuf = xmalloc(16000);
 	sprintlisp(onemorebuf, x, 16000);
-	add_to_packet(tmprid, onemorebuf);
+	add_to_packet(onemorebuf);
     }
 }
 
@@ -2572,7 +2572,7 @@ end_form()
     if (wfp) {
 	fputs(")", wfp);
     } else {
-	add_to_packet(tmprid, ")");
+	add_to_packet(")");
     }
 }
 
@@ -2582,7 +2582,7 @@ newline_form()
     if (wfp) {
 	fprintf(wfp, "\n");
     } else {
-	add_to_packet(tmprid, "\n");
+	add_to_packet("\n");
     }
 }
 
@@ -2592,47 +2592,7 @@ space_form()
     if (wfp) {
 	fputs(" ", wfp);
     } else {
-	add_to_packet(tmprid, " ");
-    }
-}
-
-static char *notherbuf;
-
-static void
-add_to_packet(id, str)
-int id;
-char *str;
-{
-    if (notherbuf == NULL)
-      notherbuf = xmalloc(100);
-    if (strlen(str) + strlen(notherbuf) < 40) {
-	strcat(notherbuf, str);
-    } else {
-	send_packet(id, notherbuf);
-	notherbuf[0] = '\0';
-	while (strlen(str) >= 40) {
-	    strncpy(notherbuf, str, 40);
-	    notherbuf[40] = '\0';
-	    send_packet(id, notherbuf);
-	    notherbuf[0] = '\0';
-	    str += 40;
-	}
-	if (strlen(str) < 40) {
-	    strcat(notherbuf, str);
-	}
-    }
-}
-
-static void
-flush_write()
-{
-    if (wfp) {
-	/* (nothing to do?) */
-    } else {
-    	if (!empty_string(notherbuf)) {
-	    send_packet(tmprid, notherbuf);
-	    notherbuf[0] = '\0';
-	}
+	add_to_packet(" ");
     }
 }
 
