@@ -1,5 +1,5 @@
 /* Commands for the Mac interface to Xconq.
-   Copyright (C) 1992-1998 Stanley T. Shebs.
+   Copyright (C) 1992-1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -11,22 +11,28 @@ any later version.  See the file COPYING.  */
 #include "kpublic.h"
 #include "macconq.h"
 
+/* Define to enable (but not activate) profiling. */
+#undef PROFILING
+
+/* Define PROFILING if CodeWarrior profiling is on. 
+Also include Profiler.h if not already included. */
+#if __profile__
+#include <Profiler.h>
+#define PROFILING
+#endif
+
+#ifdef PROFILING
+#ifdef THINK_C			
+extern int _trace;	/* Not used by CodeWarrior. */
+#include <profile.h>
+#endif
+#endif
+
 extern void set_construction_run_length(int len);
 extern void do_idle_command(int n);
 extern int do_down_command(void);
 extern int do_up_command(void);
 
-/* Define in order to get profiling controls. */
-#undef PROFILING
-
-#ifdef THINK_C
-#include <profile.h>
-#endif
-
-#ifdef PROFILING
-extern int _trace;
-#endif
-
 extern WindowPtr playersetupwin;
 
 extern int forcedtoresign;
@@ -998,7 +1004,7 @@ do_one_occupant(Unit *unit)
 			unselect_unit_on_map(frontmap, unit);
 			select_unit_on_map(frontmap, nextocc);
 			/* Overkill, but draw_row alone not as desirable? */
-			update_cell_display(dside, unit->x, unit->y, TRUE);
+			update_cell_display(dside, unit->x, unit->y, UPDATE_ALWAYS);
 		}
 	}
 	return TRUE;
@@ -1607,22 +1613,40 @@ void
 do_trace(Side *side)
 {
 	toggle_profiling();
+
 #ifdef PROFILING
+
+#ifdef THINK_C			/* Not used by CodeWarrior. */
+
 	_trace = 1;
+
+#endif /* THINK_C */
+
 #endif /* PROFILING */
+
 }
 
 void
 toggle_profiling()
 {
-#ifdef PROFILING
-	extern int _profile;
-#endif /* PROFILING */
 
+#ifdef PROFILING		
+
+#ifdef THINK_C			/* Not used by CodeWarrior. */
+
+	extern int _profile;
+
+#endif /* THINK_C */
+
+	/* Only toggle Profile if profiling is enabled! */
 	Profile = !Profile;
 
-#ifdef PROFILING
+	/* Necessary to update game window with the
+	new profiling status. */
+	draw_game();
+
 #ifdef THINK_C
+
 	if (Profile && !_profile) {
 		InitProfile(1000, 100);
 		freopen("Xconq.ProfileOut", "w", stdout);
@@ -1631,8 +1655,24 @@ toggle_profiling()
 		DumpProfile();
 		fflush(stdout);
 	}
-#endif /* PROFILING */
+
 #endif /* THINK_C */
+
+#if __profile__			/* CodeWarrior support. */
+
+	if (Profile && ProfilerGetStatus() == false) {
+		ProfilerSetStatus(true);
+	}
+	if (!Profile && ProfilerGetStatus() == true) {
+		ProfilerSetStatus(false);
+		ProfilerDump("\pXconq.Profile");
+		ProfilerClear();
+	}
+
+#endif /* __profile__ */
+
+#endif /* PROFILING */
+
 }
 
 #endif /* DEBUGGING */
