@@ -20,8 +20,10 @@ any later version.  See the file COPYING.  */
 
 extern CIconHandle mac_create_cicn(Image *img);
 extern void mac_init_cicn(Image *img);
-static void build_colors_popup_menu(MenuHandle popMenu);
-static void append_color_callback(ImageFamily *imf, int loadnow);
+static int append_image_names(MenuHandle menu);
+static int append_color_names(MenuHandle menu);
+static int append_terrain_names(MenuHandle menu);
+static int append_imf_name(Obj *form, MenuHandle menu);
 static RGBColor get_color(char *name);					/* Get new color by name */
 static RGBColor pick_new_color(RGBColor inColor, char *name); 	/* Use color picker to get a new color */
 
@@ -300,7 +302,7 @@ get_color(char* name)
     	record_imf_get(imf);			
 
 	/* Get the 1x1 image (color). */
-	img = get_img(imf, 1, 1, 0);
+	img = get_img(imf, 1, 1);
 
 	/* Needed only in the presence of mac-lib. */ 
 	mac_interp_imf(imf, img, 0);	
@@ -567,12 +569,12 @@ set_side_colors(int e)
 	c2p(tmpName3, pname);
 	SetIText(itemhandle, pname);
 
-	/* Load all available ppat colors into the popup menu */
+	/* Add "undefined" at the top of the popup menu. */
 	AppendMenu(popMenu, "\pundefined");
-	AppendMenu(popMenu, "\p(-");		/* Item separator */
-
-	/* Build the popup menu for new colors. */
-	build_colors_popup_menu(popMenu);
+	/* Add an item separator. */
+	AppendMenu(popMenu, "\p(-");
+	/* Then append available color and terrain names. */
+	append_image_names(popMenu);
 
 	/* Change port and start the main loop */
 	GetPort(&oldport);
@@ -1037,8 +1039,8 @@ set_feature_color(int e)
 	c2p(tmpName, pname);
 	SetIText(itemhandle, pname);
 
-	/* Build the popup menu for new colors. */
-	build_colors_popup_menu(popMenu);
+	/* Append available color and terrain names to the popup menu. */
+	append_image_names(popMenu);
 	
 	/* Change port and start the main loop */
 	GetPort(&oldport);
@@ -1209,8 +1211,8 @@ set_terrain_color( Str255 tname)
 		break;
 	}
 
-	/* Build the popup menu for new colors. */
-	build_colors_popup_menu(popMenu);
+	/* Append available color and terrain names to the popup menu. */
+	append_image_names(popMenu);
 	
 	/* Change port and start the main loop */
 	GetPort(&oldport);
@@ -1307,15 +1309,17 @@ set_terrain_color( Str255 tname)
 
 			} else {	/* Update everything and exit the dialog */
 
-				/* Replace terrain images used for drawing */
+				/* Replace timages[e] with the new image family. */
+				timages[e] = imf;
+				/* Recompute its best images. */
 				for (i = 0; i < NUMPOWERS; ++i) {
-					img = best_image(imf, hws[i], hcs[i]);
+					img = best_image(timages[e], hws[i], hhs[i]);
 					if (img && e != -1) {
 						best_terrain_images[i * numttypes + e] = img;
 					}
 				}
 				/* Replace terrain colors used for solid color drawing */
-				img = get_img(imf, 1, 1, 0);
+				img = get_img(imf, 1, 1);
 				if (img->hook && e != -1) {
 					macimg = (MacImage *) img->hook;
 					tcolors[e] = macimg;
@@ -1389,6 +1393,7 @@ build_sides_menu(void)
 		AppendMenu(menu, pname);
 	}
 }
+
 void
 build_features_menu(void)
 {
@@ -1404,13 +1409,13 @@ build_features_menu(void)
 	}
 }
 
-void
-build_colors_popup_menu(MenuHandle popMenu)
+int
+append_image_names(MenuHandle menu)
 {
 	Handle	ppathandle;  
 	char 		cname[32];
 	Str255	pname;
-	int 		i, n;
+	int 		i, n, num = 0;
 
 	/* Use lib-mac Images file if available. */
 	n = GetResFileAttrs(images_refnum);
@@ -1427,39 +1432,93 @@ build_colors_popup_menu(MenuHandle popMenu)
 			/* Skip invalid names. */
 			if (!valid_imf_name(cname))
 				continue;
-			AppendMenu(popMenu, pname);
+			AppendMenu(menu, pname);
+			++num;
 		}
 
-	/* Else use colors from the colors.imf and terrain.imf files. */
+	/* Else use colors.imf and terrain.imf. */
 	} else {
 		/* First load all real colors. */
-	    	make_pathname(xconq_libs->path, "colors.imf", "", spbuf);
-		load_imf_file(spbuf, append_color_callback);
-
+		num += append_color_names(menu);
 		/* Then add an item separator. */
-		AppendMenu(popMenu, "\p(-");
-
+		if (num)
+		    AppendMenu(menu, "\p(-");
 		/* Then load the terrain colors. */
-	    	make_pathname(xconq_libs->path, "terrain.imf", "", spbuf);
-		load_imf_file(spbuf, append_color_callback);
+		num += append_terrain_names(menu);
 	}
+	return num;
 }
 
-void 
-append_color_callback(ImageFamily *imf, int loadnow)
+int
+append_color_names(MenuHandle menu)
 {
-	Str255 		lastname, pname;
-	char 			cname[32];
-	MenuHandle	popMenu;	
+	int	num = 0, startlineno = 1, endlineno = 1;
+	Obj	*form;
+	FILE	*fp;
 
-	if (!valid_imf_name(imf->name))
-		return;
-	popMenu = GetMenu(mSideColorPopup);
-	GetItem(popMenu, CountMItems(popMenu), lastname);
-	p2c(lastname, cname);
-	/* Skip if item has the same name as previous item. */
-	if (strcmp(imf->name, cname) != 0) {
-		c2p(imf->name, pname);
-		AppendMenu(popMenu, pname);
+    	make_pathname(xconq_libs->path, "colors.imf", "", spbuf);
+	fp = open_file(spbuf, "r");
+	if (fp == NULL) {
+		run_warning("Could not find your colors.imf file");
+		return FALSE;		
 	}
+	while ((form = read_form(fp, &startlineno, &endlineno)) != lispeof) {
+		if (append_imf_name(form, menu))
+		    ++num;
+	}
+	fclose(fp);
+	return TRUE;
+}	
+
+int
+append_terrain_names(MenuHandle menu)
+{
+	int	num = 0, startlineno = 1, endlineno = 1;
+	Obj	*form;
+	FILE	*fp;
+
+    	make_pathname(xconq_libs->path, "terrain.imf", "", spbuf);
+	fp = open_file(spbuf, "r");
+	if (fp == NULL) {
+		run_warning("Could not find your terrain.imf file");
+		return 0;		
+	}
+	while ((form = read_form(fp, &startlineno, &endlineno)) != lispeof) {
+		if (append_imf_name(form, menu))
+		    ++num;
+	}
+	fclose(fp);
+	return num;
+}	
+
+int
+append_imf_name(Obj *form, MenuHandle menu)
+{
+	Str255 	lastname, pname;
+	char 		*name, cname[32];
+	Obj		*head;
+	
+	/* Ignore any non-lists. */
+	if (!consp(form))
+	    return FALSE;
+	head = car(form);
+	/* Ignore any non-imf forms. */
+	if (!match_keyword(head, K_IMF))
+	    return FALSE;
+	/* Ignore imf without a name. */
+	if (!stringp(cadr(form)))
+	    return FALSE;
+	name = c_string(cadr(form));
+	/* Ignore invalid imf names. */
+	if (!valid_imf_name(name))
+	    return FALSE;
+	/* Get the last item name in the menu. */
+	GetItem(menu, CountMItems(menu), lastname);
+	p2c(lastname, cname);
+	/* Skip if imf has the same name as last item. */
+	if (strcmp(name, cname) == NULL)
+	    return FALSE;
+	c2p(name, pname);
+	AppendMenu(menu, pname);
+	return TRUE;
 }
