@@ -1,5 +1,5 @@
 /* Main program of the Mac interface to Xconq.
-   Copyright (C) 1992-1998 Stanley T. Shebs.
+   Copyright (C) 1992-1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -7,20 +7,17 @@ the Free Software Foundation; either version 2, or (at your option)
 any later version.  See the file COPYING.  */
 
 #include "conq.h"
-extern int ok_to_exit;
 #include "kpublic.h"
 #include "macconq.h"
 
-extern void recalc_spacing(void);
-extern void invert_map(Map *map, int x, int y, int r);
-
-extern char *connection_method_name;
-extern int connection_method;
-extern int hosting;
-
 #include <errors.h>
 #include <time.h>
 
+/* Include Profile.h if profiling is enabled in CodeWarrior. */
+#if __profile__
+#include <Profiler.h>
+#endif
+
 #ifdef __MWERKS__
 #include <Sound.h>
 #endif
@@ -34,11 +31,13 @@ extern int hosting;
 #define PREFSIZE 2048		/* Size of prefs buffer in lisp format. Must be bigger than the default */
 						/* BUFSIZE = 256 to make room for all the new preferences */
 
-extern
-#if 0
-inline
-#endif
-int handle_numeric_keypad(EventRecord *event);
+extern int ok_to_exit;
+extern short initialvrefnum;
+
+char *connection_method_name;
+
+extern void recalc_spacing(void);
+extern void invert_map(Map *map, int x, int y, int r);
 
 /* Function prototypes. */
 
@@ -239,6 +238,15 @@ main()
 		check_screen_depths();
 	/* A hack to ensure some memory available for error handling. */
 	spare = NewHandle(2000);
+
+#if __profile__
+
+	/* Prepare profiling for CodeWarrior. */
+	ProfilerInit(collectDetailed, bestTimeBase, 1250, 36);
+	ProfilerSetStatus(false);
+
+#endif
+
 	/* If no Apple Events, go to the splash screen now, otherwise we'll wait
 	   for an oapp/odoc/pdoc event to decide what to do. */
 	if (!hasAppleEvents) {
@@ -465,7 +473,6 @@ get_files()
 {
 	int imagesfilenameres;
 	Str255 filename;
-	extern short initialvrefnum;
 
 	/* Capture the current vrefnum. */
 	GetVol(NULL, &initialvrefnum);
@@ -1400,11 +1407,11 @@ connect_game_dialog()
 
 	hosting = FALSE;
 	connection_method_dialog();
-	open_remote_connection(connection_method_name);
+	open_remote_connection(connection_method_name, hosting);
 	if (connection_method > 0) {
 		rslt = send_join("mac");
 		if (!rslt) {
-			close_remote_connection();
+			close_remote_connection(0);
 			/* Use of connection_method this way is weak; means
 			   having to reselect everything up reconnection. */
 			connection_method = 0;
@@ -1957,7 +1964,7 @@ update_unit_display(Side *side, Unit *unit, int rightnow)
 	if (active_display(side) && unit != NULL) {
 		update_unit_in_maps(unit);
 		if (1 /* unit visible to side in any way */ && inside_area(unit->x, unit->y)) {
-			update_cell_display(side, unit->x, unit->y, TRUE);
+			update_cell_display(side, unit->x, unit->y, UPDATE_ALWAYS);
 		}
 		update_unit_in_lists(unit);
 		if ((unitcloseup = find_unit_closeup(unit)) != NULL
@@ -1983,7 +1990,7 @@ update_unit_acp_display(Side *side, Unit *unit, int rightnow)
 		update_unit_in_maps(unit);
 #if 0  /* maybe add later, maybe not - acp change not usually visible tho */
 		if (1 /* unit visible to side in any way */ && inside_area(unit->x, unit->y)) {
-			update_cell_display(side, unit->x, unit->y, TRUE);
+			update_cell_display(side, unit->x, unit->y, UPDATE_ALWAYS);
 		}
 #endif
 		update_unit_in_lists(unit);
@@ -2696,7 +2703,18 @@ set_game_file_type(char *name)
 void
 exit_macconq()
 {
-	close_remote_connection();
+	close_remote_connection(0);
+
+#if __profile__
+
+	/* Make sure we use the Xconq directory. */
+	SetVol(NULL, initialvrefnum);
+	/* Dump any unsaved profiler output for CodeWarrior. */
+	ProfilerDump("\pXconq.Profile");
+	ProfilerTerm();
+
+#endif
+
 	ExitToShell();
 }
 
@@ -2745,3 +2763,12 @@ __ttyname(long fd)
 
 #endif /* __MWERKS__ */
 
+void
+add_remote_locally(int rid, char *str)
+{
+}
+
+void
+send_chat(int rid, char *str)
+{
+}
