@@ -540,7 +540,6 @@ extern int animation_pattern_state;
 extern WindowPtr playersetupwin;
 
 extern int connection_method;
-extern int hosting;
 extern Rect dragrect;
 extern int foundimagesfile;
 
@@ -891,6 +890,7 @@ extern int open_game_from_fsspec(FSSpec *fsspec);
 extern int open_game_from_name_and_volume(Str255 name, int vrefnum);
 extern void handle_player_setup_event(EventRecord *event);
 extern int hit_player_setup_dialog(int itemhit, Point mouse);
+extern int launch_game(void);
 extern void launch_game_2(void);
 extern void check_for_missing_images(void);
 extern void open_progress_dialog(void);
@@ -1107,10 +1107,10 @@ extern void toggle_shorelines(Map *map);
 extern void toggle_simple_borders(Map *map);
 extern void toggle_optimize_fonts(Map *map);
 extern void toggle_erase_names(Map *map);
-extern void toggle_draw_latlong(Map *map);			/* The associated default is declared elsewhere */
-extern void toggle_solid_color_terrain(Map *map);	/* The associated default is declared elsewhere */
-extern void toggle_list_sidecolors(List *list);		/* Uses the same default as toggle_map_sidecolors */
-extern void toggle_list_draw_emblems(List *list);	/* Uses the same default as toggle_map_sidecolors */
+extern void toggle_draw_latlong(Map *map);
+extern void toggle_solid_color_terrain(Map *map);
+extern void toggle_list_sidecolors(List *list);
+extern void toggle_list_draw_emblems(List *list);
 
 extern void read_xcol(void);				/* Read RGB colors form XCol resource */
 extern void write_xcol(void);				/* Write RGB colors to XCol resource */
@@ -1131,3 +1131,5 @@ extern void dispose_unit_cicns(void);			/* Trash every unit cicn in use */
 extern void dispose_emblem_cicns(void);		/* Trash every emblem cicn in use */
 
 extern void dissect_colorscheme(int e);	 	/* Dissect a colorscheme into sideColorNames */
+
+extern void add_remote_player(char *name);
