@@ -51,15 +51,14 @@ any later version.  See the file COPYING.  */
 #define mViewGrids 216
 #define mViewColors 217
 #define mViewBorders 218
+#define mPlanTypePopup 240
 
 #define mPreferencesTopics 700
 #define mSmallFont 701
 #define mSmallSize 702
 #define mLargeFont 703
 #define mLargeSize 704
-
 #define mSideColorPopup 705
-
 #define mSideColorUse 706
 
 #define miNotInUse 1
@@ -73,12 +72,8 @@ any later version.  See the file COPYING.  */
 #define mBuildPopup 710
 #define mAdvancePopup 711
 
-// --- NEW MENU ------------------------
-
 #define mAdvanceAchieved 713
 
-// -----------------------------------
-
 /* Menu items. */
 
 #define miAppleAbout 1
@@ -149,7 +144,7 @@ any later version.  See the file COPYING.  */
 #define miMoreDisembark 4
 #define miMoreDrop 5
 /* 6 */				/* Can't have submenu at position 5 or 6 for some weird reason! */
-#define miMoreDetach 7
+#define miMoreDetach 7	/* Problem now fixed. See macmenus.c for details. */
 #define miMoreDisband 8
 /* 9 */
 #define miMoreAddTerrain 10
@@ -175,23 +170,23 @@ any later version.  See the file COPYING.  */
 #define miSideDoctrine 12
 /* 13 */
 #define miSideSendMessage 14
-#define miSideGlobalAdvance 15
-#define miSideRename 16
+#define miSideRename 15
 
 #define miWindowsGame 1
 #define miWindowsNotices 2
 #define miWindowsHistory 3
 #define miWindowsConstruction 4
 #define miWindowsCommand 5
-#define miWindowsAgreements 6
+#define miWindowsResearch 6
 #define miWindowsScores 7
-/* 8 */
-#define miWindowsNewMap 9
-#define miWindowsNewList 10
+#define miWindowsDesign 8
+#define miWindowsAgreements 9
+#define miWindowsWorldMap 10
 /* 11 */
-#define miWindowsWorldMap 12
-/* 13 */
-#define miWindowsFirst 14
+#define miWindowsNewMap 12
+#define miWindowsNewList 13
+/* 14 */
+#define miWindowsFirst 15
 
 #define miViewCloser 1
 #define miViewFarther 2
@@ -212,8 +207,10 @@ any later version.  See the file COPYING.  */
 #define miViewGrids 16
 #define miViewColors 17
 #define miViewBorders 18
-#define miViewOffscreen 19
-#define miViewMeridians 20
+/* 19 */
+#define miViewOffscreen 20
+#define miViewMeridians 21
+#define miViewWorldMap 22
 
 #define miViewByType 1
 #define miViewByName 2
@@ -228,13 +225,8 @@ any later version.  See the file COPYING.  */
 /* 11 */
 #define miViewIconSize 12
 #define miListSideColors 13
-
-// --- USER CONTROL OF EMBLEMS ------------------------------------------
-
 #define miListDrawEmblems 14
 
-// ------------------------------------------------------------------
-
 #define miAngle15 1
 #define miAngle30 2
 #define miAngle90 3
@@ -248,7 +240,9 @@ any later version.  See the file COPYING.  */
 #define miPlanTypeDefensive 3
 #define miPlanTypeExploratory 4
 #define miPlanTypeOffensive 5
-#define miPlanTypeRandom 6
+#define miPlanTypeColonizing 6
+#define miPlanTypeImproving 7
+#define miPlanTypeRandom 8
 
 #define miPreferencesTopicsFiles 1
 #define miPreferencesTopicsMap 2
@@ -258,17 +252,14 @@ any later version.  See the file COPYING.  */
 #define miTextFeatureNames 2
 #define miTextOptimizeFonts 3
 #define miTextEraseNames 4
-
-// --- USER CONTROL OF EMBLEMS ------------------------------------------
-
 #define miTextDrawEmblems 5
 
-// ------------------------------------------------------------------
-
 #define miViewGrid 1
 #define miViewTopline 2
 #define miViewTopunit 3
-#define miViewOtherMaps 4
+#define miViewScrollBars 4
+#define miViewControlPanel 5
+#define miViewOtherMaps 6
 
 #define miSideColors 1
 #define miIconMasks 2
@@ -436,6 +427,9 @@ any later version.  See the file COPYING.  */
 #define diPrefsBoxMasks (diPrefsCommon + 19)
 #define diPrefsTextMasks (diPrefsCommon + 20)
 #define diPrefsMagPopup (diPrefsCommon + 26)
+#define diPrefsAIRegions (diPrefsCommon + 27)
+#define diPrefsScrollBars (diPrefsCommon + 28)
+#define diPrefsControlPanel (diPrefsCommon + 29)
 
 #define dsPreferencesFonts 703
 
@@ -460,6 +454,7 @@ any later version.  See the file COPYING.  */
 #define diPrefsUseVertiBuff (diPrefsCommon + 4)
 #define diPrefsVertiBuff (diPrefsCommon + 5)
 #define diPrefsVPixel (diPrefsCommon + 6)
+#define diPrefs256colors (diPrefsCommon + 10)
 
 #define dsPreferencesImageSets 705
 
@@ -468,13 +463,8 @@ any later version.  See the file COPYING.  */
 #define diPrefsColorIconsText (diPrefsCommon + 3)
 #define diPrefsUnifiedCicns (diPrefsCommon + 4)
 #define diPrefsUnifiedText (diPrefsCommon + 5)
-
-// --- USER CONTROL OF EMBLEMS ----------------------------------
-
 #define diPrefsDrawEmblems (diPrefsCommon + 6)
 
-// ----------------------------------------------------------
-
 #define dsPreferencesColorSchemes 706
 
 #define diPrefsMainColor1 (diPrefsCommon +1)
@@ -766,33 +756,32 @@ any later version.  See the file COPYING.  */
 #define dCity 803
 
 #define diCityMap 3
-#define diCityBuildPopup 4
-#define diCityAdvancePopup 5
-#define diCityName 6
+#define diCityMatPanel 4
+#define diCityFacPanel 5
+#define diCityOccPanel 6
 
-// --- STATUS INFO SUPPORT -------------------------------------
+#define diCityPlanPopup 7
+#define diCityAdvancePopup 8
+#define diCityResearchStatus 9
+#define diCityBuildPopup 10
+#define diCityBuildStatus 11
 
-#define diCitySize 7
-#define diCityMPanel 8
+#define diCityAICheck 12
+#define diCityPlanCheck 13
+#define diCityAdvanceCheck 14
+#define diCityBuildCheck 15
+#define diCityBuildRepeat 16
+#define diCityBuildEdit 17
 
-//	#define diCitySizeText 7
-//	#define diCitySize 8
+#define diCityName 18
+#define diCitySize 19
+#define diCityStats 20
 
-#define diCityStats 9
+#define diCityMatBase 16
+#define diCityOccBase 41
 
-// --- STATUS INFO SUPPORT -------------------------------------
-
-#define diCityBuildStatus 33
-#define diCityResearchStatus 34
-#define diCityFirstUnitIcon 36
-
-#define diCityBuildEdit 76
-#define diCityBuildCheck 78
-#define diCityAdvanceCheck 79
-
-#define diCityMenuBox 80
-
-// ---------------------------------------------------------
+#define diCityIcon 93
+#define diCityClickText 94
 
 #define dAdvance 804
 
@@ -801,14 +790,9 @@ any later version.  See the file COPYING.  */
 #define diAdvanceIdleScientist 5
 #define diAdvanceMainText 6
 #define diAdvancePopup 7
-
-// --- STATUS INFO SUPPORT -------------------------------------
-
 #define diAdvanceStatus 8
 #define diAdvanceCheck 9
 
-// ---------------------------------------------------------
-
 #define dGlobalAdvance 805
 
 #define diGlobalMadScientist 3
@@ -817,25 +801,13 @@ any later version.  See the file COPYING.  */
 #define diGlobalMainText 6
 #define diGlobalIdleMenu 7		/* First popup menu (Idle units). */
 #define diGlobalIdleNum 17		/* Its associated number of cities. */
-
-// --- STATUS INFO SUPPORT -------------------------------------
-
 #define diGlobalIdleStatus 27	/* Completion status of research. */
 #define diGlobalIdleText 37		/* Its associated text. */
-
 #define diGlobalMoreNote 47	
-
 #define diGlobalDoneMenu 50
-
 #define diGlobalIdleCheck 53
-
 #define diGlobalAllCheck 64
 
-//	#define diGlobalIdleText 27		/* Its associated text. */
-//	#define diGlobalMoreNote 37
-
-// ----------------------------------------------------------
-
 #define dMeridians 806
 
 #define diMeridiansOK 1
@@ -843,8 +815,6 @@ any later version.  See the file COPYING.  */
 #define diMeridiansOnOff 3
 #define diMeridiansInterval 4
 
-// --- UNIT BUILD DIALOG ----------------------------------------
-
 #define dBuild 807
 
 #define diBuildMadScientist 3
@@ -857,7 +827,15 @@ any later version.  See the file COPYING.  */
 #define diBuildText 10
 #define diBuildCheck 11
 
-// ----------------------------------------------------------
+#define dPlan 808
+
+#define diPlanMainText 4
+#define diPlanPopup 5
+#define diPlanCheck 6
+
+#define dWorldMap 809
+
+#define diWorldMapOK 1
 
 #define MAXPROJMENUS 9		/* Max number of project menus (excluding Idle units) and associated items. */
 
@@ -938,6 +916,9 @@ any later version.  See the file COPYING.  */
 #define wNotice 136
 #define wCommand 137
 #define wScores 138
+#define wFloatFixed 139
+#define wFloatResize 140
+#define wInstructions 141
 
 /* Controls. */
 
@@ -945,6 +926,7 @@ any later version.  See the file COPYING.  */
 #define cResearchButton 129
 #define cRunLengthPopup 210
 
+#define cCloseButton 130
 #define cTopicsButton 131
 #define cHelpButton 132
 #define cPrevButton 133
@@ -989,6 +971,11 @@ any later version.  See the file COPYING.  */
 #define cSendPacket 300
 #define cReceivePacket 301
 
+#define cLeft 401
+#define cRight 402
+#define cDown 403
+#define cUp 404
+
 /* Patterns. */
 
 #define pMarchingAnts 128
