@@ -278,7 +278,7 @@ draw_design_window_tool(enum tooltype tool)
 	int i;
 
 	/* Don't draw unused tools. */
-	if (enabledtooltype[i] == FALSE)
+	if (enabledtooltype[tool] == FALSE)
 		return;
 	SetRect(&tmprect, 0, 0, dtoolw, dtoolh);
 	/* Don't include unused tools in offset. */
