@@ -182,28 +182,30 @@ reduce_screen_depth(GDHandle gdev)
 void 
 scroll_map_window(Map *map, int dx, int dy)
 {
-	int 		newsx, newsy, scaled_sx, scaled_sy, dummy, redraw = FALSE;
-	Rect		destRect, tmprect, portrect = map->gworldPortPtr->portRect;
+	int 		mainw, mainh, newsx, newsy, scaled_sx, scaled_sy, dummy, redraw = FALSE;
+	Rect		destRect, mapRect;
+	Point		mapUL, mapDR;
 	GrafPtr	oldport;
+	WindowPtr	win;
 
 	GetPort(&oldport);
-	/* Set current port to the map window */
+	/* Set current port to the map window. */
 	SetPort((GrafPtr)map->windowPortPtr);
 
   	if (DebugG) {
-		/* Erase the old debugRect */
+		/* Erase the old debugRect. */
 		ForeColor(redColor);
 		PenMode(patXor);
 		FrameRect(&debugRect);
 		ForeColor(blackColor);
 		PenMode(normal);
-		scrolling = TRUE;	/* Turns off debugRect while scrolling */
+		scrolling = TRUE;	/* Turn off debugRect while scrolling. */
 	}
 
-	/* Erase other-map boxes in other windows */
+	/* Erase other-map boxes in other windows. */
 	draw_related_maps(map);
 
-	/* Find the new position */
+	/* Find the new position. */
 	newsx = map->vp->sx + dx;
 	newsy = map->vp->sy + dy;
 	
@@ -214,44 +216,44 @@ scroll_map_window(Map *map, int dx, int dy)
 		while (newsx <= 0)
 		  newsx += map->vp->sxmax;
 	} else {		
-		/* Handle non-xwrapped world. */
-		/* Restrict newsx to stay between the map edges. */
+		/* Handle non-xwrapped world. Restrict newsx to stay between the map edges. */
 		newsx = limitn(map->vp->sxmin, newsx, map->vp->sxmax);
-		/* Adjust dx to reflect this restriction */
+		/* Adjust dx to reflect this restriction. */
 		dx = newsx - map->vp->sx;
 	}
 
-	/* Scale the scrollbar to circumvent the 32K limit */
-	/* (see set_map_scrollbars for details) */
+	/* Scale the scrollbar to circumvent the 32K limit (see 
+	set_map_scrollbars for details). */
 	dummy = map->vp->sxmax;
 	scaled_sx = newsx;
 	while (dummy > 32000) {
 		dummy /= 2;
 		scaled_sx /= 2;
 	}		
-	/* Use the scaled value to set the new thumb position */
+	/* Use the scaled value to set the new thumb position. */
 	SetCtlValue(map->hscrollbar, scaled_sx);
 
-	/* Restrict newsy to stay between the map edges */
+	/* Restrict newsy to stay between the map edges. */
 	newsy = limitn(map->vp->symin, newsy, map->vp->symax);
-	/* Adjust dy to reflect this restriction */
+	/* Adjust dy to reflect this restriction. */
 	dy = newsy - map->vp->sy;
 
-	/* Scale the scrollbar to circumvent the 32K limit */
-	/* (see set_map_scrollbars for details) */
+	/* Scale the scrollbar to circumvent the 32K limit (see 
+	set_map_scrollbars for details). */
 	dummy = map->vp->symax;
 	scaled_sy = newsy;
 	while (dummy > 32000) {
 		dummy /= 2;
 		scaled_sy /= 2;
 	}		
-	/* Use the scaled value to set the new thumb position */
+	/* Use the scaled value to set the new thumb position. */
 	SetCtlValue(map->vscrollbar, scaled_sy);
 
-	/* Move the viewport */
+	/* Move the viewport. */
 	map->vp->sx = newsx;
 	map->vp->sy = newsy;
 	set_content_rect(map);
+	
 	/* Handle dx. Don't update if the map is wrapped. */
 	if (map->xwrap) {
 		redraw = FALSE; 
@@ -260,84 +262,189 @@ scroll_map_window(Map *map, int dx, int dy)
 		/* Handles dx in other cases.  Update if stepping outside. */
 		redraw = TRUE;
 	}		
-	/* Always update if dy take us outside the gworld */
+	/* Always update if dy take us outside the gworld. */
 	if ((dy > 0 && map->offsety + dy > map->bufy)
 		|| (dy < 0 && map->offsety + dy < -map->bufy)) {
 		redraw = TRUE;
 	}		
 
 	if (redraw) {
-		/* Redraw gworld and copy contentrect to the window */
+		/* Redraw gworld and copy contentrect to the window. */
 		update_gworld(map);
-		/* Redraw other-map boxes and restore port before exit */
+		/* Redraw other-map boxes and restore port before exit. */
 		draw_related_maps(map);
 		SetPort(oldport);
 		if (DebugG) {
-			SetRect(&debugRect, 0, 0, 0, 0);		/* Prevents drawing of junk next time */
-			scrolling = FALSE;				/* Turns on debugRect after scrolling */
+			SetRect(&debugRect, 0, 0, 0, 0);		/* Prevents drawing of junk next time. */
+			scrolling = FALSE;				/* Turn on debugRect after scrolling. */
 		}
 		return;
 	}	   
 	  
-	/* Scroll the already drawn region */
+	/* Scroll the already drawn region. */
 	ScrollRect(&map->contentrect, -dx, -dy, NULL);
-	/* Update offset trackers */
+	/* Update offset trackers. */
 	map->offsetx += dx;
 	map->offsety += dy;
-	/* Wrap offsetx if necessary */
+	/* Wrap offsetx if necessary. */
 	map->offsetx %= map->vp->sxmax;
 
-	/* Calculate update rects and update each one in turn from the gworld */
+	/* Find the corners of the map contentrect in global coordinates. */
+	mapUL.h = map->contentrect.left;
+	mapUL.v = map->contentrect.top;
+	mapDR.h = map->contentrect.right;
+	mapDR.v = map->contentrect.bottom;
+	LocalToGlobal(&mapUL);			
+	LocalToGlobal(&mapDR);			
 
-	if (dx > 0) {				/* Going Right */
-		SetRect(&destRect, 
-				map->conw + map->vp->pxw - dx, 
-				map->toph, 
-				map->conw + map->vp->pxw, 
-				map->toph + map->vp->pxh);
+	/* Clip it to main screen minus menubar to fix graphics drag at edges. */
+	get_main_screen_size(&mainw, &mainh);
+	mapUL.h = max(0, mapUL.h);
+	mapUL.v = max(GetMBarHeight(), mapUL.v);
+	mapDR.h = min(mapDR.h, mainw);
+	mapDR.v = min(mapDR.v, mainh);
+		
+	/* Convert clipped contentrect back to local coordinates. */
+	GlobalToLocal(&mapUL);
+	GlobalToLocal(&mapDR);
+	SetRect(&mapRect, mapUL.h, mapUL.v, mapDR.h, mapDR.v);
 
+	/* Do horizontal scrolling. */
+	destRect = mapRect;
+
+	if (dx > 0) {							/* Going Right. */
+		destRect.left = destRect.right - dx; 
 		copy_from_gworld(map, destRect);
-	
-	} else if (dx < 0) {			/* Going Left */
-		SetRect(&destRect, 
-				map->conw, 
-				map->toph, 
-				map->conw - dx, 
-				map->toph + map->vp->pxh);
-
+	} else if (dx < 0) {						/* Going Left. */
+		destRect.right = destRect.left - dx; 
 		copy_from_gworld(map, destRect);
 	}
 
-	if (dy > 0) {				/* Going Down */
-		SetRect(&destRect, 
-			/* Skip area already updated by Going Right */
-			max(map->conw,   map->conw - dx), 
-		   	         map->toph + map->vp->pxh - dy, 
-			/* Skip area already updated by Going Left */
-			min(map->conw + map->vp->pxw, map->conw + map->vp->pxw - dx), 
-				map->toph + map->vp->pxh);
+	/* Do vertical scrolling. */
+	destRect = mapRect;
 
+	/* Skip overlap already updated by Going Right or Going Left. */
+	destRect.left = max(destRect.left, destRect.left - dx); 
+	destRect.right = min(destRect.right, destRect.right - dx);		
+
+	if (dy > 0) {							/* Going Down. */
+		destRect.top = destRect.bottom - dy;
 		copy_from_gworld(map, destRect);
-
-	} else if (dy < 0) {			/* Going Up */
-		SetRect(&destRect, 
-			/* Skip area already updated by Going Right */
-			 max(map->conw,   map->conw - dx), 
-		   	         map->toph, 
-			/* Skip area already updated by Going Left */
-			 min(map->conw + map->vp->pxw, map->conw + map->vp->pxw - dx), 
-				map->toph - dy);
-
+	} else if (dy < 0) {						/* Going Up. */
+		destRect.bottom = destRect.top - dy;
 		copy_from_gworld(map, destRect);
 	}
 	
-	/* Redraw other-map boxes and restore the old port */
+	/* This handles situations where we have hidden the scrollbars and the grow box forms
+	a small protruding corner that causes a graphics drag. */
+	
+	if (!map->sbarwid) {
+
+		Rect		growRect;
+
+		/* Calculate the grow box rect. */
+		growRect = map->contentrect;
+		growRect.left = growRect.right - (map != worldmap ? sbarwid : floatsbarwid);
+		growRect.top = growRect.bottom - (map != worldmap ? sbarwid : floatsbarwid);
+
+		/* Clip to (map and) main screen content. Proceed if an overlap was found. */
+		if (SectRect(&growRect, &mapRect, &growRect) == TRUE) {
+		
+			/* Do horizontal scrolling. */
+			if (dx > 0) {						/* Going Right. */
+				destRect = growRect;
+				destRect.right = destRect.left;
+				destRect.left -= dx;
+				destRect.top -= dy;
+				copy_from_gworld(map, destRect);
+			}
+
+			/* Do vertical scrolling. */
+			if (dy > 0) {						/* Going Down. */
+				destRect = growRect;
+				destRect.bottom = destRect.top;
+				destRect.top -= dy;
+				/* Add small square missed by Going Right. */	
+				destRect.left -= dx;							
+				copy_from_gworld(map, destRect);
+			}
+		}
+	}
+	
+	/* This updates areas that scroll into view from behind floating windows. Note that 
+	because of the inverted geometry, going-down and going-up ADDS an extra square at
+	the end of destRect instead of skipping one (min and max are reversed). */
+
+	/* Note: this code also handles non-floating windows in front of the scrolled window
+	correctly. Can happen if the map is scrolled in the background. */
+
+	for_all_windows(win) {
+
+		WindowPeek 	winPeek;
+		Rect			winRect;		
+		Point			winUL;
+		Point			winDR;
+					
+		/* Stop when we reach the map window. */
+		if (win == map->window)
+			break;
+
+		/* Find the corners of the window in global coordinates. */
+		winPeek = (WindowPeek) win;
+		winRect = (*(winPeek->strucRgn))->rgnBBox;			
+		
+		/* Transform the result into local coordinates. */
+		winUL.h = winRect.left;
+		winUL.v = winRect.top;
+		winDR.h = winRect.right;
+		winDR.v = winRect.bottom;
+		GlobalToLocal(&winUL);			
+		GlobalToLocal(&winDR);			
+		SetRect(&winRect, winUL.h, winUL.v, winDR.h, winDR.v);
+
+		/* Clip window rect to the map (and main screen) content. Skip 
+		to the next window if no overlap was found. */
+		if (SectRect(&winRect, &mapRect, &winRect) != TRUE)
+		    continue;
+
+		/* Do horizontal scrolling. */
+		destRect = winRect;
+
+		if (dx > 0) {						/* Going Right. */
+			destRect.right = destRect.left;
+			destRect.left -= dx;
+			copy_from_gworld(map, destRect);
+		} else if (dx < 0) {					/* Going Left. */
+			destRect.left = destRect.right;
+			destRect.right -= dx;
+			copy_from_gworld(map, destRect);
+		}
+
+		/* Do vertical scrolling. */
+		destRect = winRect;
+
+		/* Add small square missed by Going Right or Going Left. */
+		destRect.left = min(destRect.left, destRect.left - dx); 
+		destRect.right = max(destRect.right, destRect.right - dx);		
+
+		if (dy > 0) {						/* Going Down. */
+			destRect.bottom = destRect.top;
+			destRect.top -= dy;
+			copy_from_gworld(map, destRect);
+		} else if (dy < 0) {					/* Going Up. */
+			destRect.top = destRect.bottom;
+			destRect.bottom -= dy;
+			copy_from_gworld(map, destRect);
+		}
+	}
+
+	/* Redraw other-map boxes and restore the old port. */
 	draw_related_maps(map);
 	SetPort(oldport);
 
 	if (DebugG) {
-		SetRect(&debugRect, 0, 0, 0, 0);		/* Prevents drawing of junk next time */
-		scrolling = FALSE;				/* Turns on debugRect after scrolling */
+		SetRect(&debugRect, 0, 0, 0, 0);		/* Prevents drawing of junk next time. */
+		scrolling = FALSE;				/* Turn on debugRect after scrolling. */
 				
 	}
 }
@@ -715,8 +822,10 @@ handle_numeric_keypad(EventRecord *event)
 
 	List *list;
 
-	/* Get the front map */
-	map = front_map();
+	/* Get the worldmap if alt key was down, else get the front map. */
+	if (event->modifiers & optionKey)
+		map = worldmap;
+	else	map = frontmap;
 
 	/* Check keys by keyCode instead of charCode to identify numeric keypad events */
 	key = (event->message & keyCodeMask) >> 8;
@@ -733,14 +842,16 @@ handle_numeric_keypad(EventRecord *event)
 	  return FALSE;
 
 	/* Keyboard scrolling of list window. */
-	/* First check if the front window is a list window. */
-	if ((list = list_from_window(FrontWindow())) != NULL) {
+
+	/* First check if the front window is a list and scroll it if we pressed a normal arrow key. */
+	if (((list = list_from_window(topWindow)) != NULL) && map != worldmap
+	     && (key == 0x7B || key == 0x7C || key == 0x7D || key == 0x7E)) {
 		scroll_list_using_key(list, key);
 		return TRUE;
 	}
 
 	/* Return TRUE and BEEP if the front window is not a map window */
-	if (!map || map->window != FrontWindow()) {
+	if (!map) {
 		beep(); 
 		return TRUE;
 	}
@@ -788,8 +899,8 @@ handle_numeric_keypad(EventRecord *event)
 		if (key == 0x7D) { auto_scroll_down_arrow(map); return TRUE; }		/* Down Arrow */
 
 		if (key == 0x57) { do_recenter(dside); return TRUE; }			/* Keypad 5 */
-		if (key == 0x45) { do_zoom_in(dside); return TRUE; }			/* Keypad + */
-		if (key == 0x4E) { do_zoom_out(dside); return TRUE; }			/* Keypad - */
+		if (key == 0x45) { magnify_map(map, 1); return TRUE; }		/* Keypad + */
+		if (key == 0x4E) { magnify_map(map, -1); return TRUE; }		/* Keypad - */
 
 		if (key == 0x43) { rotate_angle_up(map); return TRUE; }		/* Keypad * */
 		if (key == 0x4B) { rotate_angle_down(map); return TRUE; }		/* Keypad / */
@@ -819,7 +930,7 @@ auto_scroll_left(Map *map)
 
 	while (keyDown) {
 		scroll_map_window(map, -4, 0);
-		GetKeys((long *) keyMap);
+		GetKeys((unsigned long *) keyMap);
 		keyDown = keyMap[0x56 >> 3] >> (0x56 & 7) & 1;	/* keypad 4 */
 	}
 }
@@ -834,7 +945,7 @@ auto_scroll_right(Map *map)
 
 	while (keyDown) {
 		scroll_map_window(map, 4, 0);
-		GetKeys((long *) keyMap);
+		GetKeys((unsigned long *) keyMap);
 		keyDown = keyMap[0x58 >> 3] >> (0x58 & 7) & 1;	/* keypad 6 */
 	}
 }
@@ -849,7 +960,7 @@ auto_scroll_up(Map *map)
 
 	while (keyDown) {
 		scroll_map_window(map, 0, -4);
-		GetKeys((long *) keyMap);
+		GetKeys((unsigned long *) keyMap);
 		keyDown = keyMap[0x5B >> 3] >> (0x5B & 7) & 1;	/* keypad 8 */
 	}
 }
@@ -864,7 +975,7 @@ auto_scroll_down(Map *map)
 
 	while (keyDown) {
 		scroll_map_window(map, 0, 4);
-		GetKeys((long *) keyMap);
+		GetKeys((unsigned long *) keyMap);
 		keyDown = keyMap[0x54 >> 3] >> (0x54 & 7) & 1;	/* keypad 2 */
 	}
 }
@@ -879,7 +990,7 @@ auto_scroll_down_left(Map *map)
 
 	while (keyDown) {
 		scroll_map_window(map, -4, 4);
-		GetKeys((long *) keyMap);
+		GetKeys((unsigned long *) keyMap);
 		keyDown = keyMap[0x53 >> 3] >> (0x53 & 7) & 1;	/* keypad 1 */
 	}
 }
@@ -894,7 +1005,7 @@ auto_scroll_down_right(Map *map)
 
 	while (keyDown) {
 		scroll_map_window(map, 4, 4);
-		GetKeys((long *) keyMap);
+		GetKeys((unsigned long *) keyMap);
 		keyDown = keyMap[0x55 >> 3] >> (0x55 & 7) & 1;	/* keypad 3 */
 	}
 }
@@ -909,7 +1020,7 @@ auto_scroll_up_left(Map *map)
 
 	while (keyDown) {
 		scroll_map_window(map, -4, -4);
-		GetKeys((long *) keyMap);
+		GetKeys((unsigned long *) keyMap);
 		keyDown = keyMap[0x59 >> 3] >> (0x59 & 7) & 1;	/* keypad 7 */
 	}
 }
@@ -924,7 +1035,7 @@ auto_scroll_up_right(Map *map)
 
 	while (keyDown) {
 		scroll_map_window(map, 4, -4);
-		GetKeys((long *) keyMap);
+		GetKeys((unsigned long *) keyMap);
 		keyDown = keyMap[0x5C >> 3] >> (0x5C & 7) & 1;	/* keypad 9 */
 	}
 }
@@ -939,7 +1050,7 @@ auto_scroll_left_arrow(Map *map)
 
 	while (keyDown) {
 		scroll_map_window(map, -4, 0);
-		GetKeys((long *) keyMap);
+		GetKeys((unsigned long *) keyMap);
 		keyDown = keyMap[0x7B >> 3] >> (0x7B & 7) & 1;	/* left arrow */
 	}
 }
@@ -954,7 +1065,7 @@ auto_scroll_right_arrow(Map *map)
 
 	while (keyDown) {
 		scroll_map_window(map, 4, 0);
-		GetKeys((long *) keyMap);
+		GetKeys((unsigned long *) keyMap);
 		keyDown = keyMap[0x7C >> 3] >> (0x7C & 7) & 1;	/* right arrow */
 	}
 }
@@ -969,7 +1080,7 @@ auto_scroll_up_arrow(Map *map)
 
 	while (keyDown) {
 		scroll_map_window(map, 0, -4);
-		GetKeys((long *) keyMap);
+		GetKeys((unsigned long *) keyMap);
 		keyDown = keyMap[0x7E >> 3] >> (0x7E & 7) & 1;	/* keypad 8 */
 	}
 }
@@ -984,7 +1095,7 @@ auto_scroll_down_arrow(Map *map)
 
 	while (keyDown) {
 		scroll_map_window(map, 0, 4);
-		GetKeys((long *) keyMap);
+		GetKeys((unsigned long *) keyMap);
 		keyDown = keyMap[0x7D >> 3] >> (0x7D & 7) & 1;	/* keypad 2 */
 	}
 }
@@ -1022,8 +1133,11 @@ set_offscreen_buffers(Map *map)
 	Rect itemrect;
 	Str255 tmpstr;
 	DialogPtr win;
+	GrafPtr oldport;
 
 	win = GetNewDialog(dOffscreen, NULL, (DialogPtr) -1);
+	GetPort(&oldport);	
+	SetPort(win);
 
 	GetDItem(win, diOffscreenHorizBuff, &itemtype, &itemhandle, &itemrect);
 	NumToString(map->max_bufx, tmpstr);
@@ -1056,7 +1170,7 @@ set_offscreen_buffers(Map *map)
 				map->max_bufy = max(*itemnum, 0);
 				
 				/* Redraw the gworld (and the map) */
-				update_gworld(map);
+				force_map_update(map);
 				done = TRUE;
 				break;
 
@@ -1070,7 +1184,7 @@ set_offscreen_buffers(Map *map)
 		}
 	}
 	DisposeDialog(win);
-
+	SetPort(oldport);
 	update_all_map_windows();
 }
 
@@ -1086,8 +1200,11 @@ set_meridians(Map *map)
 	Rect itemrect;
 	Str255 tmpstr;
 	DialogPtr win;
+	GrafPtr oldport;
 
 	win = GetNewDialog(dMeridians, NULL, (DialogPtr) -1);
+	GetPort(&oldport);	
+	SetPort(win);
 
 	GetDItem(win, diMeridiansOnOff, &itemtype, &itemhandle, &itemrect);
 	SetCtlValue((ControlHandle) itemhandle, map->vp->draw_latlong);
@@ -1119,7 +1236,7 @@ set_meridians(Map *map)
 				map->vp->latlong_interval = max(*itemnum, 0);
 
 				/* Redraw the gworld (and the map) */
-				update_gworld(map);
+				force_map_update(map);
 				done = TRUE;
 				break;
 
@@ -1133,7 +1250,7 @@ set_meridians(Map *map)
 		}
 	}
 	DisposeDialog(win);
-
+	SetPort(oldport);
 	update_all_map_windows();
 }
 
