@@ -478,7 +478,7 @@ draw_help()
 	/* Draw a bit of graphic for some help nodes. */
 	if (cur_help_node->nclass == utypenode && is_unit_type(cur_help_node->arg)) {
 		draw_unit_image(helpwin, tmprect.left, tmprect.top, 32, 32,
-						cur_help_node->arg, -1, 0, FALSE);
+						cur_help_node->arg, 0, 0, FALSE);
 	} else if (cur_help_node->nclass == ttypenode && is_terrain_type(cur_help_node->arg)) {
 		draw_terrain_sample(helpwin, tmprect, cur_help_node->arg); 
 	} else if (cur_help_node->nclass == mtypenode && is_material_type(cur_help_node->arg)) {
