@@ -124,7 +124,7 @@ mac_load_imf(ImageFamily *imf)
 	}
 	pichandle = (PicHandle) GetNamedResource('PICT', namestr);
 	if (pichandle != nil) {
-		img = get_img(imf, 16, 16, 0); /* should get real bounds */
+		img = get_img(imf, 16, 16); /* should get real bounds */
 		if (img != NULL) {
 			macimg = get_mac_image(img);
 			/* (should distinguish mono and color picts somehow) */
@@ -153,7 +153,7 @@ mac_load_imf(ImageFamily *imf)
 	/* Pick up ICONs. */
 	iconhandle = (Handle) GetNamedResource('ICON', namestr);
 	if (iconhandle != nil) {
-		img = get_img(imf, 32, 32, 0);
+		img = get_img(imf, 32, 32);
 		if (img != NULL) {
 			macimg = get_mac_image(img);
 			macimg->monoicon = iconhandle;
@@ -167,7 +167,7 @@ mac_load_imf(ImageFamily *imf)
 	/* Pick up SICNs. */
 	sicnhandle = (Handle) GetNamedResource('SICN', namestr);
 	if (sicnhandle != nil) {
-		img = get_img(imf, 16, 16, 0);
+		img = get_img(imf, 16, 16);
 		if (img != NULL) {
 			macimg = get_mac_image(img);
 			/* Image itself is just the first 32 bytes, mask is second 32 if present. */
@@ -206,7 +206,7 @@ mac_load_imf(ImageFamily *imf)
 	   is always 8x8. */
 	pathandle = GetNamedResource('PAT ', namestr);
 	if (pathandle != nil) {
-		img = get_img(imf, 8, 8, 0);
+		img = get_img(imf, 8, 8);
 		if (img != NULL) {
 			img->istile = TRUE;
 			macimg = get_mac_image(img);
@@ -264,7 +264,7 @@ mac_add_cicn(ImageFamily *imf, Handle handle)
 	pmap = (*cicnhandle)->iconPMap;
 	bounds = pmap.bounds;
 	w = bounds.right - bounds.left;  h = bounds.bottom - bounds.top;
-	img = get_img(imf, w, h, 0);
+	img = get_img(imf, w, h);
 	if (img != NULL) {
 		macimg = get_mac_image(img);
 		if (!macimg->cicn_inited) {
@@ -330,7 +330,7 @@ mac_add_ppat(ImageFamily *imf, Handle handle)
 				}
 			}
 	}
-	img = get_img(imf, w, h, 0);
+	img = get_img(imf, w, h);
 	if (img != NULL) {
 		/* Indicate that we can use this pattern for any size area. */
 		img->istile = TRUE;
@@ -346,7 +346,7 @@ mac_add_ppat(ImageFamily *imf, Handle handle)
 		} else {
 			macimg->colrpat = ppathandle;
 			/* A ppat always has an 8x8 mono pattern defined. */
-			img = get_img(imf, 8, 8, 0);
+			img = get_img(imf, 8, 8);
 			if (img != NULL) {
 				img->istile = TRUE;
 				macimg = get_mac_image(img);
