@@ -169,8 +169,6 @@ int selectedplayer = -1;
 UserItemUPP draw_player_setup_list_proc;
 UserItemUPP draw_player_setup_advantage_proc;
 
-int you_player;
-
 /* Caches of images and colors. */
 
 ImageFamily **uimages = NULL;
@@ -332,7 +330,13 @@ filter_splash(DialogPtr dialog, EventRecord *evt, short *itemhit)
 				short itemtype;  Handle itemhandle;  Rect itemrect;
 
 				GetDItem(dialog, diSplashVersion, &itemtype, &itemhandle, &itemrect);
-				debugging_string(buf);
+
+				/* (debugging_string doesn't handle profiling). */
+				if (Debug || DebugM || DebugG || Profile) {
+					sprintf(buf, "%c%c%c%c",
+							(Debug ? 'D' : ''), (DebugM ? 'M' : ''), (DebugG ? 'G' : ''),
+							(Profile ? 'P' : ''));
+				}
 				c2p(buf, tmpstr);
 				SetIText(itemhandle, tmpstr);
 				DrawControls(dialog);
@@ -1747,6 +1751,7 @@ player_setup_dialog()
 	  draw_player_setup_list_proc = NewUserItemProc(draw_player_setup_list);
 	if (draw_player_setup_advantage_proc == NULL)
 	  draw_player_setup_advantage_proc = NewUserItemProc(draw_player_setup_advantage);
+#if 0  /* no longer appropriate */
 	if (my_rid > 0 && you_player > 0) {
 		int i;
 		Player *player;
@@ -1759,6 +1764,7 @@ player_setup_dialog()
 			}
 		}
 	}
+#endif
 	/* Create the window. */
 	if (playersetupwin == nil) {
 		playersetupwin = GetNewDialog(dPlayerSetup, NULL, (DialogPtr) -1L);
@@ -1977,7 +1983,7 @@ hit_player_setup_dialog(int ditem, Point pt)
 		connection_method_dialog();
 		if (connection_method > 0) {
 			hosting = TRUE;
-			open_remote_connection(connection_method_name);
+			open_remote_connection(connection_method_name, hosting);
 		}
 	}
 	if (changedall || changedselected) {
@@ -2028,13 +2034,6 @@ add_remote_player(char *name)
 	beep();
 }
 
-void
-set_you_player(id)
-int id;
-{
-	you_player = id;
-}
-
 /* This dialog opens a player-specified file as a game. */
 
 int
@@ -2523,7 +2522,7 @@ init_terrain_images()
 		for_all_terrain_types(t) {
 			
 			/* Find (or create) a 1x1 image. */
-			img = get_img(timages[t], 1, 1, 0);
+			img = get_img(timages[t], 1, 1);
 			
 			/* Needed only in the presence of mac-lib. */
 			mac_interp_imf(timages[t], img, 0);
