@@ -1,5 +1,5 @@
 /* Map graphics for the Mac interface to Xconq.
-   Copyright (C) 1992-1998 Stanley T. Shebs.
+   Copyright (C) 1992-1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -533,10 +533,6 @@ set_map_scrollbars(Map *map)
 	SetCtlMin(map->hscrollbar, scaled_sxmin);
 	SetCtlMax(map->hscrollbar, scaled_sxmax);
 	SetCtlValue(map->hscrollbar, scaled_sx);
-	/* (HiliteControl call removed - caused display bug). */
-	DGprintf("Hscroll (%shilite) is %d -- %d -- %d\n",
-			 (hilite ? "" : "no "), GetCtlMin(map->hscrollbar),
-	         GetCtlValue(map->hscrollbar), GetCtlMax(map->hscrollbar));
 
 	/* Also scale the vertical scrollbar even though no current games are that high. */
 	scaled_symin = map->vp->symin;
@@ -552,11 +548,8 @@ set_map_scrollbars(Map *map)
 	SetCtlMin(map->vscrollbar, scaled_symin);
 	SetCtlMax(map->vscrollbar, scaled_symax);
 	SetCtlValue(map->vscrollbar, scaled_sy);
-	/* (HiliteControl call removed- caused display bug). */
+
 	set_content_rect(map);
-	DGprintf("Vscroll (%shilite) is %d -- %d -- %d\n",
-			 (hilite ? "" : "no "), GetCtlMin(map->vscrollbar),
-	         GetCtlValue(map->vscrollbar), GetCtlMax(map->vscrollbar));
 }
 
 /* Given a magnification power, look up and/or calculate the sizes of everything,
@@ -2282,7 +2275,7 @@ Unit *unit;
 /* This function is called by the kernel whenever something needs to be updated. */
 
 void  
-update_cell_display(Side *side, int x, int y, int rightnow)
+update_cell_display(Side *side, int x, int y, int flags)
 {
 	Map *map;
 	
@@ -2290,13 +2283,14 @@ update_cell_display(Side *side, int x, int y, int rightnow)
 	  return;
 
 	for_all_maps(map) {
-		/* If update was only to report changes in undrawn info, maybe don't bother. */
-		if ((rightnow == 34 && !map->vp->draw_temperature) 
-		    || (rightnow == 37 && !map->vp->draw_clouds)
-		    || (rightnow == 35 && !map->vp->draw_winds)
-		    || (rightnow == 36 && !map->vp->draw_cover))
-			continue;
-		update_cell(map, x, y);
+		if (((flags & UPDATE_ALWAYS)
+		     || ((flags & UPDATE_COVER) && map->vp->draw_cover)
+		     || ((flags & UPDATE_TEMP) && map->vp->draw_temperature)
+		     || ((flags & UPDATE_CLOUDS) && map->vp->draw_clouds)
+		     || ((flags & UPDATE_WINDS) && map->vp->draw_winds)
+		     )) {
+			update_cell(map, x, y);
+		}
 	}
 }
 
