@@ -1609,8 +1609,9 @@ apply_to_all_selected(int (*fn)(Unit *unit), int beepfailure)
 			  ++numnot;
 		}
 	} else if ((closeup = unit_closeup_from_window(topFloat)) != NULL) {
+		unit = closeup->unit;
 		/* Don't apply to units that we don't control. */
-		if (side_controls_unit(dside, closeup->unit)) {
+		if (side_controls_unit(dside, unit)) {
 			rslt = (*fn)(unit);
 			if (rslt)
 			  ++numcould;
