@@ -227,20 +227,22 @@ interp_mac_ui_data(Obj *uispec)
 			  default_shorelines = numval;
 			else if (strcmp(name, "simple-borders") == 0)
 			  default_simple_borders = numval;
+			else if (strcmp(name, "draw-ai") == 0)
+			  default_draw_ai = numval;
+			else if (strcmp(name, "depth-alert") == 0)
+			  alert_256_colors = numval;
 			else if (strcmp(name, "optimize-fonts") == 0)
 			  default_optimize_fonts = numval;
-
-// --- USER CONTROL OF EMBLEMS -------------------------------------------
-
 			else if (strcmp(name, "draw-emblems") == 0)
 			  default_draw_emblems = numval;
-
-// -------------------------------------------------------------------
-
 			else if (strcmp(name, "draw-topline") == 0)
 			  default_draw_topline = numval;
 			else if (strcmp(name, "draw-topunit") == 0)
 			  default_draw_topunit = numval;
+			else if (strcmp(name, "draw-scrollbars") == 0)
+			  default_draw_scrollbars = numval;
+			else if (strcmp(name, "draw-cpanel") == 0)
+			  default_draw_cpanel = numval;
 			else if (strcmp(name, "drawothermaps") == 0)
 			  default_drawothermaps = numval;
 			else if (strcmp(name, "erase-names") == 0)
@@ -364,16 +366,14 @@ ui_update_state()
 	push_binding(&state, intern_symbol("featurenames"), new_number(default_featurenames));
 	push_binding(&state, intern_symbol("shorelines"), new_number(default_shorelines));
 	push_binding(&state, intern_symbol("simple-borders"), new_number(default_simple_borders));
+	push_binding(&state, intern_symbol("draw-ai"), new_number(default_draw_ai));
+	push_binding(&state, intern_symbol("depth-alert"), new_number(alert_256_colors));
 	push_binding(&state, intern_symbol("optimize-fonts"), new_number(default_optimize_fonts));
-
-// --- USER CONTROL OF EMBLEMS -------------------------------------------
-
 	push_binding(&state, intern_symbol("draw-emblems"), new_number(default_draw_emblems));
-
-// -------------------------------------------------------------------
-
 	push_binding(&state, intern_symbol("draw-topline"), new_number(default_draw_topline));
 	push_binding(&state, intern_symbol("draw-topunit"), new_number(default_draw_topunit));
+	push_binding(&state, intern_symbol("draw-scrollbars"), new_number(default_draw_scrollbars));
+	push_binding(&state, intern_symbol("draw-cpanel"), new_number(default_draw_cpanel));
 	push_binding(&state, intern_symbol("drawothermaps"), new_number(default_drawothermaps));
 	push_binding(&state, intern_symbol("erase-names"), new_number(default_erase_names));
 	push_binding(&state, intern_symbol("x-buffer"), new_number(default_max_bufx));
@@ -586,6 +586,9 @@ set_preferences()
 						GetDItem(win, diPrefsFeatureNames, &itemtype, &itemhandle, &itemrect);
 						default_featurenames = GetCtlValue((ControlHandle) itemhandle);
 
+						GetDItem(win, diPrefsAIRegions, &itemtype, &itemhandle, &itemrect);
+						default_draw_ai = GetCtlValue((ControlHandle) itemhandle);
+
 						GetDItem(win, diPrefsSimpleBorders, &itemtype, &itemhandle, &itemrect);
 						default_simple_borders = GetCtlValue((ControlHandle) itemhandle);
 
@@ -601,6 +604,12 @@ set_preferences()
 						GetDItem(win, diPrefsUnitInfo, &itemtype, &itemhandle, &itemrect);
 						default_draw_topunit = GetCtlValue((ControlHandle) itemhandle);
 
+						GetDItem(win, diPrefsScrollBars, &itemtype, &itemhandle, &itemrect);
+						default_draw_scrollbars = GetCtlValue((ControlHandle) itemhandle);
+
+						GetDItem(win, diPrefsControlPanel, &itemtype, &itemhandle, &itemrect);
+						default_draw_cpanel = GetCtlValue((ControlHandle) itemhandle);
+
 						GetDItem(win, diPrefsOtherMaps, &itemtype, &itemhandle, &itemrect);
 						default_drawothermaps = GetCtlValue((ControlHandle) itemhandle);
 
@@ -692,6 +701,9 @@ set_preferences()
 						/* Dont allow negative values */
 						default_max_bufy = max(*itemnum, 0);
 
+						GetDItem(win, diPrefs256colors, &itemtype, &itemhandle, &itemrect);
+						alert_256_colors = GetCtlValue((ControlHandle) itemhandle);
+
 						break;
 
 					case miPreferencesTopicsImageSets:
@@ -705,13 +717,9 @@ set_preferences()
 						GetDItem(win, diPrefsUnifiedCicns, &itemtype, &itemhandle, &itemrect);
 						unified_cicns = GetCtlValue((ControlHandle) itemhandle);
 
-// --- USER CONTROL OF EMBLEMS ------------------------------------------------------
-
 						GetDItem(win, diPrefsDrawEmblems, &itemtype, &itemhandle, &itemrect);
 						default_draw_emblems = GetCtlValue((ControlHandle) itemhandle);
 
-// ------------------------------------------------------------------------------
-
 						break;
 
 					case miPreferencesTopicsColorSchemes:
@@ -810,8 +818,11 @@ set_preferences()
 							case diPrefsFeatureBorders:
 							case diPrefsFeatureNames:
 							case diPrefsShoreLines:
+							case diPrefsAIRegions:
 							case diPrefsTopLine:
 							case diPrefsUnitInfo:
+							case diPrefsScrollBars:
+							case diPrefsControlPanel:
 							case diPrefsOtherMaps:
 							case diPrefsEraseNames:
 							/* Toggle checkboxes */
@@ -957,6 +968,11 @@ set_preferences()
 						break;
 					case miPreferencesTopicsOffscreen:
 						switch (ditem) {
+							/* Toggle the checkbox. */
+							case diPrefs256colors:
+								GetDItem(win, ditem, &itemtype, &itemhandle, &itemrect);
+								SetCtlValue((ControlHandle) itemhandle, !GetCtlValue((ControlHandle) itemhandle));
+								break;
 							default:
 								break;
 						}
@@ -984,17 +1000,12 @@ set_preferences()
 								SetCtlValue((ControlHandle) itemhandle, !GetCtlValue((ControlHandle) itemhandle));
 								break;
 
-
-// --- USER CONTROL OF EMBLEMS ------------------------------------------------------
-
 							/* Toggle checkbox */
 							case diPrefsDrawEmblems:
 								GetDItem(win, ditem, &itemtype, &itemhandle, &itemrect);
 								SetCtlValue((ControlHandle) itemhandle, !GetCtlValue((ControlHandle) itemhandle));
 								break;
 
-// ------------------------------------------------------------------------------
-
 							default:
 								break;
 						}
@@ -1240,10 +1251,16 @@ add_preferences_topic_items(DialogPtr win)
 			SetCtlValue((ControlHandle) itemhandle, !default_simple_borders);
 			GetDItem(win, diPrefsShoreLines, &itemtype, &itemhandle, &itemrect);
 			SetCtlValue((ControlHandle) itemhandle, default_shorelines);
+			GetDItem(win, diPrefsAIRegions, &itemtype, &itemhandle, &itemrect);
+			SetCtlValue((ControlHandle) itemhandle, default_draw_ai);
 			GetDItem(win, diPrefsTopLine, &itemtype, &itemhandle, &itemrect);
 			SetCtlValue((ControlHandle) itemhandle, default_draw_topline);
 			GetDItem(win, diPrefsUnitInfo, &itemtype, &itemhandle, &itemrect);
 			SetCtlValue((ControlHandle) itemhandle, default_draw_topunit);
+			GetDItem(win, diPrefsScrollBars, &itemtype, &itemhandle, &itemrect);
+			SetCtlValue((ControlHandle) itemhandle, default_draw_scrollbars);
+			GetDItem(win, diPrefsControlPanel, &itemtype, &itemhandle, &itemrect);
+			SetCtlValue((ControlHandle) itemhandle, default_draw_cpanel);
 			GetDItem(win, diPrefsOtherMaps, &itemtype, &itemhandle, &itemrect);
 			SetCtlValue((ControlHandle) itemhandle, default_drawothermaps);
 			GetDItem(win, diPrefsEraseNames, &itemtype, &itemhandle, &itemrect);
@@ -1314,7 +1331,8 @@ add_preferences_topic_items(DialogPtr win)
 			GetDItem(win, diPrefsVertiBuff, &itemtype, &itemhandle, &itemrect);
 			NumToString(default_max_bufy, tmpstr);
 			SetIText(itemhandle, tmpstr);
-			
+			GetDItem(win, diPrefs256colors, &itemtype, &itemhandle, &itemrect);
+			SetCtlValue((ControlHandle) itemhandle, alert_256_colors);
 			break;
 		case miPreferencesTopicsImageSets:
 			ditl = GetResource('DITL', dsPreferencesImageSets);
@@ -1330,13 +1348,9 @@ add_preferences_topic_items(DialogPtr win)
 			GetDItem(win, diPrefsUnifiedCicns, &itemtype, &itemhandle, &itemrect);
 			SetCtlValue((ControlHandle) itemhandle, unified_cicns);
 			
-// --- USER CONTROL OF EMBLEMS ------------------------------------------------
-
 			GetDItem(win, diPrefsDrawEmblems, &itemtype, &itemhandle, &itemrect);
 			SetCtlValue((ControlHandle) itemhandle, default_draw_emblems);
 
-// ------------------------------------------------------------------------			
-
 			break;
 		case miPreferencesTopicsColorSchemes:
 			ditl = GetResource('DITL', dsPreferencesColorSchemes);
