@@ -8,9 +8,9 @@ any later version.  See the file COPYING.  */
 
 #include "conq.h"
 extern char *curdatestr;
-extern char *goal_desc PARAMS ((char *buf, Goal *goal));
-extern int update_total_hist_lines PARAMS ((Side *side));
-extern int build_hist_contents PARAMS ((Side *side, int n, HistEvent **histcontents, int numvis));
+extern char *goal_desc(char *buf, Goal *goal);
+extern int update_total_hist_lines(Side *side);
+extern int build_hist_contents(Side *side, int n, HistEvent **histcontents, int numvis);
 
 #define unit_doctrine(unit)  \
   ((unit->side ? unit->side : indepside)->udoctrine[unit->type])
@@ -133,6 +133,8 @@ static ControlHandle notice_v_scrollbar;
 
 ControlActionUPP notice_vscroll_proc;
 
+static TextStyle *noticeStyle;
+
 /* Globals for the scores window. */
 
 DialogPtr scoreswin = nil;
@@ -279,15 +281,15 @@ draw_game_date()
 		gray_out_rect(&tmprect);
 	}
 #ifdef DEBUGGING
-    /* Indicate the state of all the debug flags. */
-	if (Debug || DebugM || DebugG) {
+    /* Indicate the state of all the debug flags (and profiling). */
+	if (Debug || DebugM || DebugG || Profile) {
 		sprintf(spbuf, "%c%c%c%c",
 				(Debug ? 'D' : ' '), (DebugM ? 'M' : ' '), (DebugG ? 'G' : ' '),
 				(Profile ? 'P' : ' '));
-		MoveTo(tmprect.right - 30, tmprect.top + 12);
+		MoveTo(tmprect.right - 40, tmprect.top + 12);
 		DrawText(spbuf, 0, strlen(spbuf));
 	}
-#endif /* DEBUGGING */
+#endif  /* DEBUGGING */
 }
 
 void
@@ -1418,7 +1420,7 @@ draw_unit_closeup(UnitCloseup *unitcloseup)
 	Unit *unit = unitcloseup->unit;
 	Map	*map;
 
-	update_cell_display(dside, unit->x, unit->y, TRUE);
+	update_cell_display(dside, unit->x, unit->y, UPDATE_ALWAYS);
 	if (!active_display(dside))
 	  return;
 	/* We now permit peeking at enemy units. */
@@ -1579,7 +1581,7 @@ do_mouse_down_unit_closeup(UnitCloseup *unitcloseup, Point mouse, int mods)
 			unselect_all(map);
 			select_unit_on_map(map, unit);
 		}
-		update_cell_display(dside, unit->x, unit->y, TRUE);
+		update_cell_display(dside, unit->x, unit->y, UPDATE_ALWAYS);
 		return TRUE;
 	}
 }
@@ -1592,7 +1594,7 @@ destroy_unit_closeup(UnitCloseup *unitcloseup)
 	Map	*map;
 
 	unit = unitcloseup->unit;
-	update_cell_display(dside, unit->x, unit->y, TRUE);
+	update_cell_display(dside, unit->x, unit->y, UPDATE_ALWAYS);
 	if (unitcloseuplist == unitcloseup) {
 		unitcloseuplist = unitcloseup->next;
 	} else {
@@ -1901,9 +1903,10 @@ create_notice_window()
 	TextFont(small_font_id);
 	TextSize(small_font_size);
 	h = window_width(noticewin);  v = window_height(noticewin);
-	SetRect(&viewrect, 5, 5, h - floatsbarwid, v - floatsbarwid); 
+	SetRect(&viewrect, 5, 0, h - floatsbarwid, v); 
 	destrect = viewrect;
-	notice_text = TENew(&destrect, &destrect);
+	/* Use TEStyleNew instead of TENew to enable text styles. */
+	notice_text = TEStyleNew(&destrect, &destrect);
 	/* Set up a vertical scrollbar. */
 	vscrollrect = noticewin->portRect;
 	vscrollrect.top -= 1;
@@ -1944,65 +1947,82 @@ append_notice(char *str)
 		}
 	}
 #endif
+	/* TEStyleNew sets lineHeight to -1 to enable variable heights. However, 
+	since adjust_notice_scrollbar uses lineHeight we must set it manually to
+	a suitable fixed value. */
+	(*notice_text)->lineHeight = small_font_size + 3;
+	/* Also update size and font from defaults. */
+	noticeStyle->tsSize = small_font_size;
+	noticeStyle->tsFont = small_font_id;
+	/* New turn notices end with a colon. Use blue bold face text. */
+	if (str[strlen(str) - 1] == ':') {
+		noticeStyle->tsColor = (RGBColor) {0, 0, 0xFFFF};
+		noticeStyle->tsFace = 1;
+	} else {
+		noticeStyle->tsColor = (RGBColor) {0, 0, 0};
+		noticeStyle->tsFace = 0;
+	}
+	/* Set insertion point and style. */
 	TESetSelect(32767, 32767, notice_text);
-	TEInsert(str, strlen(str), notice_text);
-	TEInsert("\r", strlen("\r"), notice_text);
-	TESetSelect(32767, 32767, notice_text);
-	(*notice_text)->destRect = (*notice_text)->viewRect;
-	/* Update on the screen. */
-	adjust_notice_scrollbar();
+	TESetStyle(doFace + doFont + doSize + doColor, noticeStyle, false, notice_text);
+	/* Add a linefeed before a new turn notice. */
+	if (str[strlen(str) - 1] == ':') {
+		TEStyleInsert("\r", strlen("\r"), 0, notice_text);
+	/* Indent all other notices by two tabs. */
+	} else {
+		TEStyleInsert("\t\t", strlen("\t\t"), 0, notice_text);
+	}
+	/* Insert the notice itself. */
+	TEStyleInsert(str, strlen(str), 0, notice_text);
+	/* Add a linefeed at the end of each notice. */
+	TEStyleInsert("\r", strlen("\r"), 0, notice_text);
+	/* Draw it. */
 	draw_notice();
 }
 
 void
 draw_notice()
 {
-	Rect tmprect;
 	GrafPtr oldport;
 
 	GetPort(&oldport);
 	SetPort(noticewin);
-	TextFont(small_font_id);
-	TextSize(small_font_size);
-	SetRect(&tmprect, 5, 40, 5 + 32, 40 + 32);
-	EraseRect(&tmprect);
+	adjust_notice_scrollbar();
 	TEUpdate(&(noticewin->portRect), notice_text);
 	SetPort(oldport);
-	adjust_notice_scrollbar();
 }
 
 void
 adjust_notice_scrollbar()
 {
-	int lines, oldmax, newmax, oldvalue, newvalue;
+	int	oldmax, newmax, oldvalue, newvalue;
 
 	oldvalue = GetCtlValue(notice_v_scrollbar);
 	oldmax = GetCtlMax(notice_v_scrollbar);
-	lines = (*notice_text)->nLines;
-	/* Account for a return at the end of the text. */
-	if (*(*(*notice_text)->hText + (*notice_text)->teLength - 1) == 0x0d)
-	  ++lines;
-	newmax = lines - (((*notice_text)->viewRect.bottom - (*notice_text)->viewRect.top)
-					 / (*notice_text)->lineHeight);
+
+	/* Compute and set the new scrollbar max value. */
+	newmax = (*notice_text)->nLines 
+		 - (((*notice_text)->viewRect.bottom 
+		     - (*notice_text)->viewRect.top)
+		     / (*notice_text)->lineHeight);
 	if (newmax < 0)
-	  newmax = 0;
+	      newmax = 0;
 	SetCtlMax(notice_v_scrollbar, newmax);
+
+	/* If the thumb was at max, move it to the new max. */
 	if (oldvalue == oldmax) {
-		/* If the thumb was at max, move it to the new max. */
 		newvalue = newmax;
+	/* Else leave it alone. */
 	} else {
-		/* Otherwise adjust it proportionally. */
-		newvalue = ((*notice_text)->viewRect.top - (*notice_text)->destRect.top)
-					/ (*notice_text)->lineHeight;
-		if (newvalue < 0)
-		  newvalue = 0;
-		if (newvalue > newmax)
-		  newvalue = newmax;
+		newvalue = oldvalue;
 	}
 	SetCtlValue(notice_v_scrollbar, newvalue);
-	TEScroll(0, ((*notice_text)->viewRect.top - (*notice_text)->destRect.top)
-				 - (GetCtlValue(notice_v_scrollbar) * (*notice_text)->lineHeight),
-			 notice_text);
+
+	/* Finally do the text scrolling. */
+	TEScroll(0, (*notice_text)->viewRect.top 
+		        - (*notice_text)->destRect.top
+		        - (*notice_text)->lineHeight * newvalue, 
+		                notice_text);
 }
 
 void
@@ -2098,7 +2118,7 @@ grow_notice(int h, int v)
 	MoveControl(notice_v_scrollbar, h - floatsbarwid, -1);
 	SizeControl(notice_v_scrollbar, floatsbarwid + 1, v + 1 - floatsbarwid + 1);
 	(*notice_text)->viewRect.right = h - floatsbarwid;
-	(*notice_text)->viewRect.bottom = v - floatsbarwid;
+	(*notice_text)->viewRect.bottom = v;
 	(*notice_text)->destRect.right = h - floatsbarwid;
 	TECalText(notice_text);
 	InvalRect(&noticewin->portRect);
@@ -2136,7 +2156,7 @@ zoom_notice(int part)
 	SizeControl(notice_v_scrollbar, floatsbarwid + 1, v + 1 - floatsbarwid + 1);
 	adjust_notice_scrollbar();
 	(*notice_text)->viewRect.right = h - floatsbarwid;
-	(*notice_text)->viewRect.bottom = v - floatsbarwid;
+	(*notice_text)->viewRect.bottom = v;
 	(*notice_text)->destRect.right = h - floatsbarwid;
 	TECalText(notice_text);
 	/* This will force a full redraw at the next update. */
