@@ -1536,9 +1536,8 @@ save_the_game(Side *side)
     /* (should use name in save dialog) */
     notify_all("Game will be saved to \"%s\" ...", savename);
     if (write_entire_game_state(savename)) {
-	close_displays();
 	/* this should be conditional? */
-	exit(0);
+	exit_xconq(NULL);
     } else {
 	cmd_error(side, "Can't open file \"%s\"!", savename);
     }
