@@ -19,10 +19,6 @@ void init_emblem(Side *side2);
 
 int can_give_take(Unit *unit);
 
-#ifndef __STDC__
-void abort ();
-#endif
-
 Pixmap fuzzpics[NUMPOWERS];
 Pixmap windpics[5][NUMDIRS];
 Pixmap antpic;
