@@ -1,5 +1,5 @@
 /* Closeups for the X11 interface to Xconq.
-   Copyright (C) 1995-1998 Massimo Campostrini and Stanley T. Shebs.
+   Copyright (C) 1995-1999 Massimo Campostrini and Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -13,118 +13,118 @@ any later version.  See the file COPYING.  */
 
 #include "conq.h"
 #include "xtconq.h"
-extern void create_orders_window PARAMS ((Side *side, Map *map));
+extern void create_orders_window(Side *side, Map *map);
 
-static void buffer_append PARAMS ((int nl));
-static void add_to_closeup_summary PARAMS ((UnitCloseup *closeup, Side *side));
-static void remove_from_closeup_summary PARAMS ((UnitCloseup *closeup,
-						 Side *side));
-static void summary_list_callback PARAMS ((Widget w, XtPointer dummy,
-					   XawListReturnStruct *list));
-static void unit_closeup_update PARAMS ((Widget w, XtPointer cldata,
-					 XtPointer cadata));
-static void unit_closeup_focus PARAMS ((Widget w, XtPointer cldata,
-					XtPointer cadata));
-static void unit_closeup_close PARAMS ((Widget w, XtPointer cldata,
-					XtPointer cadata));
-static void side_closeup_update PARAMS ((Widget w, XtPointer cldata,
-					 XtPointer cadata));
-static void side_closeup_close PARAMS ((Widget w, XtPointer cldata,
-					XtPointer cadata));
-static void side_closeup_close PARAMS ((Widget w, XtPointer cldata,
-					XtPointer cadata));
-static void side_closeup_type_callback PARAMS ((Widget w, XtPointer cldata,
-						XtPointer cadata));
-static void side_closeup_all_types_callback PARAMS ((Widget w,
+static void buffer_append(int nl);
+static void add_to_closeup_summary(UnitCloseup *closeup, Side *side);
+static void remove_from_closeup_summary(UnitCloseup *closeup,
+						 Side *side);
+static void summary_list_callback(Widget w, XtPointer dummy,
+					   XawListReturnStruct *list);
+static void unit_closeup_update(Widget w, XtPointer cldata,
+					 XtPointer cadata);
+static void unit_closeup_focus(Widget w, XtPointer cldata,
+					XtPointer cadata);
+static void unit_closeup_close(Widget w, XtPointer cldata,
+					XtPointer cadata);
+static void side_closeup_update(Widget w, XtPointer cldata,
+					 XtPointer cadata);
+static void side_closeup_close(Widget w, XtPointer cldata,
+					XtPointer cadata);
+static void side_closeup_close(Widget w, XtPointer cldata,
+					XtPointer cadata);
+static void side_closeup_type_callback(Widget w, XtPointer cldata,
+						XtPointer cadata);
+static void side_closeup_all_types_callback(Widget w,
 						     XtPointer cldata,
-						     XtPointer cadata));
-static void build_unit_list PARAMS ((Widget w, XtPointer cldata,
-				     XtPointer cadata));
-static void unit_list_callback PARAMS ((Widget w, XtPointer dummy,
-					XawListReturnStruct *list));
-static void unit_list_close PARAMS ((Widget w, XtPointer cldata,
-				     XtPointer cadata));
-static UnitList *find_unit_list_via_button PARAMS ((Widget w, Side *side));
-void destroy_unit_list PARAMS ((Side *side, UnitList *unit_list));
-char *pad_string PARAMS ((char *str, int n, int min));
-void one_line_unit_summary PARAMS ((char *buf, Unit *unit, Side *side,
-				    int pos));
-void hp_and_acp_desc PARAMS ((char *buf, Unit *unit, char *sep));
-void list_unit_types PARAMS ((char *buff, int nums[])); 
+						     XtPointer cadata);
+static void build_unit_list(Widget w, XtPointer cldata,
+				     XtPointer cadata);
+static void unit_list_callback(Widget w, XtPointer dummy,
+					XawListReturnStruct *list);
+static void unit_list_close(Widget w, XtPointer cldata,
+				     XtPointer cadata);
+static UnitList *find_unit_list_via_button(Widget w, Side *side);
+void destroy_unit_list(Side *side, UnitList *unit_list);
+char *pad_string(char *str, int n, int min);
+void one_line_unit_summary(char *buf, Unit *unit, Side *side,
+				    int pos);
+void hp_and_acp_desc(char *buf, Unit *unit, char *sep);
+void list_unit_types(char *buff, int nums[]); 
 
-Widget new_order_widgets PARAMS ((Side *side, OrderInterface *ordi, int num,
-				  Widget up));
-void sorder_cond_name PARAMS ((char *buffer, StandingOrder *sorder,
-			       Side *side));
-void update_order_widgets PARAMS ((Side *side, OrderInterface *ordi, 
+Widget new_order_widgets(Side *side, OrderInterface *ordi, int num,
+				  Widget up);
+void sorder_cond_name(char *buffer, StandingOrder *sorder,
+			       Side *side);
+void update_order_widgets(Side *side, OrderInterface *ordi, 
 				   StandingOrder *sorder, char *types,
-				   Task *task));
-static void orders_help_call PARAMS ((Widget w, XtPointer cldata,
-				      XtPointer cadata));
-static void orders_done_help_call PARAMS ((Widget w, XtPointer cldata,
-					   XtPointer cadata));
-static void handle_done_orders_help PARAMS ((Widget w, XEvent *event,
+				   Task *task);
+static void orders_help_call(Widget w, XtPointer cldata,
+				      XtPointer cadata);
+static void orders_done_help_call(Widget w, XtPointer cldata,
+					   XtPointer cadata);
+static void handle_done_orders_help(Widget w, XEvent *event,
 					     String *params,
-					     Cardinal *num_params));
-static void handle_done_string_select PARAMS ((Widget w, XEvent *event,
+					     Cardinal *num_params);
+static void handle_done_string_select(Widget w, XEvent *event,
 					       String *params,
-					       Cardinal *num_params));
-static void orders_add_call PARAMS ((Widget w, XtPointer cldata,
-				     XtPointer cadata));
-static void orders_clone_call PARAMS ((Widget w, XtPointer cldata,
-				       XtPointer cadata));
-static void orders_add_named PARAMS ((Widget w, char *string));
-static void orders_delete_call PARAMS ((Widget w, XtPointer cldata,
-					XtPointer cadata));
-static void orders_undo_call PARAMS ((Widget w, XtPointer cldata,
-				      XtPointer cadata));
-static void orders_save_call PARAMS ((Widget w, XtPointer cldata,
-				      XtPointer cadata));
-static void orders_restore_call PARAMS ((Widget w, XtPointer cldata,
-					 XtPointer cadata));
-static void orders_close_call PARAMS ((Widget w, XtPointer cldata,
-				       XtPointer cadata));
-static void order_toggle_call PARAMS ((Widget w, XtPointer cldata,
-				       XtPointer cadata));
-static void order_types_call PARAMS ((Widget w, XtPointer cldata,
-				      XtPointer cadata));
-static void order_etype_call PARAMS ((Widget w, XtPointer cldata,
-				      XtPointer cadata));
-static void order_eparms_call PARAMS ((Widget w, XtPointer cldata,
-				       XtPointer cadata));
-static void order_task_call PARAMS ((Widget w, XtPointer cldata,
-				     XtPointer cadata));
-static void order_tparms_call PARAMS ((Widget w, XtPointer cldata,
-				       XtPointer cadata));
-void set_cell_from_map PARAMS ((Side *side, Map *map, char *prompt,
-				void *px, void *py, int size));
-static void aux_set_cell PARAMS ((Side *side, Map *map, int cancel));
-void set_unit_from_map PARAMS ((Side *side, Map *map, char *prompt,
-				int *puid));
-static void aux_set_unit PARAMS ((Side *side, Map *map, int cancel));
-int find_side_and_ordi_via_widget PARAMS ((Widget w, Side **sidep,
-					   OrderInterface **ordip));
-void deactivate_orders PARAMS ((Side *side));
-OrderInterface *active_ordi PARAMS ((Side *side));
-int utype_select_popup PARAMS ((Side *side, Position x, Position y));
-static void utype_select_call PARAMS ((Widget w, XtPointer cldata,
-				       XtPointer cadata));
-int dir_select_popup PARAMS ((Side *side, Position x, Position y));
-static void dir_select_call PARAMS ((Widget w, XtPointer cldata,
-				     XtPointer cadata));
-int integer_select_popup PARAMS ((Side *side, Position x, Position y,
-				  int init, char *prompt));
-void string_select_popup PARAMS ((Side *side, Position x, Position y,
-				  char *result, char *init, char *prompt));
-int cond_select_popup PARAMS ((Side *side, Position x, Position y));
-static void cond_select_call PARAMS ((Widget w, XtPointer cldata,
-				      XtPointer cadata));
-int task_select_popup PARAMS ((Side *side, Position x, Position y));
-static void task_select_call PARAMS ((Widget w, XtPointer cldata,
-				      XtPointer cadata));
-int count_sorder PARAMS ((Side *side));
+					       Cardinal *num_params);
+static void orders_add_call(Widget w, XtPointer cldata,
+				     XtPointer cadata);
+static void orders_clone_call(Widget w, XtPointer cldata,
+				       XtPointer cadata);
+static void orders_add_named(Widget w, char *string);
+static void orders_delete_call(Widget w, XtPointer cldata,
+					XtPointer cadata);
+static void orders_undo_call(Widget w, XtPointer cldata,
+				      XtPointer cadata);
+static void orders_save_call(Widget w, XtPointer cldata,
+				      XtPointer cadata);
+static void orders_restore_call(Widget w, XtPointer cldata,
+					 XtPointer cadata);
+static void orders_close_call(Widget w, XtPointer cldata,
+				       XtPointer cadata);
+static void order_toggle_call(Widget w, XtPointer cldata,
+				       XtPointer cadata);
+static void order_types_call(Widget w, XtPointer cldata,
+				      XtPointer cadata);
+static void order_etype_call(Widget w, XtPointer cldata,
+				      XtPointer cadata);
+static void order_eparms_call(Widget w, XtPointer cldata,
+				       XtPointer cadata);
+static void order_task_call(Widget w, XtPointer cldata,
+				     XtPointer cadata);
+static void order_tparms_call(Widget w, XtPointer cldata,
+				       XtPointer cadata);
+void set_cell_from_map(Side *side, Map *map, char *prompt,
+				void *px, void *py, int size);
+static void aux_set_cell(Side *side, Map *map, int cancel);
+void set_unit_from_map(Side *side, Map *map, char *prompt,
+				int *puid);
+static void aux_set_unit(Side *side, Map *map, int cancel);
+int find_side_and_ordi_via_widget(Widget w, Side **sidep,
+					   OrderInterface **ordip);
+void deactivate_orders(Side *side);
+OrderInterface *active_ordi(Side *side);
+int utype_select_popup(Side *side, Position x, Position y);
+static void utype_select_call(Widget w, XtPointer cldata,
+				       XtPointer cadata);
+int dir_select_popup(Side *side, Position x, Position y);
+static void dir_select_call(Widget w, XtPointer cldata,
+				     XtPointer cadata);
+int integer_select_popup(Side *side, Position x, Position y,
+				  int init, char *prompt);
+void string_select_popup(Side *side, Position x, Position y,
+				  char *result, char *init, char *prompt);
+int cond_select_popup(Side *side, Position x, Position y);
+static void cond_select_call(Widget w, XtPointer cldata,
+				      XtPointer cadata);
+int task_select_popup(Side *side, Position x, Position y);
+static void task_select_call(Widget w, XtPointer cldata,
+				      XtPointer cadata);
+int count_sorder(Side *side);
 
-static void orders_check PARAMS ((Side *side));
+static void orders_check(Side *side);
 
 static char buffer[200], *longbuffer = NULL;
 /* initial lengths of arrays, they will grow when needed */
@@ -2437,6 +2437,8 @@ XtPointer call_data;
 			      (void *) &side->ui->sorder_edit->a2,
 			      sizeof(side->ui->sorder_edit->a1));
 	    break;
+	  default:
+	    break;
 	}
     } else {
 	/* display */
@@ -3211,7 +3213,7 @@ Side *side;
 }
 
 int
-num_tasks()
+num_tasks(void)
 {
     int i;
 
@@ -3222,8 +3224,7 @@ num_tasks()
 /* debugging stuff */
 
 static void 
-orders_check (side)
-Side *side;
+orders_check (Side *side)
 {
     StandingOrder *sorder;
     OrderInterface *ordi;
