@@ -9,35 +9,36 @@ any later version.  See the file COPYING.  */
 #include "conq.h"
 #include "kpublic.h"
 #include "xtconq.h"
-extern void create_orders_window PARAMS ((Side *side, Map *map));
+extern void create_orders_window(Side *side, Map *map);
+extern void set_contour_interval(VP *vp, int n);
 
-static void aux_add_terrain PARAMS ((Side *side, Map *map, int cancel));
-static void aux_add_terrain_2 PARAMS ((Side *side, Map *map, int cancel));
-static void do_add_terrain_2 PARAMS ((Side *side, Map *map, int t));
-static void aux_attack PARAMS ((Side *side, Map *map, int cancel));
-static void aux_build PARAMS ((Side *side, Map *map, int cancel));
-static void impl_build PARAMS ((Side *side, Unit *unit, int u2, int n));
-static void aux_distance PARAMS ((Side *side, Map *map, int cancel));
-static void aux_fire_at PARAMS ((Side *side, Map *map, int cancel));
-static void aux_move_look PARAMS ((Side *side, Map *map));
-static void aux_move_dir PARAMS ((Side *side, Map *map, Unit *unit));
-static void aux_message PARAMS ((Side *side, Map *map, int cancel));
-static void aux_move_to PARAMS ((Side *side, Map *map, int cancel));
-static void aux_name PARAMS ((Side *side, Map *map, int cancel));
-static void aux_others PARAMS ((Side *side, Map *map, int cancel));
-static void aux_remove_terrain PARAMS ((Side *side, Map *map, int cancel));
-static void aux_remove_terrain_2 PARAMS ((Side *side, Map *map, int cancel));
-static void do_remove_terrain_2 PARAMS ((Side *side, Map *map, int t));
-static void aux_resign PARAMS ((Side *side, Map *map, int cancel));
-static void aux_resign_2 PARAMS ((Side *side, Map *map, int cancel));
-static void aux_leave_game PARAMS ((Side *side, Map *map, int cancel));
-static void aux_kill_game PARAMS ((Side *side, Map *map, int cancel));
-static void aux_resign_b PARAMS ((Side *side, Map *map, int cancel));
-static void aux_save_2 PARAMS ((Side *side, Map *map, int cancel));
-static void aux_save_1 PARAMS ((Side *side, Map *map, int cancel));
-static void aux_save_1_1 PARAMS ((Side *side, Map *map, int cancel));
-static void aux_set_formation PARAMS ((Side *side, Map *map, int cancel));
-static void save_the_game PARAMS ((Side *side));
+static void aux_add_terrain(Side *side, Map *map, int cancel);
+static void aux_add_terrain_2(Side *side, Map *map, int cancel);
+static void do_add_terrain_2(Side *side, Map *map, int t);
+static void aux_attack(Side *side, Map *map, int cancel);
+static void aux_build(Side *side, Map *map, int cancel);
+static void impl_build(Side *side, Unit *unit, int u2, int n);
+static void aux_distance(Side *side, Map *map, int cancel);
+static void aux_fire_at(Side *side, Map *map, int cancel);
+static void aux_move_look(Side *side, Map *map);
+static void aux_move_dir(Side *side, Map *map, Unit *unit);
+static void aux_message(Side *side, Map *map, int cancel);
+static void aux_move_to(Side *side, Map *map, int cancel);
+static void aux_name(Side *side, Map *map, int cancel);
+static void aux_others(Side *side, Map *map, int cancel);
+static void aux_remove_terrain(Side *side, Map *map, int cancel);
+static void aux_remove_terrain_2(Side *side, Map *map, int cancel);
+static void do_remove_terrain_2(Side *side, Map *map, int t);
+static void aux_resign(Side *side, Map *map, int cancel);
+static void aux_resign_2(Side *side, Map *map, int cancel);
+static void aux_leave_game(Side *side, Map *map, int cancel);
+static void aux_kill_game(Side *side, Map *map, int cancel);
+static void aux_resign_b(Side *side, Map *map, int cancel);
+static void aux_save_2(Side *side, Map *map, int cancel);
+static void aux_save_1(Side *side, Map *map, int cancel);
+static void aux_save_1_1(Side *side, Map *map, int cancel);
+static void aux_set_formation(Side *side, Map *map, int cancel);
+static void save_the_game(Side *side);
 
 /* Use this macro in any command if it requires a current unit. */
 
@@ -827,7 +828,7 @@ Side *side;
     Map *map = side->ui->curmap;
     int something = FALSE;
     int n, u, m, r, gift, actual;
-    Unit *unit = map->curunit, *main = NULL;
+    Unit *unit = map->curunit, *mainunit = NULL;
     char buf[BUFSIZE];
 
     if (nummtypes == 0) {
@@ -836,23 +837,23 @@ Side *side;
     }
     REQUIRE_UNIT(side, map);
     u = unit->type;
-    main = unit->transport;
-    if (main == NULL) {
+    mainunit = unit->transport;
+    if (mainunit == NULL) {
 	cmd_error(side, "Nothing to give to here!");
 	return;
     }
-    m = main->type;
+    m = mainunit->type;
     n = (map->prefixarg < 0 ? 1 : map->prefixarg);
 
     buf[0] = '\0';
     for_all_material_types(r) {
-	gift = (n < 0 ? (um_storage_x(m, r) - main->supply[r]) : n);
+	gift = (n < 0 ? (um_storage_x(m, r) - mainunit->supply[r]) : n);
 	if (gift > 0) {
 	    something = TRUE;
 	    /* Be stingy if we're low */
 	    if (2 * unit->supply[r] < um_storage_x(u, r))
 	      gift = max(1, gift/2);
-	    actual = transfer_supply(unit, main, r, gift);
+	    actual = transfer_supply(unit, mainunit, r, gift);
 	    tprintf(buf, " %d %s", actual, m_type_name(r));
 	}
     }
@@ -921,7 +922,7 @@ void
 do_map(side)
 Side *side;
 {
-    int u, n;
+    int n;
     Map *map = side->ui->curmap;
 
     if (empty_string(cmdargstr))
@@ -1778,7 +1779,6 @@ void
 do_standing_orders(side)
 Side *side;
 {
-    Map *map = side->ui->curmap;
     int rslt;
 
     if (cmdargstr) {
@@ -1940,13 +1940,13 @@ Side *side;
 
 #ifdef DESIGNERS
 
-static void aux_design PARAMS ((Side *side, Map *map, int cancel));
+static void aux_design(Side *side, Map *map, int cancel);
 
 int designed_on = FALSE;
 
-void enable_in_unit_type_list PARAMS ((Side *side, Map *map, int u, int flag));
+void enable_in_unit_type_list(Side *side, Map *map, int u, int flag);
 
-static void really_do_design PARAMS ((Side *side));
+static void really_do_design(Side *side);
 
 void
 do_design(side)
