@@ -1,5 +1,5 @@
 /* Lower-level drawing routines for the X11 interface to Xconq.
-   Copyright (C) 1987-1989, 1991-1998 Stanley T. Shebs.
+   Copyright (C) 1987-1989, 1991-1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -25,69 +25,60 @@ Map *tmpmap;
 
 #define conns_to_draw(m) (numconntypes > 0 && cwid[(m)->vp->power] > 0)
 
-Unit *x_find_unit_or_occ PARAMS ((Side *side, Map *map, Unit *unit,
-				 int usx, int usy, int usw, int ush,
-				 int sx, int sy));
-Unit *x_find_unit_at PARAMS ((Side *side, Map *map, int x, int y,
-			     int sx, int sy));
+Unit *x_find_unit_or_occ(Side *side, Map *map, Unit *unit,
+			 int usx, int usy, int usw, int ush, int sx, int sy);
+Unit *x_find_unit_at(Side *side, Map *map, int x, int y, int sx, int sy);
 
-static void xform_fractional PARAMS ((Side *side, Map *map,
-				      int x, int y, int xf, int yf,
-				      int *sxp, int *syp));
+static void xform_fractional(Side *side, Map *map,
+			     int x, int y, int xf, int yf, int *sxp, int *syp);
 
-static void draw_feature_name PARAMS ((Side *side, Map *map, int fid));
-static void draw_border_line_mult PARAMS ((Side *side, Map *map,
-					   Window win, int sx, int sy,
-					   int bitmask, int power, int t));
-static void draw_connection_line_mult PARAMS ((Side *side, Window win,
-					       int sx, int sy, int bitmask,
-					       int power, int c));
-static void draw_hex_polygon PARAMS ((Side *side, Map *map, Window win,
-				      GC gc, int sx, int sy,
-				      int power, int over, int dogrid));
-static void draw_area_background PARAMS ((Side *side, Map *map));
-static void meridian_line_callback PARAMS ((int x1, int y1, int x1f, int y1f,
-					    int x2, int y2, int x2f, int y2f));
-static void meridian_text_callback PARAMS ((int x1, int y1, int x1f, int y1f,
-					    char *str));
-static int cell_drawing_info PARAMS ((Side *side, int x, int y, int power,
-				      int seeall, Pixmap *patp, long *colorp));
-static void set_terrain_gc_for_image PARAMS ((Side *side, Image *timg));
-static void draw_terrain_row PARAMS ((Side *side, Map *map,
-				      int x0, int y0, int len, int force));
-static void draw_contours PARAMS ((Side *side, Map *map,
-				   int x0, int y0, int len));
-static void draw_elevations PARAMS ((Side *side, Map *map,
-				     int x0, int y0, int len));
-static void draw_clouds_row PARAMS ((Side *side, Map *map,
-				     int x0, int y0, int len));
-static void draw_temperature_row PARAMS ((Side *side, Map *map,
-					  int x0, int y0, int len));
-static void draw_winds_row PARAMS ((Side *side, Map *map,
-				    int x0, int y0, int len));
-static void draw_units PARAMS ((Side *side, Map *map, int x, int y));
-static void draw_unit_and_occs PARAMS ((Side *side, Map *map, Unit *unit,
-					int sx, int sy, int sw, int sh,
-					int drawoccs));
-static void draw_unit_name PARAMS ((Side *side, Map *map, Unit *unit,
-				   int sx, int sy, int sw, int sh));
-static void draw_people PARAMS ((Side *side, Map *map, int x, int y));
-static void draw_borders PARAMS ((Side *side, Map *map, int x, int y, int b));
-static void draw_connections PARAMS ((Side *side, Map *map, int x, int y,
-				      int c));
-static void draw_legend PARAMS ((Side *side, Map *map, int x, int y));
-static void draw_country_border_line PARAMS ((Side *side, Window win,
-					      int sx, int sy, int dir,
-					      int power));
-static void draw_legend_text PARAMS ((Side *side, Window win,
-				      int sx, int sy, int power, char *str,
-				      int color, int maskit));
-static void draw_feature_boundary PARAMS ((Side *side, Map *map,
-					   int x, int y, int fid));
-static void draw_info_text PARAMS ((Side *side, Map *map, int x, int y,
-				    int len, char *buf));
+static void draw_feature_name(Side *side, Map *map, int fid);
+static void draw_border_line_mult(Side *side, Map *map, Window win,
+				  int sx, int sy, int bitmask, int power,
+				  int t);
+static void draw_connection_line_mult(Side *side, Window win,
+				      int sx, int sy, int bitmask,
+				      int power, int c);
+static void draw_hex_polygon(Side *side, Map *map, Window win,
+			     GC gc, int sx, int sy,
+			     int power, int over, int dogrid);
+static void draw_area_background(Side *side, Map *map);
+static void meridian_line_callback(int x1, int y1, int x1f, int y1f,
+				   int x2, int y2, int x2f, int y2f);
+static void meridian_text_callback(int x1, int y1, int x1f, int y1f,
+				   char *str);
+static int cell_drawing_info(Side *side, int x, int y, int power,
+			     int seeall, Pixmap *patp, long *colorp);
+static void set_terrain_gc_for_image(Side *side, Image *timg);
+static void draw_terrain_row(Side *side, Map *map,
+			     int x0, int y0, int len, int force);
+static void draw_contours(Side *side, Map *map, int x0, int y0, int len);
+#if 0
+static void draw_elevations(Side *side, Map *map, int x0, int y0, int len);
+#endif
+static void draw_clouds_row(Side *side, Map *map, int x0, int y0, int len);
+static void draw_temperature_row(Side *side, Map *map, int x0, int y0,
+				 int len);
+static void draw_winds_row(Side *side, Map *map, int x0, int y0, int len);
+static void draw_units(Side *side, Map *map, int x, int y);
+static void draw_unit_and_occs(Side *side, Map *map, Unit *unit,
+			       int sx, int sy, int sw, int sh, int drawoccs);
+static void draw_unit_name(Side *side, Map *map, Unit *unit,
+			   int sx, int sy, int sw, int sh);
+static void draw_people(Side *side, Map *map, int x, int y);
+static void draw_borders(Side *side, Map *map, int x, int y, int b);
+static void draw_connections(Side *side, Map *map, int x, int y, int c);
+static void draw_legend(Side *side, Map *map, int x, int y);
+static void draw_country_border_line(Side *side, Window win,
+				     int sx, int sy, int dir, int power);
+static void draw_legend_text(Side *side, Window win,
+			     int sx, int sy, int power, char *str,
+			     int color, int maskit);
+static void draw_feature_boundary(Side *side, Map *map, int x, int y, int fid);
+static void draw_info_text(Side *side, Map *map, int x, int y,
+			   int len, char *buf);
 
-static void draw_meridians PARAMS ((Side *side, Map *map));
+static void draw_meridians(Side *side, Map *map);
 
 #define cell_overlay(side, x, y)  \
   ((side->designer) \
@@ -927,6 +918,7 @@ int x0, y0, len;
     }
 }
 
+#if 0
 static void
 draw_elevations(side, map, x0, y0, len)
 Side *side;
@@ -947,6 +939,7 @@ int x0, y0, len;
 	}
     }
 }
+#endif
 
 static void
 draw_clouds_row(side, map, x0, y0, len)
@@ -1680,7 +1673,7 @@ Side *side;
 Window win;
 int sx, sy, sw, sh, u, s2, fg, bg, mod;
 {
-    char buf[1], *ename;
+    char *ename;
     int sx2, sy2, ex, ey, ew, eh, desperate = FALSE;
     long imagecolor = side->ui->blackcolor, maskcolor = side->ui->whitecolor;
     Image *uimg;
@@ -1810,7 +1803,7 @@ Side *side;
 Window win;
 int ex, ey, ew, eh, s2, style;
 {
-    int ex2, ey2, ew2, eh2, offset;
+    int ex2, ey2, offset;
     long imagecolor, maskcolor;
     Image *eimg;
     X11Image *ximg;
@@ -1908,7 +1901,7 @@ Side *side;
 Map *map;
 {
     char infobuf[BUFSIZE];
-    int u, s, t, mrow, x = map->curx, y = map->cury, uview, len;
+    int u, s, mrow, x = map->curx, y = map->cury, uview, len;
     Unit *unit, *unit2;
     Side *side2 = NULL; /* init to keep GCC quiet */
 
