@@ -13,10 +13,6 @@ extern void init_emblem PARAMS ((Side *side, Side *side2));
 extern XrmOptionDescRec xoptions[];
 extern int xoptions_count;
 
-#ifndef __STDC__
-void abort ();
-#endif
-
 static void set_optional_colors PARAMS ((Side *side));
 static void init_gcs PARAMS ((Side *side));
 static void init_fonts PARAMS ((Side *side));
