@@ -10,79 +10,79 @@ any later version.  See the file COPYING.  */
    windows. */
 
 #include "conq.h"
-extern int num_features PARAMS ((void));
+extern int num_features(void);
 #include "kpublic.h"
 #include "xtconq.h"
-void update_unit_controls PARAMS ((Side *side, Map *map));
+void update_unit_controls(Side *side, Map *map);
 
-static void create_map_controls PARAMS ((Side *side, Map *map));
-static void interp_key_command PARAMS ((Side *side, Map *map));
-static void handle_map_click PARAMS ((Side *side, Map *map, int sx, int sy));
-static void help_unit_type PARAMS ((Side *side, Map *map));
-static void help_terrain_type PARAMS ((Side *side, Map *map));
-static void mode_callback PARAMS ((Widget w, XtPointer client_data,
-				  XtPointer call_data));
-static void command_callback PARAMS ((Widget w, XtPointer client_data,
-				     XtPointer call_data));
-static void view_flag_callback PARAMS ((Widget w, XtPointer client_data,
-				       XtPointer call_data));
-static void zoom_callback PARAMS ((Widget w, XtPointer client_data,
-				  XtPointer call_data));
-static void map_help_callback PARAMS ((Widget w, XtPointer client_data,
-				      XtPointer call_data));
-static void unit_type_list_callback PARAMS ((Widget w, XtPointer client_data,
-					    XtPointer call_data));
-static void panner_callback PARAMS ((Widget w, XtPointer client_data,
-				    XtPointer call_data));
-static void porthole_callback PARAMS ((Widget w, XtPointer client_data,
-				      XtPointer call_data));
-static void panner_resize_handler PARAMS ((Widget w, XtPointer client_data,
-					  XEvent *event, Boolean *cont));
-static void MA_keypress PARAMS ((Widget w, XEvent *event, String *params,
-				Cardinal *num_params));
-static void MA_mapexpose PARAMS ((Widget w, XEvent *event, String *params,
-				 Cardinal *num_params));
-static void MA_setcoord PARAMS ((Widget w, XEvent *event, String *params,
-				Cardinal *num_params));
-static void MA_movelook PARAMS ((Widget w, XEvent *event, String *params,
-				Cardinal *num_params));
-static void MA_moveunit PARAMS ((Widget w, XEvent *event, String *params,
-				Cardinal *num_params));
-static void MA_distance PARAMS ((Widget w, XEvent *event, String *params,
-				Cardinal *num_params));
-static void MA_motionsetcoord PARAMS ((Widget w, XEvent *event, String *params,
-				      Cardinal *num_params));
-static void MA_toolaction PARAMS ((Widget w, XEvent *event, String *params,
-				  Cardinal *num_params));
-static void MA_toolselection PARAMS ((Widget w, XEvent *event, String *params,
-				     Cardinal *num_params));
-static void MA_movelook_ul PARAMS ((Widget wdgt, XEvent *event, String *params,
-				   Cardinal *num_params));
-static void MA_movelook_l  PARAMS ((Widget wdgt, XEvent *event, String *params,
-				   Cardinal *num_params));
-static void MA_movelook_dl PARAMS ((Widget wdgt, XEvent *event, String *params,
-				   Cardinal *num_params));
-static void MA_movelook_ur PARAMS ((Widget wdgt, XEvent *event, String *params,
-				   Cardinal *num_params));
-static void MA_movelook_r  PARAMS ((Widget wdgt, XEvent *event, String *params,
-				   Cardinal *num_params));
-static void MA_movelook_dr PARAMS ((Widget wdgt, XEvent *event, String *params,
-				   Cardinal *num_params));
-static void MA_center PARAMS ((Widget wdgt, XEvent *event, String *params,
-			      Cardinal *num_params));
-static void movelook_one_cell PARAMS ((Widget w, int xdelta, int ydelta));
-static void popup_ctrlpanel PARAMS ((Side *side, Map *map));
-static void popdown_ctrlpanel PARAMS ((Side *side, Map *map));
-static void create_ctrlpanel PARAMS ((Side *side, Map *map));
-static void ctrlpanel_cancel_callback PARAMS ((Widget w, XtPointer client_data,
-					      XtPointer call_data));
-static void ctrlpanel_revert_callback PARAMS ((Widget w, XtPointer client_data,
-					      XtPointer call_data));
-static void ctrlpanel_apply_callback PARAMS ((Widget w, XtPointer client_data,
-					     XtPointer call_data));
-static void ctrlpanel_done_callback PARAMS ((Widget w, XtPointer client_data,
-					    XtPointer call_data));
-static int set_from_controls PARAMS ((Side *side, Map *map));
+static void create_map_controls(Side *side, Map *map);
+static void interp_key_command(Side *side, Map *map);
+static void handle_map_click(Side *side, Map *map, int sx, int sy);
+static void help_unit_type(Side *side, Map *map);
+static void help_terrain_type(Side *side, Map *map);
+static void mode_callback(Widget w, XtPointer client_data,
+			  XtPointer call_data);
+static void command_callback(Widget w, XtPointer client_data,
+			     XtPointer call_data);
+static void view_flag_callback(Widget w, XtPointer client_data,
+			       XtPointer call_data);
+static void zoom_callback(Widget w, XtPointer client_data,
+			  XtPointer call_data);
+static void map_help_callback(Widget w, XtPointer client_data,
+			      XtPointer call_data);
+static void unit_type_list_callback(Widget w, XtPointer client_data,
+				    XtPointer call_data);
+static void panner_callback(Widget w, XtPointer client_data,
+			    XtPointer call_data);
+static void porthole_callback(Widget w, XtPointer client_data,
+			      XtPointer call_data);
+static void panner_resize_handler(Widget w, XtPointer client_data,
+				  XEvent *event, Boolean *cont);
+static void MA_keypress(Widget w, XEvent *event, String *params,
+			Cardinal *num_params);
+static void MA_mapexpose(Widget w, XEvent *event, String *params,
+			 Cardinal *num_params);
+static void MA_setcoord(Widget w, XEvent *event, String *params,
+			Cardinal *num_params);
+static void MA_movelook(Widget w, XEvent *event, String *params,
+			Cardinal *num_params);
+static void MA_moveunit(Widget w, XEvent *event, String *params,
+			Cardinal *num_params);
+static void MA_distance(Widget w, XEvent *event, String *params,
+			Cardinal *num_params);
+static void MA_motionsetcoord(Widget w, XEvent *event, String *params,
+			      Cardinal *num_params);
+static void MA_toolaction(Widget w, XEvent *event, String *params,
+			  Cardinal *num_params);
+static void MA_toolselection(Widget w, XEvent *event, String *params,
+			     Cardinal *num_params);
+static void MA_movelook_ul(Widget wdgt, XEvent *event, String *params,
+			   Cardinal *num_params);
+static void MA_movelook_l (Widget wdgt, XEvent *event, String *params,
+			   Cardinal *num_params);
+static void MA_movelook_dl(Widget wdgt, XEvent *event, String *params,
+			   Cardinal *num_params);
+static void MA_movelook_ur(Widget wdgt, XEvent *event, String *params,
+			   Cardinal *num_params);
+static void MA_movelook_r (Widget wdgt, XEvent *event, String *params,
+			   Cardinal *num_params);
+static void MA_movelook_dr(Widget wdgt, XEvent *event, String *params,
+			   Cardinal *num_params);
+static void MA_center(Widget wdgt, XEvent *event, String *params,
+		      Cardinal *num_params);
+static void movelook_one_cell(Widget w, int xdelta, int ydelta);
+static void popup_ctrlpanel(Side *side, Map *map);
+static void popdown_ctrlpanel(Side *side, Map *map);
+static void create_ctrlpanel(Side *side, Map *map);
+static void ctrlpanel_cancel_callback(Widget w, XtPointer client_data,
+				      XtPointer call_data);
+static void ctrlpanel_revert_callback(Widget w, XtPointer client_data,
+				      XtPointer call_data);
+static void ctrlpanel_apply_callback(Widget w, XtPointer client_data,
+				     XtPointer call_data);
+static void ctrlpanel_done_callback(Widget w, XtPointer client_data,
+				    XtPointer call_data);
+static int set_from_controls(Side *side, Map *map);
 
 XtActionsRec map_actions_table[] = {
     { "keypress", MA_keypress },
@@ -115,9 +115,7 @@ add_map_actions()
    of the different subareas. */
 
 static void
-subdivide_map(side, map)
-Side *side;
-Map *map;
+subdivide_map(Side *side, Map *map)
 {
     /* Subdivide the window into right and left halves. */
     if (map->leftfrac == 0)
@@ -1191,7 +1189,7 @@ XEvent *evt;
 {
     char buf[4], ch;
     int nchar, cancelled;
-    void (*fn) PARAMS ((Side *sidex, Map *mapx, int cancelledx));
+    void (*fn)(Side *sidex, Map *mapx, int cancelledx);
 
     nchar = XLookupString(&(evt->xkey), buf, 4, NULL, NULL);
     if (nchar > 0) {
@@ -1344,7 +1342,7 @@ Side *side;
 Map *map;
 char *prompt;
 int *possibles;
-void (*handler)();
+void (*handler)(Side *side, Map *map, int cancel);
 {
     int u, numtypes = 0;
 
@@ -1467,7 +1465,7 @@ Side *side;
 Map *map;
 char *prompt;
 int *possibles;
-void (*handler) PARAMS ((Side *side, Map *map, int cancelled));
+void (*handler)(Side *side, Map *map, int cancelled);
 {
     int numtypes = 0, t;
 
@@ -1550,7 +1548,7 @@ ask_position(side, map, prompt, handler)
 Side *side;
 Map *map;
 char *prompt;
-void (*handler) PARAMS ((Side *side, Map *map, int cancelled));
+void (*handler)(Side *side, Map *map, int cancelled);
 {
     strcpy(map->prompt, prompt);
     map->answer[0] = '\0';
@@ -1589,7 +1587,7 @@ Side *side;
 Map *map;
 char *question;
 int dflt;
-void (*handler) PARAMS ((Side *side, Map *map, int cancelled));
+void (*handler)(Side *side, Map *map, int cancelled);
 {
     sprintf(map->prompt, "%s [%s]", question, (dflt ? "yn" : "ny"));
     map->answer[0] = '\0';
@@ -1622,7 +1620,7 @@ ask_string(side, map, prompt, dflt, handler)
 Side *side;
 Map *map;
 char *prompt, *dflt;
-void (*handler) PARAMS ((Side *side, Map *map, int cancelled));
+void (*handler)(Side *side, Map *map, int cancelled);
 {
     sprintf(map->prompt, "%s", prompt);
     /* Default must be non-NULL. */
@@ -1669,7 +1667,7 @@ Side *side;
 Map *map;
 char *prompt;
 Side *dfltside;
-void (*handler) PARAMS ((Side *side, Map *map, int cancel));
+void (*handler)(Side *side, Map *map, int cancel);
 {
     char *dfltstr;
 
@@ -1686,7 +1684,7 @@ Side *side;
 Map *map;
 Side **side2p;
 {
-    char ch = map->inpch, *str;
+    char ch = map->inpch;
     int len;
     Side *side3;
 
@@ -1735,10 +1733,7 @@ Side **side2p;
 /* Given a pixel in a map, describe what's there. */
 
 static void
-move_look(side, map, sx, sy)
-Side *side;
-Map *map;
-int sx, sy;
+move_look(Side *side, Map *map, int sx, int sy)
 {
     int nx, ny;
     Unit *unit;
@@ -2036,7 +2031,7 @@ XtPointer call_data;
     int which = (int) client_data;
     Side *side;
     Map *map;
-    void (*fn) PARAMS ((Side *sidex, Map *mapx, int cancelledx));
+    void (*fn)(Side *sidex, Map *mapx, int cancelledx);
     
     if (!find_side_and_map_via_listform(w, &side, &map))
       return;
@@ -2171,7 +2166,7 @@ int sx, sy;
 {
     int ax, ay;
     Unit *unit2;
-    void (*fn) PARAMS ((Side *sidex, Map *mapx, int cancelledx));
+    void (*fn)(Side *sidex, Map *mapx, int cancelledx);
 
     if (map == NULL) {
 	beep(side);
@@ -2724,7 +2719,7 @@ XtPointer call_data;
     update_controls(side, map);
 }
 
-int get_toggle_state PARAMS ((Widget w));
+int get_toggle_state(Widget w);
 
 int
 get_toggle_state(w)
@@ -2866,7 +2861,7 @@ Map *map;
       XtPopdown(map->ctrlpanel_shell);
 }
 
-void set_control_state PARAMS ((Side *side, Map *map, int, int, int));
+void set_control_state(Side *side, Map *map, int, int, int);
 
 void
 update_controls(side, map)
