@@ -1,12 +1,54 @@
 /* Definitions for the X11 Xt interface to Xconq.
-   Copyright (C) 1998, 1999 Stanley T. Shebs.
+   Copyright (C) 1987-1989, 1991-1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.  See the file COPYING.  */
 
-#include "xconq.h"
+/* Default color of text and icons - 0 is for white on black, 1 is for
+   black on white.  Should be set appropriately for the most common
+   monochrome display (color displays always do white on black).  This
+   is also settable by the player, so the default is just for
+   convenience of the majority. */
+
+#define BLACKONWHITE 1
+
+/* The default fonts can be altered by users, so these are just hints. */
+
+#define TEXTFONT "fixed"
+
+/* Some X11 servers die if too much is written between output flushes. */
+
+/* #define STUPIDFLUSH */
+
+#include <X11/Xos.h>
+#include <X11/Xlib.h>
+#include <X11/Xutil.h>
+#include <X11/Xresource.h>
+
+#include <math.h>
+
+#include "imf.h"
+#include "ximf.h"
+#include "ui.h"
+#include "print.h"
+
+enum grayshade {
+  black,
+  gray,
+  darkgray,
+  numgrays
+};
+
+/* Drawing techniques that may be used. */
+
+enum whattouse {
+  dontdraw,
+  useblocks,
+  usepictures,
+  usepolygons
+};
 
 /* This is the name of a family of programs, so argv[0] inadequate. */
 
@@ -420,7 +462,7 @@ typedef struct a_map {
     struct a_unit *curunit;	/* Unit under cursor */
     short savedcurx, savedcury;	/* Current spot being looked at (saved) */
     struct a_unit *savedcurunit;/* Unit under cursor (saved) */
-    void (*modalhandler) PARAMS ((Side *side, struct a_map *map, int cancelled));
+    void (*modalhandler)(Side *side, struct a_map *map, int cancelled);
     char inpch;			/* Keyboard char */
     short inptype;		/* Unit type clicked in unit type list */
     short prefixarg;		/* numerical prefix argument */
@@ -460,196 +502,173 @@ extern Arg tmpargs[];
 
 /* Declarations of globally visible functions. */
 
-extern int ask_unit_type PARAMS ((Side *side, Map *map, char *prompt,
-				 int *poss,
-				 void (*handler)(Side *side, Map *map,
-						 int cancel)));
-extern int ask_terrain_type PARAMS ((Side *side, Map *map, char *prompt,
-				    int *poss,
-				    void (*handler)(Side *side, Map *map,
-						    int cancel)));
-extern void ask_side PARAMS ((Side *side, Map *map, char *prompt,
-			     Side *dflt,
-			     void (*handler)(Side *side, Map *map,
-					     int cancel)));
-extern void ask_position PARAMS ((Side *side, Map *map, char *prompt,
-				 void (*handler)(Side *side, Map *map,
-						 int cancel)));
-extern void ask_bool PARAMS ((Side *side, Map *map, char *prompt,
-			     int dflt, void (*handler)(Side *side, Map *map,
-						       int cancel)));
-extern void ask_string PARAMS ((Side *side, Map *map, char *prompt, char *dflt,
-			       void (*handler)(Side *side, Map *map,
-					       int cancel)));
+extern int ask_unit_type(Side *side, Map *map, char *prompt, int *poss,
+			 void (*handler)(Side *side, Map *map, int cancel));
+extern int ask_terrain_type(Side *side, Map *map, char *prompt, int *poss,
+			    void (*handler)(Side *side, Map *map, int cancel));
+extern void ask_side(Side *side, Map *map, char *prompt, Side *dflt,
+		     void (*handler)(Side *side, Map *map, int cancel));
+extern void ask_position(Side *side, Map *map, char *prompt,
+			 void (*handler)(Side *side, Map *map, int cancel));
+extern void ask_bool(Side *side, Map *map, char *prompt, int dflt,
+		     void (*handler)(Side *side, Map *map, int cancel));
+extern void ask_string(Side *side, Map *map, char *prompt, char *dflt,
+		       void (*handler)(Side *side, Map *map, int cancel));
 
-extern int grok_unit_type PARAMS ((Side *side, Map *map, int *typep));
-extern int grok_terrain_type PARAMS ((Side *side, Map *map, int *typep));
-extern int grok_side PARAMS ((Side *side, Map *map, Side **side2p));
-extern int grok_position PARAMS ((Side *side, Map *map, int *xp, int *yp,
-				  Unit **unitp));
-extern int grok_bool PARAMS ((Side *side, Map *map));
-extern int grok_string PARAMS ((Side *side, Map *map, char **strp));
+extern int grok_unit_type(Side *side, Map *map, int *typep);
+extern int grok_terrain_type(Side *side, Map *map, int *typep);
+extern int grok_side(Side *side, Map *map, Side **side2p);
+extern int grok_position(Side *side, Map *map, int *xp, int *yp, Unit **unitp);
+extern int grok_bool(Side *side, Map *map);
+extern int grok_string(Side *side, Map *map, char **strp);
 
-extern void xform PARAMS ((Side *side, Map *map, int x, int y,
-			   int *sxp, int *syp));
-extern void x_xform_unit PARAMS ((Side *side, Map *map, Unit *unit,
-				   int *sxp, int *syp, int *swp, int *shp));
-extern void x_xform_unit_self PARAMS ((Side *side, Map *map, Unit *unit,
-				     int *sxp, int *syp, int *swp, int *shp));
-extern void x_xform_occupant PARAMS ((Side *side, Map *map,
-				    Unit *transport, Unit *unit,
-				    int sx, int sy, int sw, int sh,
-				    int *sxp, int *syp, int *swp, int *shp));
-extern int x_nearest_cell PARAMS ((Side *side, Map *map, int sx, int sy,
-				  int *xp, int *yp));
-extern int x_nearest_boundary PARAMS ((Side *side, Map *map, int sx, int sy,
-				      int *xp, int *yp, int *dirp));
-extern int x_nearest_unit PARAMS ((Side *side, Map *map, int sx, int sy,
-				  Unit **unitp));
+extern void xform(Side *side, Map *map, int x, int y, int *sxp, int *syp);
+extern void x_xform_unit(Side *side, Map *map, Unit *unit,
+			 int *sxp, int *syp, int *swp, int *shp);
+extern void x_xform_unit_self(Side *side, Map *map, Unit *unit,
+			      int *sxp, int *syp, int *swp, int *shp);
+extern void x_xform_occupant(Side *side, Map *map, Unit *transport, Unit *unit,
+			     int sx, int sy, int sw, int sh,
+			     int *sxp, int *syp, int *swp, int *shp);
+extern int x_nearest_cell(Side *side, Map *map, int sx, int sy,
+			  int *xp, int *yp);
+extern int x_nearest_boundary(Side *side, Map *map, int sx, int sy,
+			      int *xp, int *yp, int *dirp);
+extern int x_nearest_unit(Side *side, Map *map, int sx, int sy, Unit **unitp);
 
-extern void init_x_signal_handlers PARAMS ((void));
+extern void init_x_signal_handlers(void);
 
-extern void popup_game_dialog PARAMS ((void));
+extern void popup_game_dialog(void);
 
-extern void check_player_displays PARAMS ((void));
-extern void init_redraws PARAMS ((void));
-extern void init_display PARAMS ((Side *side));
-extern void set_colors PARAMS ((Side *side));
-extern long request_color PARAMS ((Side *side, char *name));
+extern void check_player_displays(void);
+extern void init_redraws(void);
+extern void init_display(Side *side);
+extern void set_colors(Side *side);
+extern long request_color(Side *side, char *name);
 
-extern XFontStruct *open_font PARAMS ((Side *side, char *name, char *xdefault,
-				      XFontStruct *altfont, char *alttype,
-				      Font *fid));
-extern Cursor make_cursor PARAMS ((Display *dpy, Window win,
-				  char *cursbits, char *maskbits,
-				  unsigned long fg, unsigned long bg,
-				  unsigned int x, unsigned int y));
+extern XFontStruct *open_font(Side *side, char *name, char *xdefault,
+			      XFontStruct *altfont, char *alttype, Font *fid);
+extern Cursor make_cursor(Display *dpy, Window win,
+			  char *cursbits, char *maskbits,
+			  unsigned long fg, unsigned long bg,
+			  unsigned int x, unsigned int y);
 
-extern void reset_color_state PARAMS ((Side *side));
-extern void reset_window_colors PARAMS ((Side *side, Window win));
+extern void reset_color_state(Side *side);
+extern void reset_window_colors(Side *side, Window win);
 
-extern void set_current_unit PARAMS ((Side *side, Map *map, Unit *unit));
-extern void set_current_xy PARAMS ((Side *side, Map *map, int x, int y));
-extern void clear_current PARAMS ((Side *side, Map *map));
-extern void save_cur PARAMS ((Side *side, Map *map));
-extern void restore_cur PARAMS ((Side *side, Map *map));
+extern void set_current_unit(Side *side, Map *map, Unit *unit);
+extern void set_current_xy(Side *side, Map *map, int x, int y);
+extern void clear_current(Side *side, Map *map);
+extern void save_cur(Side *side, Map *map);
+extern void restore_cur(Side *side, Map *map);
 
-extern Map *create_map PARAMS ((Side *side, int power, char *geospec));
+extern Map *create_map(Side *side, int power, char *geospec);
 
-extern void add_map_actions PARAMS ((void));
+extern void add_map_actions(void);
 
-extern void set_tool_cursor PARAMS ((Side *side, Map *map));
+extern void set_tool_cursor(Side *side, Map *map);
 
-extern void set_map_power PARAMS ((Side *side, Map *map, int power));
-extern void x_center_on_focus PARAMS ((Side *side, Map *map));
+extern void set_map_power(Side *side, Map *map, int power);
+extern void x_center_on_focus(Side *side, Map *map);
 
-extern void handle_key_event PARAMS ((Side *side, Map *map, XEvent *evt));
+extern void handle_key_event(Side *side, Map *map, XEvent *evt);
 
-extern int find_side_and_map PARAMS ((Widget w, Side **sidep, Map **mapp));
-extern int find_side_and_map_via_control PARAMS ((Widget w,
-						 Side **sidep, Map **mapp));
-extern int find_side_and_map_via_listform PARAMS ((Widget w,
-						  Side **sidep, Map **mapp));
-extern int find_side_and_map_via_mapform PARAMS ((Widget w,
-						 Side **sidep, Map **mapp));
-extern int find_side_and_map_via_rightform PARAMS ((Widget w,
-						   Side **sidep, Map **mapp));
-extern int find_side_and_map_via_a_toplevel PARAMS ((Widget w,
-						    Side **sidep, Map **mapp));
-extern int find_side_and_map_via_porthole PARAMS ((Widget w,
-						  Side **sidep, Map **mapp));
-extern int find_side_via_widget PARAMS ((Widget w, Side **sidep));
+extern int find_side_and_map(Widget w, Side **sidep, Map **mapp);
+extern int find_side_and_map_via_control(Widget w, Side **sidep, Map **mapp);
+extern int find_side_and_map_via_listform(Widget w, Side **sidep, Map **mapp);
+extern int find_side_and_map_via_mapform(Widget w, Side **sidep, Map **mapp);
+extern int find_side_and_map_via_rightform(Widget w, Side **sidep, Map **mapp);
+extern int find_side_and_map_via_a_toplevel(Widget w, Side **sidep,
+					    Map **mapp);
+extern int find_side_and_map_via_porthole(Widget w, Side **sidep, Map **mapp);
+extern int find_side_via_widget(Widget w, Side **sidep);
 
-extern void update_controls PARAMS ((Side *side, Map *map));
+extern void update_controls(Side *side, Map *map);
 
-extern void draw_all_maps PARAMS ((Side *side));
+extern void draw_all_maps(Side *side);
 
-extern void draw_map PARAMS ((Side *side, Map *map));
-extern void draw_map_view PARAMS ((Side *side, Map *map));
-extern void destroy_map PARAMS ((Side *side, Map *map));
+extern void draw_map(Side *side, Map *map);
+extern void draw_map_view(Side *side, Map *map);
+extern void destroy_map(Side *side, Map *map);
 
 
-extern void draw_row PARAMS ((Side *side, Map *map,
-			     int x0, int y0, int len, int clearit));
-extern void draw_unit_image PARAMS ((Side *side, Window win,
-				    int sx, int sy, int sw, int sh,
-				    int u, int s2, int fg, int bg, int mod));
-extern void draw_side_emblem PARAMS ((Side *side, Window win,
-				     int ex, int ey, int ew, int eh,
-				     int s2, int style));
-extern void draw_current PARAMS ((Side *side, Map *map));
-extern void erase_current PARAMS ((Side *side, Map *map, int x, int y,
-				  Unit *unit));
+extern void draw_row(Side *side, Map *map, int x0, int y0, int len,
+		     int clearit);
+extern void draw_unit_image(Side *side, Window win,
+			    int sx, int sy, int sw, int sh,
+			    int u, int s2, int fg, int bg, int mod);
+extern void draw_side_emblem(Side *side, Window win, int ex, int ey,
+			     int ew, int eh, int s2, int style);
+extern void draw_current(Side *side, Map *map);
+extern void erase_current(Side *side, Map *map, int x, int y, Unit *unit);
 
-extern void draw_prompt PARAMS ((Side *side, Map *map));
-extern void clear_prompt PARAMS ((Side *side, Map *map));
-extern void draw_map_info PARAMS ((Side *side, Map *map));
-extern void draw_game_state PARAMS ((Side *side, Map *map));
-extern void draw_game_clocks PARAMS ((Side *side, Map *map));
-extern void draw_map_sides PARAMS ((Side *side, Map *map));
-extern void draw_side_info PARAMS ((Side *side, Map *map, Side *side2));
-extern void draw_side_progress PARAMS ((Side *side, Map *map, Side *side2));
+extern void draw_prompt(Side *side, Map *map);
+extern void clear_prompt(Side *side, Map *map);
+extern void draw_map_info(Side *side, Map *map);
+extern void draw_game_state(Side *side, Map *map);
+extern void draw_game_clocks(Side *side, Map *map);
+extern void draw_map_sides(Side *side, Map *map);
+extern void draw_side_info(Side *side, Map *map, Side *side2);
+extern void draw_side_progress(Side *side, Map *map, Side *side2);
 
-extern void put_on_screen PARAMS ((Side *side, Map *map, int x, int y));
-extern int in_middle PARAMS ((Side *side, Map *map, int x, int y));
+extern void put_on_screen(Side *side, Map *map, int x, int y);
+extern int in_middle(Side *side, Map *map, int x, int y);
 
-extern void move_the_selected_unit PARAMS ((Side *side, Map *map, Unit *unit,
-					   int sx, int sy));
+extern void move_the_selected_unit(Side *side, Map *map, Unit *unit,
+				   int sx, int sy);
 
-extern void create_help PARAMS ((Side *side));
-extern void popup_help PARAMS ((Side *side));
-extern void popdown_help PARAMS ((Side *side));
+extern void create_help(Side *side);
+extern void popup_help(Side *side);
+extern void popdown_help(Side *side);
 
-extern void recenter PARAMS ((Side *side, Map *map, int x, int y));
+extern void recenter(Side *side, Map *map, int x, int y);
 
-extern void draw_text PARAMS ((Side *side, Window win, int x, int y,
-			      char *str,int color));
-extern void draw_fg_text PARAMS ((Side *side, Window win, int x, int y,
-				 char *str));
+extern void draw_text(Side *side, Window win, int x, int y, char *str,
+		      int color);
+extern void draw_fg_text(Side *side, Window win, int x, int y, char *str);
 
-extern void textw_printf PARAMS ((const Widget w, const char *fmt, ...));
+extern void textw_printf(const Widget w, const char *fmt, ...);
 
-extern int font_width PARAMS ((XFontStruct *font));
-extern int font_height PARAMS ((XFontStruct *font));
+extern int font_width(XFontStruct *font);
+extern int font_height(XFontStruct *font);
 
-extern void close_display PARAMS ((Side *side));
+extern void close_display(Side *side);
 
-extern void exit_xconq PARAMS ((Side *side));
+extern void exit_xconq(Side *side);
 
-extern void notify_all PARAMS ((char *fmt, ...));
-extern void low_notify PARAMS ((Side *side, char *str));
-extern void redraw PARAMS ((Side *side));
-extern void flush_output PARAMS ((Side *side));
-extern void beep PARAMS ((Side *side));
+extern void notify_all(char *fmt, ...);
+extern void low_notify(Side *side, char *str);
+extern void redraw(Side *side);
+extern void flush_output(Side *side);
+extern void beep(Side *side);
 
-extern void flush_input PARAMS ((Side *side));
+extern void flush_input(Side *side);
 
-extern void build_name PARAMS ((char *name, char *first, char *second));
+extern void build_name(char *name, char *first, char *second);
 
-extern void draw_view_in_panner PARAMS ((Side *side, Map *map));
+extern void draw_view_in_panner(Side *side, Map *map);
 
-extern void set_message_area PARAMS ((Map *map, char *msg));
+extern void set_message_area(Map *map, char *msg);
 
-extern void add_map_actions PARAMS ((void));
+extern void add_map_actions(void);
 
-extern void update_unit_type_list PARAMS ((Side *side, Map *map, int u));
+extern void update_unit_type_list(Side *side, Map *map, int u);
 
-extern XawTextPosition widget_text_length PARAMS ((Widget w));
+extern XawTextPosition widget_text_length(Widget w);
 
-extern void move_caret_to_end PARAMS ((Widget w));
+extern void move_caret_to_end(Widget w);
 
-extern int popup_print_setup_dialog PARAMS ((Side *side));
+extern int popup_print_setup_dialog(Side *side);
 
-void place_legends PARAMS ((Side *side));
+void place_legends(Side *side);
 
 
-void enable_in_unit_type_list PARAMS ((Side *side, Map *map, int u, int flag));
+void enable_in_unit_type_list(Side *side, Map *map, int u, int flag);
 
-extern void zoom_in_out PARAMS ((Side *side, Map *map, int which));
+extern void zoom_in_out(Side *side, Map *map, int which);
 
-extern int find_side_and_map_via_ctrlpanel_form PARAMS ((Widget w,
-							Side **sidep,
-							Map **mapp));
+extern int find_side_and_map_via_ctrlpanel_form(Widget w, Side **sidep,
+						Map **mapp);
 
 extern int min_w_for_unit_image;
 extern int min_h_for_unit_image;
@@ -657,53 +676,52 @@ extern int min_h_for_unit_image;
 extern time_t game_start_in_real_time;
 extern time_t turn_play_start_in_real_time;
 
-extern void handle_map_sides_events PARAMS ((Widget w, XtPointer clientdata,
-					    XEvent *evt, Boolean *contdispatch));
-extern void handle_map_info_events PARAMS ((Widget w, XtPointer clientdata,
-					   XEvent *evt, Boolean *contdispatch));
+extern void handle_map_sides_events(Widget w, XtPointer clientdata,
+				    XEvent *evt, Boolean *contdispatch);
+extern void handle_map_info_events(Widget w, XtPointer clientdata,
+				   XEvent *evt, Boolean *contdispatch);
 
-extern void place_legends PARAMS ((Side *side));
+extern void place_legends(Side *side);
 
-extern void scroll_map_absolute PARAMS ((Side *side, Map *map, int sx, int sy));
-extern void scroll_map_relative PARAMS ((Side *side, Map *map, int sx, int sy));
+extern void scroll_map_absolute(Side *side, Map *map, int sx, int sy);
+extern void scroll_map_relative(Side *side, Map *map, int sx, int sy);
 
-extern void draw_blast_image PARAMS ((Side *side, Map *map, int sx, int sy, int sw, int sh, int blasttype));
-extern void invert_unit_subarea PARAMS ((Side *side, Map *map, int x, int y));
+extern void draw_blast_image(Side *side, Map *map, int sx, int sy,
+			     int sw, int sh, int blasttype);
+extern void invert_unit_subarea(Side *side, Map *map, int x, int y);
 
-extern void update_help PARAMS ((Side *side));
+extern void update_help(Side *side);
 
 #ifdef DESIGNERS
-extern void create_design PARAMS ((Side *side));
-extern void popup_design PARAMS ((Side *side));
-extern void update_curttype PARAMS ((Side *side));
-extern void update_curutype PARAMS ((Side *side));
-extern void update_cursidenumber PARAMS ((Side *side));
-extern void update_curfeature PARAMS ((Side *side));
-extern void update_curbrushradius PARAMS ((Side *side));
-extern void set_designer_cur_from_map PARAMS ((Side *side, Map *map,
-					      int sx, int sy));
-extern void handle_designer_map_click PARAMS ((Side *side, Map *map,
-					      int sx, int sy));
-extern void popdown_design PARAMS ((Side *side));
+extern void create_design(Side *side);
+extern void popup_design(Side *side);
+extern void update_curttype(Side *side);
+extern void update_curutype(Side *side);
+extern void update_cursidenumber(Side *side);
+extern void update_curfeature(Side *side);
+extern void update_curbrushradius(Side *side);
+extern void set_designer_cur_from_map(Side *side, Map *map, int sx, int sy);
+extern void handle_designer_map_click(Side *side, Map *map, int sx, int sy);
+extern void popdown_design(Side *side);
 #endif /* DESIGNERS */
 
-extern UnitCloseup *find_unit_closeup PARAMS ((Side *side, Unit *unit));
-extern UnitCloseup *find_unit_closeup_via_button PARAMS ((Widget w,
-							  Side *side));
-extern UnitCloseup *create_unit_closeup PARAMS ((Side *side, Map *map,
-						 Unit *unit));
-extern void draw_unit_closeup PARAMS ((Side *side, UnitCloseup *unitcloseup));
-extern void destroy_unit_closeup PARAMS ((Side *side,
-					  UnitCloseup *unitcloseup));
-extern SideCloseup *find_side_closeup PARAMS ((Side *side, Side *side2));
-extern SideCloseup *find_side_closeup_via_button PARAMS ((Widget w,
-							  Side *side));
-extern SideCloseup *create_side_closeup PARAMS ((Side *side, Map *map,
-						 Side *side2));
-extern void draw_side_closeup PARAMS ((Side *side, SideCloseup *sidecloseup));
-extern void destroy_side_closeup PARAMS ((Side *side,
-					  SideCloseup *sidecloseup));
-extern Pixmap get_unit_picture PARAMS ((int utype, Side *side));
-extern Pixmap get_side_picture PARAMS ((Side *side, Side *side1));
+extern UnitCloseup *find_unit_closeup(Side *side, Unit *unit);
+extern UnitCloseup *find_unit_closeup_via_button(Widget w, Side *side);
+extern UnitCloseup *create_unit_closeup(Side *side, Map *map, Unit *unit);
+extern void draw_unit_closeup(Side *side, UnitCloseup *unitcloseup);
+extern void destroy_unit_closeup(Side *side, UnitCloseup *unitcloseup);
+extern SideCloseup *find_side_closeup(Side *side, Side *side2);
+extern SideCloseup *find_side_closeup_via_button(Widget w, Side *side);
+extern SideCloseup *create_side_closeup(Side *side, Map *map, Side *side2);
+extern void draw_side_closeup(Side *side, SideCloseup *sidecloseup);
+extern void destroy_side_closeup(Side *side, SideCloseup *sidecloseup);
+extern Pixmap get_unit_picture(int utype, Side *side);
+extern Pixmap get_side_picture(Side *side, Side *side1);
+
+void raise_widget(Widget w);
+
+void initial_ui_init(int argc, char *argv[]);
+void ui_init(void);
+void ui_mainloop(void);
+
 
-void raise_widget PARAMS ((Widget w));
