@@ -1,5 +1,5 @@
 /* Toplevel code for the X11 Xt/Xaw interface to Xconq.
-   Copyright (C) 1987-1989, 1991-1998 Stanley T. Shebs.
+   Copyright (C) 1987-1989, 1991-1998, 1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -7,30 +7,23 @@ the Free Software Foundation; either version 2, or (at your option)
 any later version.  See the file COPYING.  */
 
 #include "conq.h"
-extern void notify_instructions PARAMS ((void));
-extern int sendnow;
 #include "kpublic.h"
 #include "cmdline.h"
 extern char *args_used;
 extern char *default_player_spec;
 #include "xtconq.h"
-extern void init_emblem PARAMS ((Side *side, Side *side2));
+extern void init_emblem(Side *side, Side *side2);
 
 extern String fallback_resources[];
 
-extern int connection_method;
-
 /* Local function declarations. */
 
-static void quit_program PARAMS ((Widget wdgt, XEvent *event, String *params,
-				  Cardinal *num_params));
-static void run_game_proc PARAMS ((XtPointer client_data, XtIntervalId *id));
-static Boolean run_game_idle PARAMS ((XtPointer clientdata));
-static void animate_current_proc PARAMS ((XtPointer client_data,
-					  XtIntervalId *id));
-static int handle_x_error PARAMS ((Display *dpy, XErrorEvent *evt));
-static int handle_xio_error PARAMS ((Display *dpy));
-static void handle_xt_error PARAMS ((String msg));
+static void quit_program(Widget wdgt, XEvent *event, String *params,
+			 Cardinal *num_params);
+static void run_game_proc(XtPointer client_data, XtIntervalId *id);
+static Boolean run_game_idle(XtPointer clientdata);
+static void animate_current_proc(XtPointer client_data, XtIntervalId *id);
+static void animate_fire_proc(XtPointer client_data, XtIntervalId *id);
 
 /* X-specific options, plus some NULL definitions so that they'll be
    ignored by X parsing and get passed through to the generic Xconq
@@ -91,9 +84,8 @@ Cardinal *num_params;
     }
 }
 
-initial_ui_init(argc, argv)
-int argc;
-char *argv[];
+void
+initial_ui_init(int argc, char *argv[])
 {
     /* Do the usual Xt application setup. */
     /* Note that this opens one display by default, which means that
@@ -107,7 +99,8 @@ char *argv[];
 		      fallback_resources, (ArgList) NULL, 0);
 }
 
-ui_init()
+void
+ui_init(void)
 {
     /* And, perform some once per application context initialization... */
     XtAppAddActions(thisapp, quit_actions_table, XtNumber(quit_actions_table));
@@ -117,7 +110,8 @@ ui_init()
     XtAppAddWorkProc(thisapp, run_game_idle, NULL);
 }
 
-ui_mainloop()
+void
+ui_mainloop(void)
 {
     XtAppMainLoop(thisapp);
 }
@@ -133,7 +127,7 @@ XtIntervalId *id;
     unsigned long interval;
 
     /* Check for any input from remotes. */
-    if (connection_method > 0 && my_rid > 0) {
+    if (my_rid > 0) {
 	flush_outgoing_queue();
 	receive_data(0);
 	++rslt;
@@ -143,7 +137,7 @@ XtIntervalId *id;
     rslt += net_run_game(1);
     run_local_ai(2, 20);
     /* Check for any input from remotes. */
-    if (connection_method > 0 && my_rid > 0) {
+    if (my_rid > 0) {
 	flush_outgoing_queue();
 	receive_data(0);
 	++rslt;
@@ -269,9 +263,9 @@ Side *side;
 /* Draw an individual detailed hex, as a row of one, on all maps. */
 
 void
-update_cell_display(side, x, y, rightnow)
+update_cell_display(side, x, y, flags)
 Side *side;
-int x, y, rightnow;
+int x, y, flags;
 {
     Map *map;
 
@@ -279,19 +273,19 @@ int x, y, rightnow;
 	for_all_maps(side, map) {
 	    /* If update was only to report changes in undrawn info,
 	       maybe don't bother. */
-	    if ((rightnow == 34 && !map->vp->draw_temperature) 
-		|| (rightnow == 35 && !map->vp->draw_winds)
-		|| (rightnow == 36 && !map->vp->draw_cover)
-		|| (rightnow == 37 && !map->vp->draw_clouds)
-		)
+	    if (!((flags & UPDATE_ALWAYS)
+		  || ((flags & UPDATE_COVER) && map->vp->draw_cover)
+		  || ((flags & UPDATE_TEMP) && map->vp->draw_temperature)
+		  || ((flags & UPDATE_CLOUDS) && map->vp->draw_clouds)
+		  || ((flags & UPDATE_WINDS) && map->vp->draw_winds)
+		  ))
 	      continue;
 	    draw_row(side, map, x, y, 1, TRUE);
 	    if (map->curunit && map->curunit->x == x && map->curunit->y == y) {
 		draw_current(side, map);
 	    }
 	}
-	if (rightnow)
-	  flush_output(side);
+	flush_output(side);
     }
 }
 
@@ -329,7 +323,7 @@ int rightnow;
 
     if (active_display(side) && unit != NULL) {
 	if (inside_area(unit->x, unit->y)) {
-	    update_cell_display(side, unit->x, unit->y, rightnow);
+	    update_cell_display(side, unit->x, unit->y, UPDATE_ALWAYS);
 	}
 	/* Redraw any/all info about unit and its side. */
 	for_all_maps(side, map) {
@@ -455,8 +449,6 @@ Side *side;
 HistEvent *hevt;
 int rightnow;
 {
-    Unit *unit;
-    Side *side2;
     Map *map;
 
     if (active_display(side)) {
@@ -467,6 +459,8 @@ int rightnow;
 		update_controls(side, map);
 	    }
 	    break;
+	  default:
+	    break;
 	}
 	if (rightnow)
 	  flush_output(side);
@@ -481,9 +475,7 @@ struct fire_state {
 } firestates[10];
 
 static void
-animate_fire_proc(client_data, id)
-XtPointer client_data;
-XtIntervalId *id;
+animate_fire_proc(XtPointer client_data, XtIntervalId *id)
 {
     int which = (int) client_data;
     int sx1, sy1, sw1, sh1, sx2, sy2, sw2, sh2, dx, dy, xx, yy;
@@ -979,7 +971,7 @@ Widget w;
     XawTextSetInsertionPoint(w, pos);
 }
 
-static int count_lines PARAMS ((Widget w));
+static int count_lines(Widget w);
 
 static int
 count_lines(w)
@@ -1002,7 +994,7 @@ Widget w;
     return nlines;
 }
 
-static void drop_lines_from_top PARAMS ((Widget w, int num));
+static void drop_lines_from_top(Widget w, int num);
 
 static void
 drop_lines_from_top(w, num)
@@ -1126,7 +1118,7 @@ long a1, a2, a3, a4, a5, a6, a7, a8, a9;
 }
 
 #if 0
-void textw_iprintf PARAMS ((const Widget w, const char *fmt, ...));
+void textw_iprintf(const Widget w, const char *fmt, ...);
 
 void
 #ifdef ANSI_PROTOTYPES
